(Slip Opinion) OCTOBER TERM, 2023 1


Syllabus


NOTE: Where it is feasible, a syllabus (headnote) will be released, as is
being done in connection with this case, at the time the opinion is issued.
The syllabus constitutes no part of the opinion of the Court but has been
prepared by the Reporter of Decisions for the convenience of the reader.
See _United States_ v. _Detroit Timber & Lumber Co.,_ 200 U. S. 321, 337.

# **SUPREME COURT OF THE UNITED STATES**


Syllabus


TRUMP _v_ . UNITED STATES


CERTIORARI TO THE UNITED STATES COURT OF APPEALS FOR
THE DISTRICT OF COLUMBIA CIRCUIT


No. 23–939. Argued April 25, 2024—Decided July 1, 2024


A federal grand jury indicted former President Donald J. Trump on four
counts for conduct that occurred during his Presidency following the
November 2020 election. The indictment alleged that after losing that
election, Trump conspired to overturn it by spreading knowingly false
claims of election fraud to obstruct the collecting, counting, and certifying of the election results. Trump moved to dismiss the indictment
based on Presidential immunity, arguing that a President has absolute
immunity from criminal prosecution for actions performed within the
outer perimeter of his official responsibilities, and that the indictment’s allegations fell within the core of his official duties. The District
Court denied Trump’s motion to dismiss, holding that former Presidents do not possess federal criminal immunity for any acts. The D. C.
Circuit affirmed. Both the District Court and the D. C. Circuit declined to decide whether the indicted conduct involved official acts.

_Held_ : Under our constitutional structure of separated powers, the nature
of Presidential power entitles a former President to absolute immunity
from criminal prosecution for actions within his conclusive and preclusive constitutional authority. And he is entitled to at least presumptive immunity from prosecution for all his official acts. There is no
immunity for unofficial acts. Pp. 5–43.

(a) This case is the first criminal prosecution in our Nation’s history
of a former President for actions taken during his Presidency. Determining whether and under what circumstances such a prosecution
may proceed requires careful assessment of the scope of Presidential
power under the Constitution. The nature of that power requires that
a former President have some immunity from criminal prosecution for
official acts during his tenure in office. At least with respect to the


---

2 TRUMP _v._ UNITED STATES


Syllabus


President’s exercise of his core constitutional powers, this immunity
must be absolute. As for his remaining official actions, he is entitled
to at least presumptive immunity. Pp. 5–15.

(1) Article II of the Constitution vests “executive Power” in “a
President of the United States of America.” §1, cl. 1. The President
has duties of “unrivaled gravity and breadth.” _Trump_ v. _Vance_, 591
U. S. 786, 800. His authority to act necessarily “stem[s] either from an
act of Congress or from the Constitution itself.” _Youngstown Sheet &_
_Tube Co._ v. _Sawyer_, 343 U. S. 579, 585. In the latter case, the President’s authority is sometimes “conclusive and preclusive.” _Id._, at 638
(Jackson, J., concurring). When the President exercises such authority, Congress cannot act on, and courts cannot examine, the President’s actions. It follows that an Act of Congress—either a specific one
targeted at the President or a generally applicable one—may not criminalize the President’s actions within his exclusive constitutional
power. Neither may the courts adjudicate a criminal prosecution that
examines such Presidential actions. The Court thus concludes that
the President is absolutely immune from criminal prosecution for conduct within his exclusive sphere of constitutional authority. Pp. 6–9.

(2) Not all of the President’s official acts fall within his “conclusive
and preclusive” authority. The reasons that justify the President’s absolute immunity from criminal prosecution for acts within the scope of
his exclusive constitutional authority do not extend to conduct in areas
where his authority is shared with Congress. To determine the President’s immunity in this context, the Court looks primarily to the Framers’ design of the Presidency within the separation of powers, precedent on Presidential immunity in the civil context, and criminal cases
where a President resisted prosecutorial demands for documents. P.
9.

(i) The Framers designed the Presidency to provide for a “vigorous” and “energetic” Executive. The Federalist No. 70, pp. 471–472 (J.
Cooke ed. 1961) (A. Hamilton). They vested the President with “supervisory and policy responsibilities of utmost discretion and sensitivity.” _Nixon_ v. _Fitzgerald_, 457 U. S. 731, 750. Appreciating the “unique
risks” that arise when the President’s energies are diverted by proceedings that might render him “unduly cautious in the discharge of
his official duties,” the Court has recognized Presidential immunities
and privileges “rooted in the constitutional tradition of the separation
of powers and supported by our history.” _Id._, at 749, 751, 752, n. 32.
In _Fitzgerald_, for instance, the Court concluded that a former President is entitled to absolute immunity from “damages liability for acts
within the ‘outer perimeter’ of his official responsibility.” _Id._, at 756.
The Court’s “dominant concern” was to avoid “diversion of the President’s attention during the decisionmaking process caused by needless


---

Cite as: 603 U. S. ____ (2024) 3


Syllabus


worry as to the possibility of damages actions stemming from any particular official decision.” _Clinton_ v. _Jones_, 520 U. S. 681, 694, n. 19.

By contrast, when prosecutors have sought evidence from the President, the Court has consistently rejected Presidential claims of absolute immunity. During the treason trial of former Vice President Aaron Burr, for instance, Chief Justice Marshall rejected President
Thomas Jefferson’s claim that the President could not be subjected to
a subpoena. Marshall simultaneously recognized, however, the existence of a “privilege” to withhold certain “official paper[s].” _United_
_States_ v. _Burr_, 25 F. Cas. 187, 192 (No. 14,694) (CC Va.). And when a
subpoena issued to President Richard Nixon, the Court rejected his
claim of “absolute privilege.” _United States_ v. _Nixon_, 418 U. S. 683,
703. But recognizing “the public interest in candid, objective, and even
blunt or harsh opinions in Presidential decisionmaking,” it held that a
“presumptive privilege” protects Presidential communications. _Id_ ., at
708. Because that privilege “relates to the effective discharge of a
President’s powers,” _id._, at 711, the Court deemed it “fundamental to
the operation of Government and inextricably rooted in the separation
of powers under the Constitution.” _Id_ ., at 708. Pp. 9–12.

(ii) Criminally prosecuting a President for official conduct undoubtedly poses a far greater threat of intrusion on the authority and
functions of the Executive Branch than simply seeking evidence in his
possession. The danger is greater than what led the Court to recognize
absolute Presidential immunity from civil damages liability—that the
President would be chilled from taking the “bold and unhesitating action” required of an independent Executive. _Fitzgerald_, 457 U. S., at
745. Although the President might be exposed to fewer criminal prosecutions than civil damages suits, the threat of trial, judgment, and
imprisonment is a far greater deterrent and plainly more likely to distort Presidential decisionmaking than the potential payment of civil
damages. The hesitation to execute the duties of his office fearlessly
and fairly that might result when a President is making decisions under “a pall of potential prosecution,” _McDonnell_ v. _United States_, 579
U. S. 550, 575, raises “unique risks to the effective functioning of government,” _Fitzgerald_, 457 U. S., at 751. But there is also a compelling
“public interest in fair and effective law enforcement.” _Vance_, 591
U. S., at 808.

Taking into account these competing considerations, the Court concludes that the separation of powers principles explicated in the
Court’s precedent necessitate at least a _presumptive_ immunity from
criminal prosecution for a President’s acts within the outer perimeter
of his official responsibility. Such an immunity is required to safeguard the independence and effective functioning of the Executive


---

4 TRUMP _v._ UNITED STATES


Syllabus


Branch, and to enable the President to carry out his constitutional duties without undue caution. At a minimum, the President must be
immune from prosecution for an official act unless the Government can
show that applying a criminal prohibition to that act would pose no
“dangers of intrusion on the authority and functions of the Executive
Branch.” _Fitzgerald_, 457 U. S., at 754. Pp. 12–15.

(3) As for a President’s unofficial acts, there is no immunity. Although Presidential immunity is required for _official_ actions to ensure
that the President’s decisionmaking is not distorted by the threat of
future litigation stemming from those actions, that concern does not
support immunity for _unofficial_ conduct. _Clinton_, 520 U. S., at 694,
and n. 19. The separation of powers does not bar a prosecution predicated on the President’s unofficial acts. P. 15.

(b) The first step in deciding whether a former President is entitled
to immunity from a particular prosecution is to distinguish his official
from unofficial actions. In this case, no court thus far has drawn that
distinction, in general or with respect to the conduct alleged in particular. It is therefore incumbent upon the Court to be mindful that it is
“a court of final review and not first view.” _Zivotofsky_ v. _Clinton_, 566
U. S. 189, 201. Critical threshold issues in this case are how to differentiate between a President’s official and unofficial actions, and how
to do so with respect to the indictment’s extensive and detailed allegations covering a broad range of conduct. The Court offers guidance on
those issues. Pp. 16–32.

(1) When the President acts pursuant to “constitutional and statutory authority,” he takes official action to perform the functions of his
office. _Fitzgerald_, 456 U. S., at 757. Determining whether an action
is covered by immunity thus begins with assessing the President’s authority to take that action. But the breadth of the President’s “discretionary responsibilities” under the Constitution and laws of the United
States frequently makes it “difficult to determine which of [his] innumerable ‘functions’ encompassed a particular action.” _Id._, at 756. The
immunity the Court has recognized therefore extends to the “outer perimeter” of the President’s official responsibilities, covering actions so
long as they are “not manifestly or palpably beyond [his] authority.”
_Blassingame_ v. _Trump_, 87 F. 4th 1, 13 (CADC).

In dividing official from unofficial conduct, courts may not inquire
into the President’s motives. Such a “highly intrusive” inquiry would
risk exposing even the most obvious instances of official conduct to judicial examination on the mere allegation of improper purpose. _Fitz-_
_gerald_, 457 U. S., at 756. Nor may courts deem an action unofficial
merely because it allegedly violates a generally applicable law. Otherwise, Presidents would be subject to trial on “every allegation that
an action was unlawful,” depriving immunity of its intended effect.


---

Cite as: 603 U. S. ____ (2024) 5


Syllabus


_Ibid_ . Pp. 17–19.


(2) With the above principles in mind, the Court turns to the conduct alleged in the indictment. Certain allegations—such as those involving Trump’s discussions with the Acting Attorney General—are
readily categorized in light of the nature of the President’s official relationship to the office held by that individual. Other allegations—
such as those involving Trump’s interactions with the Vice President,
state officials, and certain private parties, and his comments to the
general public—present more difficult questions. Pp. 19–30.

(i) The indictment alleges that as part of their conspiracy to
overturn the legitimate results of the 2020 presidential election,
Trump and his co-conspirators attempted to leverage the Justice Department’s power and authority to convince certain States to replace
their legitimate electors with Trump’s fraudulent slates of electors.
According to the indictment, Trump met with the Acting Attorney
General and other senior Justice Department and White House officials to discuss investigating purported election fraud and sending a
letter from the Department to those States regarding such fraud. The
indictment further alleges that after the Acting Attorney General resisted Trump’s requests, Trump repeatedly threatened to replace him.

The Government does not dispute that the indictment’s allegations
regarding the Justice Department involve Trump’s use of official
power. The allegations in fact plainly implicate Trump’s “conclusive
and preclusive” authority. The Executive Branch has “exclusive authority and absolute discretion” to decide which crimes to investigate
and prosecute, including with respect to allegations of election crime.
_Nixon_, 418 U. S., at 693. And the President’s “management of the Executive Branch” requires him to have “unrestricted power to remove
the most important of his subordinates”—such as the Attorney General—“in their most important duties.” _Fitzgerald_, 457 U. S., at 750.
The indictment’s allegations that the requested investigations were
shams or proposed for an improper purpose do not divest the President
of exclusive authority over the investigative and prosecutorial functions of the Justice Department and its officials. Because the President cannot be prosecuted for conduct within his exclusive constitutional authority, Trump is absolutely immune from prosecution for the
alleged conduct involving his discussions with Justice Department officials. Pp. 19–21.

(ii) The indictment next alleges that Trump and his co-conspirators “attempted to enlist the Vice President to use his ceremonial role
at the January 6 certification proceeding to fraudulently alter the election results.” App. 187, Indictment ¶10(d). In particular, the indictment alleges several conversations in which Trump pressured the Vice
President to reject States’ legitimate electoral votes or send them back


The Government does not dispute that the indictment’s allegations
regarding the Justice Department involve Trump’s use of official
power. The allegations in fact plainly implicate Trump’s “conclusive
and preclusive” authority. The Executive Branch has “exclusive authority and absolute discretion” to decide which crimes to investigate
and prosecute, including with respect to allegations of election crime.
_Nixon_, 418 U. S., at 693. And the President’s “management of the Executive Branch” requires him to have “unrestricted power to remove
the most important of his subordinates”—such as the Attorney General—“in their most important duties.” _Fitzgerald_, 457 U. S., at 750.
The indictment’s allegations that the requested investigations were
shams or proposed for an improper purpose do not divest the President
of exclusive authority over the investigative and prosecutorial functions of the Justice Department and its officials. Because the President cannot be prosecuted for conduct within his exclusive constitutional authority, Trump is absolutely immune from prosecution for the
alleged conduct involving his discussions with Justice Department officials. Pp. 19–21.


---

6 TRUMP _v._ UNITED STATES


Syllabus


to state legislatures for review.


Whenever the President and Vice President discuss their official responsibilities, they engage in official conduct. Presiding over the January 6 certification proceeding at which Members of Congress count
the electoral votes is a constitutional and statutory duty of the Vice
President. Art. II, §1, cl. 3; Amdt. 12; 3 U. S. C. §15. The indictment’s
allegations that Trump attempted to pressure the Vice President to
take particular acts in connection with his role at the certification proceeding thus involve official conduct, and Trump is at least presumptively immune from prosecution for such conduct.

The question then becomes whether that presumption of immunity
is rebutted under the circumstances. It is the Government’s burden to
rebut the presumption of immunity. The Court therefore remands to
the District Court to assess in the first instance whether a prosecution
involving Trump’s alleged attempts to influence the Vice President’s
oversight of the certification proceeding would pose any dangers of intrusion on the authority and functions of the Executive Branch. Pp.
21–24.

(iii) The indictment’s remaining allegations involve Trump’s interactions with persons outside the Executive Branch: state officials,
private parties, and the general public. In particular, the indictment
alleges that Trump and his co-conspirators attempted to convince certain state officials that election fraud had tainted the popular vote
count in their States, and thus electoral votes for Trump’s opponent
needed to be changed to electoral votes for Trump. After Trump failed
to convince those officials to alter their state processes, he and his coconspirators allegedly developed and effectuated a plan to submit
fraudulent slates of Presidential electors to obstruct the certification
proceeding. On Trump’s view, the alleged conduct qualifies as official
because it was undertaken to ensure the integrity and proper administration of the federal election. As the Government sees it, however,
Trump can point to no plausible source of authority enabling the President to take such actions. Determining whose characterization may
be correct, and with respect to which conduct, requires a fact-specific
analysis of the indictment’s extensive and interrelated allegations.
The Court accordingly remands to the District Court to determine in
the first instance whether Trump’s conduct in this area qualifies as
official or unofficial. Pp. 24–28.

(iv) The indictment also contains various allegations regarding
Trump’s conduct in connection with the events of January 6 itself. The
alleged conduct largely consists of Trump’s communications in the
form of Tweets and a public address. The President possesses “extraordinary power to speak to his fellow citizens and on their behalf.”
_Trump_ v. _Hawaii_, 585 U. S. 667, 701. So most of a President’s public


(iii) The indictment’s remaining allegations involve Trump’s interactions with persons outside the Executive Branch: state officials,
private parties, and the general public. In particular, the indictment
alleges that Trump and his co-conspirators attempted to convince certain state officials that election fraud had tainted the popular vote
count in their States, and thus electoral votes for Trump’s opponent
needed to be changed to electoral votes for Trump. After Trump failed
to convince those officials to alter their state processes, he and his coconspirators allegedly developed and effectuated a plan to submit
fraudulent slates of Presidential electors to obstruct the certification
proceeding. On Trump’s view, the alleged conduct qualifies as official
because it was undertaken to ensure the integrity and proper administration of the federal election. As the Government sees it, however,
Trump can point to no plausible source of authority enabling the President to take such actions. Determining whose characterization may
be correct, and with respect to which conduct, requires a fact-specific
analysis of the indictment’s extensive and interrelated allegations.
The Court accordingly remands to the District Court to determine in
the first instance whether Trump’s conduct in this area qualifies as
official or unofficial. Pp. 24–28.


---

Cite as: 603 U. S. ____ (2024) 7


Syllabus


communications are likely to fall comfortably within the outer perimeter of his official responsibilities. There may, however, be contexts in
which the President speaks in an unofficial capacity—perhaps as a
candidate for office or party leader. To the extent that may be the case,
objective analysis of “content, form, and context” will necessarily inform the inquiry. _Snyder_ v. _Phelps_, 562 U. S. 443, 453. Whether the
communications alleged in the indictment involve official conduct may
depend on the content and context of each. This necessarily factbound
analysis is best performed initially by the District Court. The Court
therefore remands to the District Court to determine in the first instance whether this alleged conduct is official or unofficial. Pp. 28–30.

(3) Presidents cannot be indicted based on conduct for which they
are immune from prosecution. On remand, the District Court must
carefully analyze the indictment’s remaining allegations to determine
whether they too involve conduct for which a President must be immune from prosecution. And the parties and the District Court must
ensure that sufficient allegations support the indictment’s charges
without such conduct. Testimony or private records of the President
or his advisers probing such conduct may not be admitted as evidence
at trial. Pp. 30–32.

(c) Trump asserts a far broader immunity than the limited one the
Court recognizes, contending that the indictment must be dismissed
because the Impeachment Judgment Clause requires that impeachment and Senate conviction precede a President’s criminal prosecution. But the text of the Clause does not address whether and on what
conduct a President may be prosecuted if he was never impeached and
convicted. See Art. I, §3, cl. 7. Historical evidence likewise lends little
support to Trump’s position. The Federalist Papers on which Trump
relies concerned the checks available against a _sitting_ President; they
did not endorse or even consider whether the Impeachment Judgment
Clause immunizes a _former_ President from prosecution. Transforming
the political process of impeachment into a necessary step in the enforcement of criminal law finds little support in the text of the Constitution or the structure of the Nation’s Government. Pp. 32–34.

(d) The Government takes a similarly broad view, contending that
the President enjoys no immunity from criminal prosecution for any
action. On its view, as-applied challenges in the course of the trial
suffice to protect Article II interests, and review of a district court’s
decisions on such challenges should be deferred until after trial. But
questions about whether the President may be held liable for particular actions, consistent with the separation of powers, must be addressed at the outset of a proceeding. Even if the President were ultimately not found liable for certain official actions, the possibility of an
extended proceeding alone may render him “unduly cautious in the


---

8 TRUMP _v._ UNITED STATES


Syllabus


discharge of his official duties.” _Fitzgerald_, 457 U. S., at 752, n. 32.
The Constitution does not tolerate such impediments to “the effective
functioning of government.” _Id._, at 751. Pp. 34–37.

(e) This case poses a question of lasting significance: When may a
former President be prosecuted for official acts taken during his Presidency? In answering that question, unlike the political branches and
the public at large, the Court cannot afford to fixate exclusively, or
even primarily, on present exigencies. Enduring separation of powers
principles guide our decision in this case. The President enjoys no immunity for his unofficial acts, and not everything the President does is
official. The President is not above the law. But under our system of
separated powers, the President may not be prosecuted for exercising
his core constitutional powers, and he is entitled to at least presumptive immunity from prosecution for his official acts. That immunity
applies equally to all occupants of the Oval Office. Pp. 41–43.

91 F. 4th 1173, vacated and remanded.


ROBERTS, C. J., delivered the opinion of the Court, in which THOMAS,
ALITO, GORSUCH, and KAVANAUGH, JJ., joined in full, and in which BAR
RETT, J., joined except as to Part III–C. THOMAS, J., filed a concurring
opinion. BARRETT, J., filed an opinion concurring in part. SOTOMAYOR,
J., filed a dissenting opinion, in which KAGAN and JACKSON, JJ., joined.
JACKSON, J., filed a dissenting opinion.


---

Cite as: 603 U. S. ____ (2024) 1


Opinion of the Court


NOTICE: This opinion is subject to formal revision before publication in the
United States Reports. Readers are requested to notify the Reporter of
Decisions, Supreme Court of the United States, Washington, D. C. 20543,
pio@supremecourt.gov, of any typographical or other formal errors.

# **SUPREME COURT OF THE UNITED STATES**

_________________


No. 23–939

_________________

DONALD J. TRUMP, PETITIONER _v._
UNITED STATES


ON WRIT OF CERTIORARI TO THE UNITED STATES COURT OF
APPEALS FOR THE DISTRICT OF COLUMBIA CIRCUIT


[July 1, 2024]


CHIEF JUSTICE ROBERTS delivered the opinion of the
Court.

This case concerns the federal indictment of a former
President of the United States for conduct alleged to involve
official acts during his tenure in office. We consider the
scope of a President’s immunity from criminal prosecution.

I
From January 2017 until January 2021, Donald J.
Trump served as President of the United States. On August 1, 2023, a federal grand jury indicted him on four
counts for conduct that occurred during his Presidency following the November 2020 election. The indictment alleged
that after losing that election, Trump conspired to overturn
it by spreading knowingly false claims of election fraud to
obstruct the collecting, counting, and certifying of the election results.
According to the indictment, Trump advanced his goal
through five primary means. First, he and his co-conspirators
“used knowingly false claims of election fraud to get state
legislators and election officials to . . . change electoral


---

2 TRUMP _v._ UNITED STATES


Opinion of the Court


votes for [Trump’s] opponent, Joseph R. Biden, Jr., to electoral votes for [Trump].” App. 185, Indictment ¶10(a). Second, Trump and his co-conspirators “organized fraudulent
slates of electors in seven targeted states” and “caused
these fraudulent electors to transmit their false certificates
to the Vice President and other government officials to be
counted at the certification proceeding on January 6.” _Id_ .,
at 186, ¶10(b). Third, Trump and his co-conspirators attempted to use the Justice Department “to conduct sham
election crime investigations and to send a letter to the targeted states that falsely claimed that the Justice Department had identified significant concerns that may have impacted the election outcome.” _Id_ ., at 186–187, ¶10(c).
Fourth, Trump and his co-conspirators attempted to persuade “the Vice President to use his ceremonial role at the
January 6 certification proceeding to fraudulently alter the
election results.” _Id_ ., at 187, ¶10(d). And when that failed,
on the morning of January 6, they “repeated knowingly
false claims of election fraud to gathered supporters, falsely
told them that the Vice President had the authority to and
might alter the election results, and directed them to the
Capitol to obstruct the certification proceeding.” _Ibid._
Fifth, when “a large and angry crowd . . . violently attacked
the Capitol and halted the proceeding,” Trump and his coconspirators “exploited the disruption by redoubling efforts
to levy false claims of election fraud and convince Members
of Congress to further delay the certification.” _Id_ ., at 187–
188, ¶10(e).

Based on this alleged conduct, the indictment charged
Trump with (1) conspiracy to defraud the United States in
violation of 18 U. S. C. §371, (2) conspiracy to obstruct an
official proceeding in violation of §1512(k), (3) obstruction
of and attempt to obstruct an official proceeding in violation


---

Cite as: 603 U. S. ____ (2024) 3


Opinion of the Court


of §1512(c)(2), §2, and (4) conspiracy against rights in violation of §241. [1 ]

Trump moved to dismiss the indictment based on Presidential immunity. In his view, the conduct alleged in the
indictment, properly characterized, was that while he was
President he (1) “made public statements about the administration of the federal election”; (2) communicated with
senior Justice Department officials “about investigating
election fraud and about choosing the leadership” of the Department; (3) “communicated with state officials about the
administration of the federal election and their exercise of
official duties with respect to it”; (4) “communicated with
the Vice President” and with “Members of Congress about
the exercise of their official duties regarding the election
certification”; and (5) “authorized or directed others to organize contingent slates of electors in furtherance of his attempts to convince the Vice President to exercise his official
authority in a manner advocated for by President Trump.”
Motion To Dismiss Indictment Based on Presidential Immunity in No. 1:23–cr–00257 (DC), ECF Doc. 74, p. 9.
Trump argued that all of the indictment’s allegations fell
within the core of his official duties. _Id._, at 27. And he contended that a President has absolute immunity from criminal prosecution for actions performed within the outer perimeter of his official responsibilities, to ensure that he can
undertake the especially sensitive duties of his office with
bold and unhesitating action. _Id._, at 14, 24.

The District Court denied the motion to dismiss, holding


——————

1 Trump contends that the indictment stretches Section 1512(c)(2) “far
beyond its natural meaning.” Brief for Petitioner 39, n. 4. As we explained in _Fischer_ v. _United States_, Section 1512(c)(2) covers acts that
impair “the availability or integrity for use in an official proceeding of
records, documents, objects, or . . . other things used in the proceeding.”
603 U. S. ___, ___ (2024) (slip op., at 16). If necessary, the District Court
should determine in the first instance whether the Section 1512(c)(2)
charges may proceed in light of our decision in _Fischer_ .


---

4 TRUMP _v._ UNITED STATES


Opinion of the Court


that “former Presidents do not possess absolute federal
criminal immunity for any acts committed while in office.”
2023 WL 8359833, *15 (DC, Dec. 1, 2023). The District
Court recognized that the President is immune from damages liability in civil cases, to protect against the chilling
effect such exposure might have on the carrying out of his
responsibilities. See _Nixon_ v. _Fitzgerald_, 457 U. S. 731,
749–756 (1982). But it reasoned that “the possibility of vexatious post-Presidency litigation is much reduced in the
criminal context” in light of “[t]he robust procedural safeguards attendant to federal criminal prosecutions.” 2023
WL 8359833, *9–*10. The District Court declined to decide
whether the indicted conduct involved official acts. See _id._,
at *15.

The D. C. Circuit affirmed. 91 F. 4th 1173 (2024) ( _per cu-_
_riam_ ). Citing _Marbury_ v. _Madison_, 1 Cranch 137 (1803),
the court distinguished between two kinds of official acts:
discretionary and ministerial. 91 F. 4th, at 1189–1190. It
observed that “although discretionary acts are ‘only politically examinable,’ the judiciary has the power to hear cases”
involving ministerial acts that an officer is directed to perform by the legislature. _Ibid._ (quoting _Marbury_, 1 Cranch,
at 166). From this distinction, the D. C. Circuit concluded
that the “separation of powers doctrine, as expounded in
_Marbury_ and its progeny, necessarily permits the Judiciary
to oversee the federal criminal prosecution of a former President for his official acts because the fact of the prosecution
means that the former President has allegedly acted in defiance of the Congress’s laws.” 91 F. 4th, at 1191. In the
court’s view, the fact that Trump’s actions “allegedly violated generally applicable criminal laws” meant that those
actions “were not properly within the scope of his lawful
discretion.” _Id._, at 1192. The D. C. Circuit thus concluded
that Trump had “no structural immunity from the charges
in the Indictment.” _Ibid._ Like the District Court, the D. C.


---

Cite as: 603 U. S. ____ (2024) 5


Opinion of the Court


Circuit declined to analyze the actions described in the indictment to determine whether they involved official acts.
See _id._, at 1205, n. 14.

We granted certiorari to consider the following question:
“Whether and if so to what extent does a former President
enjoy presidential immunity from criminal prosecution for
conduct alleged to involve official acts during his tenure in
office.” 601 U. S. ___ (2024).

II
This case is the first criminal prosecution in our Nation’s
history of a former President for actions taken during his
Presidency. We are called upon to consider whether and
under what circumstances such a prosecution may proceed. Doing so requires careful assessment of the scope of
Presidential power under the Constitution. We undertake
that responsibility conscious that we must not confuse “the
issue of a power’s validity with the cause it is invoked to
promote,” but must instead focus on the “enduring consequences upon the balanced power structure of our Republic.” _Youngstown Sheet & Tube Co._ v. _Sawyer_, 343 U. S. 579,
634 (1952) (Jackson, J., concurring).
The parties before us do not dispute that a former President can be subject to criminal prosecution for unofficial
acts committed while in office. See Tr. of Oral Arg. 28.
They also agree that some of the conduct described in the
indictment includes actions taken by Trump in his unofficial capacity. See _id_ ., at 28–30, 36–37, 124.
They disagree, however, about whether a former President can be prosecuted for his official actions. Trump contends that just as a President is absolutely immune from
civil damages liability for acts within the outer perimeter of
his official responsibilities, _Fitzgerald_, 457 U. S., at 756, he
must be absolutely immune from criminal prosecution for
such acts. Brief for Petitioner 10. And Trump argues that
the bulk of the indictment’s allegations involve conduct in


---

6 TRUMP _v._ UNITED STATES


Opinion of the Court


his official capacity as President. See Tr. of Oral Arg. 30–
32. Although the Government agrees that some official actions are included in the indictment’s allegations, see _id._, at
125, it maintains that a former President does not enjoy immunity from criminal prosecution for any actions, regardless of how they are characterized. See Brief for United
States 9.

We conclude that under our constitutional structure of
separated powers, the nature of Presidential power requires that a former President have some immunity from
criminal prosecution for official acts during his tenure in
office. At least with respect to the President’s exercise of
his core constitutional powers, this immunity must be absolute. As for his remaining official actions, he is also entitled to immunity. At the current stage of proceedings in
this case, however, we need not and do not decide whether
that immunity must be absolute, or instead whether a presumptive immunity is sufficient.

A
Article II of the Constitution provides that “[t]he executive Power shall be vested in a President of the United
States of America.” §1, cl. 1. The President’s duties are of
“unrivaled gravity and breadth.” _Trump_ v. _Vance_, 591 U. S.
786, 800 (2020). They include, for instance, commanding
the Armed Forces of the United States; granting reprieves
and pardons for offenses against the United States; and appointing public ministers and consuls, the Justices of this
Court, and Officers of the United States. See §2. He also
has important foreign relations responsibilities: making
treaties, appointing ambassadors, recognizing foreign governments, meeting foreign leaders, overseeing international diplomacy and intelligence gathering, and managing
matters related to terrorism, trade, and immigration. See
§§2, 3. Domestically, he must “take Care that the Laws be
faithfully executed,” §3, and he bears responsibility for the


---

Cite as: 603 U. S. ____ (2024) 7


Opinion of the Court


actions of the many departments and agencies within the
Executive Branch. He also plays a role in lawmaking by
recommending to Congress the measures he thinks wise
and signing or vetoing the bills Congress passes. See Art.
I, §7, cl. 2; Art. II, §3.

No matter the context, the President’s authority to act
necessarily “stem[s] either from an act of Congress or from
the Constitution itself.” _Youngstown_, 343 U. S., at 585. In
the latter case, the President’s authority is sometimes “conclusive and preclusive.” _Id._, at 638 (Jackson, J., concurring). When the President exercises such authority, he may
act even when the measures he takes are “incompatible
with the expressed or implied will of Congress.” _Id_ ., at 637.
The exclusive constitutional authority of the President “disabl[es] the Congress from acting upon the subject.” _Id._, at
637–638. And the courts have “no power to control [the
President’s] discretion” when he acts pursuant to the powers invested exclusively in him by the Constitution. _Mar-_
_bury_, 1 Cranch, at 166.

If the President claims authority to act but in fact exercises mere “individual will” and “authority without law,”
the courts may say so. _Youngstown_, 343 U. S., at 655 (Jackson, J., concurring). In _Youngstown_, for instance, we held
that President Truman exceeded his constitutional authority when he seized most of the Nation’s steel mills. See _id._,
at 582–589 (majority opinion). But once it is determined
that the President acted within the scope of his exclusive
authority, his discretion in exercising such authority cannot
be subject to further judicial examination.

The Constitution, for example, vests the “Power to Grant
Reprieves and Pardons for Offences against the United
States” in the President. Art. II, §2, cl. 1. During and after
the Civil War, President Lincoln offered a full pardon, with
restoration of property rights, to anyone who had “engaged
in the rebellion” but agreed to take an oath of allegiance to
the Union. _United States_ v. _Klein_, 13 Wall. 128, 139–141


---

8 TRUMP _v._ UNITED STATES


Opinion of the Court


(1872). But in 1870, Congress enacted a provision that prohibited using the President’s pardon as evidence of restoration of property rights. _Id._, at 143–144. Chief Justice
Chase held the provision unconstitutional because it “impair[ed] the effect of a pardon, and thus infring[ed] the constitutional power of the Executive.” _Id._, at 147. “To the
executive alone is intrusted the power of pardon,” and the
“legislature cannot change the effect of such a pardon any
more than the executive can change a law.” _Id._, at 147–148.
The President’s authority to pardon, in other words, is “conclusive and preclusive,” “disabling the Congress from acting
upon the subject.” _Youngstown_, 343 U. S., at 637–638
(Jackson, J., concurring).

Some of the President’s other constitutional powers also
fit that description. “The President’s power to remove—and
thus supervise—those who wield executive power on his behalf,” for instance, “follows from the text of Article II.” _Seila_
_Law LLC_ v. _Consumer Financial Protection Bureau_, 591
U. S. 197, 204 (2020). We have thus held that Congress
lacks authority to control the President’s “unrestricted
power of removal” with respect to “executive officers of the
United States whom he has appointed.” _Myers_ v. _United_
_States_, 272 U. S. 52, 106, 176 (1926); see _Youngstown_, 343
U. S., at 638, n. 4 (Jackson, J., concurring) (citing the President’s “exclusive power of removal in executive agencies”
as an example of “conclusive and preclusive” constitutional
authority); cf. _Seila Law_, 591 U. S., at 215 (noting only “two
exceptions to the President’s unrestricted removal power”).
The power “to control recognition determinations” of foreign
countries is likewise an “exclusive power of the President.”
_Zivotofsky_ v. _Kerry_, 576 U. S. 1, 32 (2015). Congressional
commands contrary to the President’s recognition determinations are thus invalid. _Ibid._

Congress cannot act on, and courts cannot examine, the
President’s actions on subjects within his “conclusive and
preclusive” constitutional authority. It follows that an Act


---

Cite as: 603 U. S. ____ (2024) 9


Opinion of the Court


of Congress—either a specific one targeted at the President
or a generally applicable one—may not criminalize the
President’s actions within his exclusive constitutional
power. Neither may the courts adjudicate a criminal prosecution that examines such Presidential actions. We thus
conclude that the President is absolutely immune from
criminal prosecution for conduct within his exclusive
sphere of constitutional authority.

B
But of course not all of the President’s official acts fall
within his “conclusive and preclusive” authority. As Justice
Robert Jackson recognized in _Youngstown_, the President
sometimes “acts pursuant to an express or implied authorization of Congress,” or in a “zone of twilight” where “he and
Congress may have concurrent authority.” 343 U. S., at
635, 637 (concurring opinion). The reasons that justify the
President’s absolute immunity from criminal prosecution
for acts within the scope of his exclusive authority therefore
do not extend to conduct in areas where his authority is
shared with Congress.
We recognize that only a limited number of our prior decisions guide determination of the President’s immunity in
this context. That is because proceedings directly involving
a President have been uncommon in our Nation, and “decisions of the Court in this area” have accordingly been “rare”
and “episodic.” _Dames & Moore_ v. _Regan_, 453 U. S. 654, 661
(1981). To resolve the matter, therefore, we look primarily
to the Framers’ design of the Presidency within the separation of powers, our precedent on Presidential immunity in
the civil context, and our criminal cases where a President
resisted prosecutorial demands for documents.

1
The President “occupies a unique position in the constitutional scheme,” _Fitzgerald_, 457 U. S., at 749, as “the only


---

10 TRUMP _v._ UNITED STATES


Opinion of the Court


person who alone composes a branch of government,”
_Trump_ v. _Mazars USA, LLP_, 591 U. S. 848, 868 (2020). The
Framers “sought to encourage energetic, vigorous, decisive,
and speedy execution of the laws by placing in the hands of
a single, constitutionally indispensable, individual the ultimate authority that, in respect to the other branches, the
Constitution divides among many.” _Clinton_ v. _Jones_, 520
U. S. 681, 712 (1997) (Breyer, J., concurring in judgment).
They “deemed an energetic executive essential to ‘the protection of the community against foreign attacks,’ ‘the
steady administration of the laws,’ ‘the protection of property,’ and ‘the security of liberty.’” _Seila Law_, 591 U. S., at
223–224 (quoting The Federalist No. 70, p. 471 (J. Cooke
ed. 1961) (A. Hamilton)). The purpose of a “vigorous” and
“energetic” Executive, they thought, was to ensure “good
government,” for a “feeble executive implies a feeble execution of the government.” _Id_ ., at 471–472.

The Framers accordingly vested the President with “supervisory and policy responsibilities of utmost discretion
and sensitivity.” _Fitzgerald_, 457 U. S., at 750. He must
make “the most sensitive and far-reaching decisions entrusted to any official under our constitutional system.” _Id._,
at 752. There accordingly “exists the greatest public interest” in providing the President with “‘the maximum ability
to deal fearlessly and impartially with’ the duties of his office.” _Ibid._ (quoting _Ferri_ v. _Ackerman_, 444 U. S. 193, 203
(1979)). Appreciating the “unique risks to the effective
functioning of government” that arise when the President’s
energies are diverted by proceedings that might render him
“unduly cautious in the discharge of his official duties,” we
have recognized Presidential immunities and privileges
“rooted in the constitutional tradition of the separation of
powers and supported by our history.” _Fitzgerald_, 457
U. S., at 749, 751, 752, n. 32.

In _Nixon_ v. _Fitzgerald_, for instance, we recognized that
as “a functionally mandated incident of [his] unique office,”


---

Cite as: 603 U. S. ____ (2024) 11


Opinion of the Court


a former President “is entitled to absolute immunity from
damages liability predicated on his official acts.” _Id_ ., at
749. That case involved a terminated Air Force employee
who sued former President Richard Nixon for damages, alleging that Nixon approved an Air Force reorganization
that wrongfully led to his firing. In holding that Nixon was
immune from that suit, “our dominant concern” was to
avoid “diversion of the President’s attention during the decisionmaking process caused by needless worry as to the
possibility of damages actions stemming from any particular official decision.” _Clinton_, 520 U. S., at 694, n. 19.
“[T]he singular importance of the President’s duties” implicating “matters likely to ‘arouse the most intense feelings,’”
coupled with “the sheer prominence of [his] office,” heightens the prospect of private damages suits that would
threaten such diversion. _Fitzgerald_, 457 U. S., at 751–753
(quoting _Pierson_ v. _Ray_, 386 U. S. 547, 554 (1967)). We
therefore concluded that the President must be absolutely
immune from “damages liability for acts within the ‘outer
perimeter’ of his official responsibility.” _Fitzgerald_, 457
U. S., at 756.

By contrast, when prosecutors have sought evidence from
the President, we have consistently rejected Presidential
claims of absolute immunity. For instance, during the treason trial of former Vice President Aaron Burr, Chief Justice
Marshall rejected President Thomas Jefferson’s claim that
the President could not be subjected to a subpoena. Marshall reasoned that “the law does not discriminate between
the president and a private citizen.” _United States_ v. _Burr_,
25 F. Cas. 30, 34 (No. 14,692d) (CC Va. 1807) ( _Burr I_ ). Because a President does not “stand exempt from the general
provisions of the constitution,” including the Sixth Amendment’s guarantee that those accused shall have compulsory
process for obtaining witnesses for their defense, a subpoena could issue. _Id._, at 33–34.

Marshall acknowledged, however, the existence of a


---

12 TRUMP _v._ UNITED STATES


Opinion of the Court


“privilege” to withhold certain “official paper[s]” that “ought
not on light ground to be forced into public view.” _United_
_States_ v. _Burr_, 25 F. Cas. 187, 192 (No. 14,694) (CC Va.
1807) ( _Burr II_ ); see also _Burr I_, 25 F. Cas., at 37 (stating
that nothing before the court showed that the document in
question “contain[ed] any matter the disclosure of which
would endanger the public safety”). And he noted that a
court may not “be required to proceed against the president
as against an ordinary individual.” _Burr II_, 25 F. Cas., at
192.

Similarly, when a subpoena issued to President Nixon to
produce certain tape recordings and documents relating to
his conversations with aides and advisers, this Court rejected his claim of “absolute privilege,” given the “constitutional duty of the Judicial Branch to do justice in criminal
prosecutions.” _United States_ v. _Nixon_, 418 U. S. 683, 703,
707 (1974). But we simultaneously recognized “the public
interest in candid, objective, and even blunt or harsh opinions in Presidential decisionmaking,” as well as the need to
protect “communications between high Government officials and those who advise and assist them in the performance of their manifold duties.” _Id_ ., at 705, 708. Because
the President’s “need for complete candor and objectivity
from advisers calls for great deference from the courts,” we
held that a “presumptive privilege” protects Presidential
communications. _Id_ ., at 706, 708. That privilege, we explained, “relates to the effective discharge of a President’s
powers.” _Id._, at 711. We thus deemed it “fundamental to
the operation of Government and inextricably rooted in the
separation of powers under the Constitution.” _Id_ ., at 708.

2
Criminally prosecuting a President for official conduct
undoubtedly poses a far greater threat of intrusion on the
authority and functions of the Executive Branch than
simply seeking evidence in his possession, as in _Burr_ and


---

Cite as: 603 U. S. ____ (2024) 13


Opinion of the Court


_Nixon_ . The danger is akin to, indeed greater than, what led
us to recognize absolute Presidential immunity from civil
damages liability—that the President would be chilled from
taking the “bold and unhesitating action” required of an independent Executive. _Fitzgerald_, 457 U. S., at 745. Although the President might be exposed to fewer criminal
prosecutions than the range of civil damages suits that
might be brought by various plaintiffs, the threat of trial,
judgment, and imprisonment is a far greater deterrent. Potential criminal liability, and the peculiar public opprobrium that attaches to criminal proceedings, are plainly
more likely to distort Presidential decisionmaking than the
potential payment of civil damages.

The hesitation to execute the duties of his office fearlessly
and fairly that might result when a President is making decisions under “a pall of potential prosecution,” _McDonnell_ v.
_United States_, 579 U. S. 550, 575 (2016), raises “unique
risks to the effective functioning of government,” _Fitzger-_
_ald_, 457 U. S., at 751. A President inclined to take one
course of action based on the public interest may instead
opt for another, apprehensive that criminal penalties may
befall him upon his departure from office. And if a former
President’s official acts are routinely subjected to scrutiny
in criminal prosecutions, “the independence of the Executive Branch” may be significantly undermined. _Vance_, 591
U. S., at 800. The Framers’ design of the Presidency did not
envision such counterproductive burdens on the “vigor[]”
and “energy” of the Executive. The Federalist No. 70, at
471–472.

We must, however, “recognize[] the countervailing interests at stake.” _Vance_, 591 U. S., at 799. Federal criminal
laws seek to redress “a wrong to the public” as a whole, not
just “a wrong to the individual.” _Huntington_ v. _Attrill_, 146
U. S. 657, 668 (1892). There is therefore a compelling “public interest in fair and effective law enforcement.” _Vance_,
591 U. S., at 808. The President, charged with enforcing


---

14 TRUMP _v._ UNITED STATES


Opinion of the Court


federal criminal laws, is not above them.

Chief Justice Marshall’s decisions in _Burr_ and our decision in _Nixon_ recognized the distinct interests present in
criminal prosecutions. Although _Burr_ acknowledged that
the President’s official papers may be privileged and publicly unavailable, it did not grant him an absolute exemption from responding to subpoenas. See _Burr II_, 25 F. Cas.,
at 192; _Burr I_, 25 F. Cas., at 33–34. _Nixon_ likewise recognized a strong protection for the President’s confidential
communications—a “presumptive privilege”—but it did not
entirely exempt him from providing evidence in criminal
proceedings. 418 U. S., at 708.

Taking into account these competing considerations, we
conclude that the separation of powers principles explicated
in our precedent necessitate at least a _presumptive_ immunity from criminal prosecution for a President’s acts within
the outer perimeter of his official responsibility. Such an
immunity is required to safeguard the independence and
effective functioning of the Executive Branch, and to enable
the President to carry out his constitutional duties without
undue caution. Indeed, if presumptive protection for the
President is necessary to enable the “effective discharge” of
his powers when a prosecutor merely seeks evidence of his
official papers and communications, _id._, at 711, it is certainly necessary when the prosecutor seeks to charge, try,
and imprison the President himself for his official actions.
At a minimum, the President must therefore be immune
from prosecution for an official act unless the Government
can show that applying a criminal prohibition to that act
would pose no “dangers of intrusion on the authority and
functions of the Executive Branch.” _Fitzgerald_, 457 U. S.,
at 754.

But as we explain below, the current stage of the proceedings in this case does not require us to decide whether this
immunity is presumptive or absolute. See Part III–B, _infra_ .
Because we need not decide that question today, we do not


---

Cite as: 603 U. S. ____ (2024) 15


Opinion of the Court


decide it. “[O]ne case” in more than “two centuries does not
afford enough experience” to definitively and comprehensively determine the President’s scope of immunity from
criminal prosecution. _Mazars_, 591 U. S., at 871.

C
As for a President’s unofficial acts, there is no immunity.
The principles we set out in _Clinton_ v. _Jones_ confirm as
much. When Paula Jones brought a civil lawsuit against
then-President Bill Clinton for acts he allegedly committed
prior to his Presidency, we rejected his argument that he
enjoyed temporary immunity from the lawsuit while serving as President. 520 U. S., at 684. Although Presidential
immunity is required for _official_ actions to ensure that the
President’s decisionmaking is not distorted by the threat of
future litigation stemming from those actions, that concern
does not support immunity for _unofficial_ conduct. _Id._, at
694, and n. 19. The “‘justifying purposes’” of the immunity
we recognized in _Fitzgerald_, and the one we recognize today, are not that the President must be immune because he
is the President; rather, they are to ensure that the President can undertake his constitutionally designated functions effectively, free from undue pressures or distortions.
520 U. S., at 694, and n. 19 (quoting _Fitzgerald_, 457 U. S.,
at 755). “[I]t [is] the nature of the function performed, not
the identity of the actor who perform[s] it, that inform[s]
our immunity analysis.” _Forrester_ v. _White_, 484 U. S. 219,
229 (1988). The separation of powers does not bar a prosecution predicated on the President’s unofficial acts. [2 ]


——————

2 Our decision in _Clinton_ permitted claims alleging unofficial acts to
proceed against the sitting President. See 520 U. S., at 684. In the criminal context, however, the Justice Department “has long recognized” that
“the separation of powers precludes the criminal prosecution of a sitting
President.” Brief for United States 9 (citing A Sitting President’s Amenability to Indictment and Criminal Prosecution, 24 Op. OLC 222 (2000);
emphasis deleted); see Tr. for Oral Arg. 78.


---

16 TRUMP _v._ UNITED STATES


Opinion of the Court


III
Determining whether a former President is entitled to
immunity from a particular prosecution requires applying
the principles we have laid out to his conduct at issue. The
first step is to distinguish his official from unofficial actions.
In this case, however, no court has thus far considered how
to draw that distinction, in general or with respect to the
conduct alleged in particular.

Despite the unprecedented nature of this case, and the
very significant constitutional questions that it raises, the
lower courts rendered their decisions on a highly expedited
basis. Because those courts categorically rejected _any_ form
of Presidential immunity, they did not analyze the conduct
alleged in the indictment to decide which of it should be categorized as official and which unofficial. Neither party has
briefed that issue before us (though they discussed it at oral
argument in response to questions). And like the underlying immunity question, that categorization raises multiple
unprecedented and momentous questions about the powers
of the President and the limits of his authority under the
Constitution. As we have noted, there is little pertinent
precedent on those subjects to guide our review of this
case—a case that we too are deciding on an expedited basis,
less than five months after we granted the Government’s
request to construe Trump’s emergency application for a
stay as a petition for certiorari, grant that petition, and answer the consequential immunity question. See 601 U. S.,
at ___. Given all these circumstances, it is particularly incumbent upon us to be mindful of our frequent admonition
that “[o]urs is a court of final review and not first view.”
_Zivotofsky_ v. _Clinton_, 566 U. S. 189, 201 (2012) (internal
quotation marks omitted).

Critical threshold issues in this case are how to differentiate between a President’s official and unofficial actions,
and how to do so with respect to the indictment’s extensive
and detailed allegations covering a broad range of conduct.


---

Cite as: 603 U. S. ____ (2024) 17


Opinion of the Court


We offer guidance on those issues below. Certain allegations—such as those involving Trump’s discussions with
the Acting Attorney General—are readily categorized in
light of the nature of the President’s official relationship to
the office held by that individual. Other allegations—such
as those involving Trump’s interactions with the Vice President, state officials, and certain private parties, and his
comments to the general public—present more difficult
questions. Although we identify several considerations pertinent to classifying those allegations and determining
whether they are subject to immunity, that analysis ultimately is best left to the lower courts to perform in the first
instance.

A
Distinguishing the President’s official actions from his
unofficial ones can be difficult. When the President acts
pursuant to “constitutional and statutory authority,” he
takes official action to perform the functions of his office.
_Fitzgerald_, 457 U. S., at 757. Determining whether an action is covered by immunity thus begins with assessing the
President’s authority to take that action.
But the breadth of the President’s “discretionary responsibilities” under the Constitution and laws of the United
States “in a broad variety of areas, many of them highly
sensitive,” frequently makes it “difficult to determine which
of [his] innumerable ‘functions’ encompassed a particular
action.” _Id_ ., at 756. And some Presidential conduct—for
example, speaking to and on behalf of the American people,
see _Trump_ v. _Hawaii_, 585 U. S. 667, 701 (2018)—certainly
can qualify as official even when not obviously connected to
a particular constitutional or statutory provision. For those
reasons, the immunity we have recognized extends to the
“outer perimeter” of the President’s official responsibilities,
covering actions so long as they are “not manifestly or palpably beyond [his] authority.” _Blassingame_ v. _Trump_, 87


---

18 TRUMP _v._ UNITED STATES


Opinion of the Court


F. 4th 1, 13 (CADC 2023) (internal quotation marks omitted); see _Fitzgerald_, 457 U. S., at 755–756 (noting that we
have “refused to draw functional lines finer than history
and reason would support”).

In dividing official from unofficial conduct, courts may
not inquire into the President’s motives. Such an inquiry
would risk exposing even the most obvious instances of official conduct to judicial examination on the mere allegation
of improper purpose, thereby intruding on the Article II interests that immunity seeks to protect. Indeed, “[i]t would
seriously cripple the proper and effective administration of
public affairs as entrusted to the executive branch of the
government” if “[i]n exercising the functions of his office,”
the President was “under an apprehension that the motives
that control his official conduct may, at any time, become
the subject of inquiry.” _Fitzgerald_, 457 U. S., at 745 (quoting _Spalding_ v. _Vilas_, 161 U. S. 483, 498 (1896)). We thus
rejected such inquiries in _Fitzgerald_ . The plaintiff there
contended that he was dismissed from the Air Force for retaliatory reasons. See 457 U. S., at 733–741, 756. The Air
Force responded that the reorganization that led to Fitzgerald’s dismissal was undertaken to promote efficiency. _Ibid._
Because under Fitzgerald’s theory “an inquiry into the
President’s motives could not be avoided,” we rejected the
theory, observing that “[i]nquiries of this kind could be
highly intrusive.” _Id._, at 756. “[B]are allegations of malice
should not suffice to subject government officials either to
the costs of trial or to the burdens of broad-reaching discovery.” _Harlow_ v. _Fitzgerald_, 457 U. S. 800, 817–818 (1982).

Nor may courts deem an action unofficial merely because
it allegedly violates a generally applicable law. For instance, when Fitzgerald contended that his dismissal violated various congressional statutes and thus rendered his
discharge “outside the outer perimeter of [Nixon’s] duties,”
we rejected that contention. 457 U. S., at 756 _._ Otherwise,
Presidents would be subject to trial on “every allegation


---

Cite as: 603 U. S. ____ (2024) 19


Opinion of the Court


that an action was unlawful,” depriving immunity of its intended effect. _Ibid._

B
With these principles in mind, we turn to the conduct alleged in the indictment.

1
The indictment broadly alleges that Trump and his coconspirators sought to “overturn the legitimate results of
the 2020 presidential election.” App. 183, Indictment ¶7.
It charges that they conspired to obstruct the January 6
congressional proceeding at which electoral votes are
counted and certified, and the winner of the election is certified as President-elect. _Id_ ., at 181–185, ¶¶4, 7, 9. As part
of this conspiracy, Trump and his co-conspirators allegedly
attempted to leverage the Justice Department’s power and
authority to convince certain States to replace their legitimate electors with Trump’s fraudulent slates of electors.
See _id_ ., at 215–220, ¶¶70–85. According to the indictment,
Trump met with the Acting Attorney General and other
senior Justice Department and White House officials to discuss investigating purported election fraud and sending a
letter from the Department to those States regarding such
fraud. See, _e.g._, _id._, at 217, 219–220, ¶¶77, 84. The indictment further alleges that after the Acting Attorney General
resisted Trump’s requests, Trump repeatedly threatened to
replace him. See, _e.g._, _id_ ., at 216–217, ¶¶74, 77.
The Government does not dispute that the indictment’s
allegations regarding the Justice Department involve
Trump’s “use of official power.” Brief for United States 46;
see _id._, at 10–11; Tr. of Oral Arg. 125. The allegations in
fact plainly implicate Trump’s “conclusive and preclusive”
authority. “[I]nvestigation and prosecution of crimes is a
quintessentially executive function.” Brief for United
States 19 (quoting _Morrison_ v. _Olson_, 487 U. S. 654, 706


---

20 TRUMP _v._ UNITED STATES


Opinion of the Court


(1988) (Scalia, J., dissenting)). And the Executive Branch
has “exclusive authority and absolute discretion” to decide
which crimes to investigate and prosecute, including with
respect to allegations of election crime. _Nixon_, 418 U. S., at
693; see _United States_ v. _Texas_, 599 U. S. 670, 678–679
(2023) (“Under Article II, the Executive Branch possesses
authority to decide ‘how to prioritize and how aggressively
to pursue legal actions against defendants who violate the
law.’” (quoting _TransUnion LLC_ v. _Ramirez_, 594 U. S. 413,
429 (2021))). The President may discuss potential investigations and prosecutions with his Attorney General and
other Justice Department officials to carry out his constitutional duty to “take Care that the Laws be faithfully executed.” Art. II, §3. And the Attorney General, as head of
the Justice Department, acts as the President’s “chief law
enforcement officer” who “provides vital assistance to [him]
in the performance of [his] constitutional duty to ‘preserve,
protect, and defend the Constitution.’” _Mitchell_ v. _Forsyth_,
472 U. S. 511, 520 (1985) (quoting Art. II, §1, cl. 8).

Investigative and prosecutorial decisionmaking is “the
special province of the Executive Branch,” _Heckler_ v.
_Chaney_, 470 U. S. 821, 832 (1985), and the Constitution
vests the entirety of the executive power in the President,
Art. II, §1. For that reason, Trump’s threatened removal of
the Acting Attorney General likewise implicates “conclusive and preclusive” Presidential authority. As we have explained, the President’s power to remove “executive officers
of the United States whom he has appointed” may not be
regulated by Congress or reviewed by the courts. _Myers_,
272 U. S., at 106, 176; see _supra_, at 8. The President’s
“management of the Executive Branch” requires him to
have “unrestricted power to remove the most important of
his subordinates”—such as the Attorney General—“in their
most important duties.” _Fitzgerald_, 457 U. S., at 750 (internal quotation marks and alteration omitted).


---

Cite as: 603 U. S. ____ (2024) 21


Opinion of the Court


The indictment’s allegations that the requested investigations were “sham[s]” or proposed for an improper purpose
do not divest the President of exclusive authority over the
investigative and prosecutorial functions of the Justice Department and its officials. App. 186–187, Indictment
¶10(c). And the President cannot be prosecuted for conduct
within his exclusive constitutional authority. Trump is
therefore absolutely immune from prosecution for the alleged conduct involving his discussions with Justice Department officials.

2
The indictment next alleges that Trump and his coconspirators “attempted to enlist the Vice President to use
his ceremonial role at the January 6 certification proceeding to fraudulently alter the election results.” _Id_ ., at 187,
¶10(d). In particular, the indictment alleges several conversations in which Trump pressured the Vice President to
reject States’ legitimate electoral votes or send them back
to state legislatures for review. See, _e.g._, _id_ ., at 222–224,
226, ¶¶90, 92–93, 97.
The Government explained at oral argument that although it “has not yet had to come to grips with how [it]
would analyze” Trump’s interactions with the Vice President, there is “support” to characterize that conduct as official. Tr. of Oral Arg. 128. Indeed, our constitutional system
anticipates that the President and Vice President will remain in close contact regarding their official duties over the
course of the President’s term in office. These two officials
are the only ones “elected by the entire Nation.” _Seila Law_,
591 U. S., at 224; see Art. II, §1. The Constitution provides
that “the Vice President shall become President” in the case
of “the removal of the President from office or of his death
or resignation.” Amdt. 25, §1. It also “empowers the Vice
President, together with a majority of the ‘principal officers


---

22 TRUMP _v._ UNITED STATES


Opinion of the Court


of the executive departments,’ to declare the President ‘unable to discharge the powers and duties of his office.’” _Frey-_
_tag_ v. _Commissioner_, 501 U. S. 868, 886–887 (1991) (quoting Amdt. 25, §4). And Article I of course names the Vice
President as President of the Senate and gives him a tiebreaking vote. §3, cl. 4. It is thus important for the President to discuss official matters with the Vice President to
ensure continuity within the Executive Branch and to advance the President’s agenda in Congress and beyond.

The Vice President may in practice also serve as one of
the President’s closest advisers. The Office of Legal Counsel has explained that within the Executive Branch, the
Vice President’s “sole function [is] advising and assisting
the President.” Whether the Office of the Vice President Is
an ‘Agency’ for Purposes of the Freedom of Information Act,
18 Op. OLC 10 (1994). Indeed, the “Twelfth Amendment
was brought about” to avoid the “manifestly intolerable” situation that occurred “[d]uring the John Adams administration,” when “we had a President and Vice-President of different parties.” _Ray_ v. _Blair_, 343 U. S. 214, 224, n. 11
(1952). The President and Vice President together “are the
senior officials of the Executive Branch of government” and
therefore “must formulate, explain, advocate, and defend
policies” of the President’s administration. Payment of Expenses Associated With Travel by the President and Vice
President, 6 Op. OLC 214, 215 (1982).

As the President’s second in command, the Vice President
has historically performed important functions “at the will
and as the representative of the President.” Participation
of the Vice President in the Affairs of the Executive Branch,
1 Supp. Op. OLC 214, 220 (1961). President Woodrow Wilson’s Vice President, for instance, “presided over a few cabinet meetings while Wilson was in France negotiating” the
Treaty of Versailles after World War I. H. Relyea, The Law:
The Executive Office of the Vice President: Constitutional
and Legal Considerations, 40 Presidential Studies Q. 327,


---

Cite as: 603 U. S. ____ (2024) 23


Opinion of the Court


328 (2010). During President Franklin Roosevelt’s administration, the Vice President “became a regular participant
in cabinet deliberations—a practice that was continued by
each succeeding president.” _Ibid._ And when President
Dwight Eisenhower “suffered three major illnesses while in
office . . . Vice President Richard Nixon consulted with the
Cabinet and developed a procedure for relaying important
matters to the President.” Presidential Succession and Delegation in Case of Disability, 5 Op. OLC 91, 102 (1981). At
the President’s discretion, “the Vice President may engage
in activities ranging into the highest levels of diplomacy
and negotiation and may do so anywhere in the world.” 1
Supp. Op. OLC, at 220. Domestically, he may act as the
President’s delegate to perform any duties “co-extensive
with the scope of the President’s power of delegation.” _Ibid._

Whenever the President and Vice President discuss their
official responsibilities, they engage in official conduct. Presiding over the January 6 certification proceeding at which
Members of Congress count the electoral votes is a constitutional and statutory duty of the Vice President. Art. II,
§1, cl. 3; Amdt. 12; 3 U. S. C. §15. The indictment’s allegations that Trump attempted to pressure the Vice President
to take particular acts in connection with his role at the certification proceeding thus involve official conduct, and
Trump is at least presumptively immune from prosecution
for such conduct.

The question then becomes whether that presumption of
immunity is rebutted under the circumstances. When the
Vice President presides over the January 6 certification
proceeding, he does so in his capacity as President of the
Senate. _Ibid._ Despite the Vice President’s expansive role
of advising and assisting the President within the Executive Branch, the Vice President’s Article I responsibility of
“presiding over the Senate” is “not an ‘executive branch’
function.” Memorandum from L. Silberman, Deputy Atty.
Gen., to R. Burress, Office of the President, Re: Conflict of


---

24 TRUMP _v._ UNITED STATES


Opinion of the Court


Interest Problems Arising Out of the President’s Nomination of Nelson A. Rockefeller To Be Vice President Under
the Twenty-Fifth Amendment to the Constitution 2 (Aug.
28, 1974). With respect to the certification proceeding in
particular, Congress has legislated extensively to define the
Vice President’s role in the counting of the electoral votes,
see, _e.g._, 3 U. S. C. §15, and the President plays no direct
constitutional or statutory role in that process. So the Government may argue that consideration of the President’s
communications with the Vice President concerning the
certification proceeding does not pose “dangers of intrusion
on the authority and functions of the Executive Branch.”
_Fitzgerald_, 457 U. S., at 754; see _supra_, at 14.

At the same time, however, the President may frequently
rely on the Vice President in his capacity as President of the
Senate to advance the President’s agenda in Congress.
When the Senate is closely divided, for instance, the Vice
President’s tiebreaking vote may be crucial for confirming
the President’s nominees and passing laws that align with
the President’s policies. Applying a criminal prohibition to
the President’s conversations discussing such matters with
the Vice President—even though they concern his role as
President of the Senate—may well hinder the President’s
ability to perform his constitutional functions.

It is ultimately the Government’s burden to rebut the
presumption of immunity. We therefore remand to the District Court to assess in the first instance, with appropriate
input from the parties, whether a prosecution involving
Trump’s alleged attempts to influence the Vice President’s
oversight of the certification proceeding in his capacity as
President of the Senate would pose any dangers of intrusion
on the authority and functions of the Executive Branch.

3
The indictment’s remaining allegations cover a broad
range of conduct. Unlike the allegations describing


---

Cite as: 603 U. S. ____ (2024) 25


Opinion of the Court


Trump’s communications with the Justice Department and
the Vice President, these remaining allegations involve
Trump’s interactions with persons outside the Executive
Branch: state officials, private parties, and the general public. Many of the remaining allegations, for instance, cover
at great length events arising out of communications that
Trump and his co-conspirators initiated with state legislators and election officials in Arizona, Georgia, Michigan,
Pennsylvania, and Wisconsin regarding those States’ certification of electors. See App. 192–207, Indictment ¶¶13–
52.

Specifically, the indictment alleges that Trump and his
co-conspirators attempted to convince those officials that
election fraud had tainted the popular vote count in their
States, and thus electoral votes for Trump’s opponent
needed to be changed to electoral votes for Trump. See _id_ .,
at 185–186, ¶10(a). After Trump failed to convince those
officials to alter their state processes, he and his co-conspirators
allegedly developed a plan “to marshal individuals who
would have served as [Trump’s] electors, had he won the
popular vote” in Arizona, Georgia, Michigan, Nevada, New
Mexico, Pennsylvania, and Wisconsin, “and cause those individuals to make and send to the Vice President and Congress false certifications that they were legitimate electors.”
_Id_ ., at 208, ¶53. If the plan worked, “the submission of
these fraudulent slates” would position the Vice President
to “open and count the fraudulent votes” at the certification
proceeding and set up “a fake controversy that would derail
the proper certification of Biden as president-elect.” _Id_ ., at
208–209, ¶¶53, 54(b). According to the indictment, Trump
used his campaign staff to effectuate the plan. See, _e.g._, _id_ .,
at 210, 212–213, ¶¶55, 63. On the same day that the legitimate electors met in their respective jurisdictions to cast
their votes, the indictment alleges that Trump’s “fraudulent electors convened sham proceedings in the seven tar


---

26 TRUMP _v._ UNITED STATES


Opinion of the Court


geted states to cast fraudulent electoral ballots” in his favor. _Id_ ., at 214, ¶66. Those ballots “were mailed to the
President of the Senate, the Archivist of the United States,
and others.” _Ibid_ ., ¶67.

At oral argument, Trump appeared to concede that at
least some of these acts—those involving “private actors”
who “helped implement a plan to submit fraudulent slates
of presidential electors to obstruct the certification proceeding” at the direction of Trump and a co-conspirator—entail
“private” conduct. Tr. of Oral Arg. 29–30. He later asserted, however, that asking “the chairwoman of the Republican National Committee . . . to gather electors” qualifies
as official conduct because “the organization of alternate
slates of electors is based on, for example, the historical example of President Grant as something that was done pursuant to and ancillary and preparatory to the exercise of ” a
core Presidential power. _Id._, at 37; see also _id._, at 25 (discussing the “historical precedent . . . of President Grant
sending federal troops to Louisiana and Mississippi in 1876
to make sure that the Republican electors got certified in
those two cases, which delivered the election to Rutherford
B. Hayes”). He also argued that it is “[a]bsolutely an official
act for the president to communicate with state officials on
. . . the integrity of a federal election.” _Id._, at 38. The Government disagreed, contending that this alleged conduct
does not qualify as “official conduct” but as “campaign conduct.” _Id._, at 124–125.

On Trump’s view, the alleged conduct qualifies as official
because it was undertaken to ensure the integrity and
proper administration of the federal election. Of course, the
President’s duty to “take Care that the Laws be faithfully
executed” plainly encompasses enforcement of federal election laws passed by Congress. Art. II, §3. And the President’s broad power to speak on matters of public concern
does not exclude his public communications regarding the
fairness and integrity of federal elections simply because he


---

Cite as: 603 U. S. ____ (2024) 27


Opinion of the Court


is running for re-election. Cf. _Hawaii_, 585 U. S., at 701.
Similarly, the President may speak on and discuss such
matters with state officials—even when no specific federal
responsibility requires his communication—to encourage
them to act in a manner that promotes the President’s view
of the public good.

As the Government sees it, however, these allegations encompass nothing more than Trump’s “private scheme with
private actors.” Brief for United States 44. In its view,
Trump can point to no plausible source of authority enabling the President to not only organize alternate slates of
electors but also cause those electors—unapproved by any
state official—to transmit votes to the President of the Senate for counting at the certification proceeding, thus interfering with the votes of States’ properly appointed electors.
Indeed, the Constitution commits to the States the power
to “appoint” Presidential electors “in such Manner as the
Legislature thereof may direct.” Art. II, §1, cl. 2; see _Bur-_
_roughs_ v. _United States_, 290 U. S. 534, 544 (1934). “Article
II, §1’s appointments power,” we have said, “gives the
States far-reaching authority over presidential electors, absent some other constitutional constraint.” _Chiafalo_ v.
_Washington_, 591 U. S. 578, 588–589 (2020). By contrast,
the Federal Government’s role in appointing electors is limited. Congress may prescribe when the state-appointed
electors shall meet, and it counts and certifies their votes.
Art. II, §1, cls. 3, 4. The President, meanwhile, plays no
direct role in the process, nor does he have authority to control the state officials who do. And the Framers, wary of
“cabal, intrigue and corruption,” specifically excluded from
service as electors “all those who from situation might be
suspected of too great devotion to the president in office.”
The Federalist No. 68, at 459 (A. Hamilton); see Art. II, §1,
cl. 2.

Determining whose characterization may be correct, and
with respect to which conduct, requires a close analysis of


---

28 TRUMP _v._ UNITED STATES


Opinion of the Court


the indictment’s extensive and interrelated allegations.
See App. 192–215, Indictment ¶¶13–69. Unlike Trump’s
alleged interactions with the Justice Department, this alleged conduct cannot be neatly categorized as falling within
a particular Presidential function. The necessary analysis
is instead fact specific, requiring assessment of numerous
alleged interactions with a wide variety of state officials
and private persons. And the parties’ brief comments at
oral argument indicate that they starkly disagree on the
characterization of these allegations. The concerns we
noted at the outset—the expedition of this case, the lack of
factual analysis by the lower courts, and the absence of pertinent briefing by the parties—thus become more prominent. We accordingly remand to the District Court to determine in the first instance—with the benefit of briefing
we lack—whether Trump’s conduct in this area qualifies as
official or unofficial.

4
Finally, the indictment contains various allegations regarding Trump’s conduct in connection with the events of
January 6 itself. It alleges that leading up to the January
6 certification proceeding, Trump issued a series of Tweets
(to his nearly 89 million followers) encouraging his supporters to travel to Washington, D. C., on that day. See, _e.g._,
App. 221, 225–227, Indictment ¶¶87–88, 96, 100. Trump
and his co-conspirators addressed the gathered public that
morning, asserting that certain States wanted to recertify
their electoral votes and that the Vice President had the
power to send those States’ ballots back for recertification.
_Id._, at 228–230, ¶¶103–104. Trump then allegedly “directed the crowd in front of him to go to the Capitol” to pressure the Vice President to do so at the certification proceeding. _Id._, at 228–230, ¶104. When it became public that the
Vice President would not use his role at the certification
proceeding to determine which electoral votes should be


---

Cite as: 603 U. S. ____ (2024) 29


Opinion of the Court


counted, the crowd gathered at the Capitol “broke through
barriers cordoning off the Capitol grounds” and eventually
“broke into the building.” _Id_ ., at 230–231, ¶¶107, 109.

The alleged conduct largely consists of Trump’s communications in the form of Tweets and a public address. The
President possesses “extraordinary power to speak to his
fellow citizens and on their behalf.” _Hawaii_, 585 U. S., at
701; cf. _Lindke_ v. _Freed_, 601 U. S. 187, 191 (2024). As the
sole person charged by the Constitution with executing the
laws of the United States, the President oversees—and thus
will frequently speak publicly about—a vast array of activities that touch on nearly every aspect of American life. Indeed, a long-recognized aspect of Presidential power is using the office’s “bully pulpit” to persuade Americans,
including by speaking forcefully or critically, in ways that
the President believes would advance the public interest.
He is even expected to comment on those matters of public
concern that may not directly implicate the activities of the
Federal Government—for instance, to comfort the Nation
in the wake of an emergency or tragedy. For these reasons,
most of a President’s public communications are likely to
fall comfortably within the outer perimeter of his official responsibilities.

There may, however, be contexts in which the President,
notwithstanding the prominence of his position, speaks in
an unofficial capacity—perhaps as a candidate for office or
party leader. To the extent that may be the case, objective
analysis of “content, form, and context” will necessarily inform the inquiry. _Snyder_ v. _Phelps_, 562 U. S. 443, 453
(2011) (internal quotation marks omitted). But “there is not
always a clear line between [the President’s] personal and
official affairs.” _Mazars_, 591 U. S., at 868. The analysis
therefore must be fact specific and may prove to be challenging.

The indictment reflects these challenges. It includes only


---

30 TRUMP _v._ UNITED STATES


Opinion of the Court


select Tweets and brief snippets of the speech Trump delivered on the morning of January 6, omitting its full text or
context. See App. 228–230, Indictment ¶104. Whether the
Tweets, that speech, and Trump’s other communications on
January 6 involve official conduct may depend on the content and context of each. Knowing, for instance, what else
was said contemporaneous to the excerpted communications, or who was involved in transmitting the electronic
communications and in organizing the rally, could be relevant to the classification of each communication. This necessarily factbound analysis is best performed initially by
the District Court. We therefore remand to the District
Court to determine in the first instance whether this alleged conduct is official or unofficial.

C
The essence of immunity “is its possessor’s entitlement
not to have to answer for his conduct” in court. _Mitchell_,
472 U. S., at 525. Presidents therefore cannot be indicted
based on conduct for which they are immune from prosecution. As we have explained, the indictment here alleges at
least some such conduct. See Part III–B–1, _supra_ . On remand, the District Court must carefully analyze the indictment’s remaining allegations to determine whether they too
involve conduct for which a President must be immune from
prosecution. And the parties and the District Court must
ensure that sufficient allegations support the indictment’s
charges without such conduct.
The Government does not dispute that if Trump is entitled to immunity for certain official acts, he may not “be
held criminally liable” based on those acts. Brief for United
States 46. But it nevertheless contends that a jury could
“consider” evidence concerning the President’s official acts
“for limited and specified purposes,” and that such evidence
would “be admissible to prove, for example, [Trump’s]
knowledge or notice of the falsity of his election-fraud


---

Cite as: 603 U. S. ____ (2024) 31


Opinion of the Court


claims.” _Id._, at 46, 48. That proposal threatens to eviscerate the immunity we have recognized. It would permit a
prosecutor to do indirectly what he cannot do directly—invite the jury to examine acts for which a President is immune from prosecution to nonetheless prove his liability on
any charge. But “[t]he Constitution deals with substance,
not shadows.” _Cummings_ v. _Missouri_, 4 Wall. 277, 325
(1867). And the Government’s position is untenable in light
of the separation of powers principles we have outlined.

If official conduct for which the President is immune may
be scrutinized to help secure his conviction, even on charges
that purport to be based only on his unofficial conduct, the
“intended effect” of immunity would be defeated. _Fitzger-_
_ald_, 457 U. S., at 756. The President’s immune conduct
would be subject to examination by a jury on the basis of
generally applicable criminal laws. Use of evidence about
such conduct, even when an indictment alleges only unofficial conduct, would thereby heighten the prospect that the
President’s official decisionmaking will be distorted. See
_Clinton_, 520 U. S., at 694, n. 19.

The Government asserts that these weighty concerns can
be managed by the District Court through the use of “evidentiary rulings” and “jury instructions.” Brief for United
States 46. But such tools are unlikely to protect adequately
the President’s constitutional prerogatives. Presidential
acts frequently deal with “matters likely to ‘arouse the most
intense feelings.’ ” _Fitzgerald_, 457 U. S., at 752 (quoting
_Pierson_, 386 U. S., at 554). Allowing prosecutors to ask or
suggest that the jury probe official acts for which the President is immune would thus raise a unique risk that the
jurors’ deliberations will be prejudiced by their views of the
President’s policies and performance while in office. The
prosaic tools on which the Government would have courts
rely are an inadequate safeguard against the peculiar constitutional concerns implicated in the prosecution of a former President. Cf. _Nixon_, 418 U. S., at 706. Although such


---

32 TRUMP _v._ UNITED STATES


Opinion of the Court


tools may suffice to protect the constitutional rights of individual criminal defendants, the interests that underlie
Presidential immunity seek to protect not the President
himself, but the institution of the Presidency. [3 ]

IV
A
Trump asserts a far broader immunity than the limited
one we have recognized. He contends that the indictment
must be dismissed because the Impeachment Judgment
Clause requires that impeachment and Senate conviction
precede a President’s criminal prosecution. Brief for Petitioner 16.

The text of the Clause provides little support for such an
absolute immunity. It states that an impeachment judgment “shall not extend further than to removal from Office,
and disqualification to hold and enjoy any Office of honor,
Trust or Profit under the United States.” Art. I, §3, cl. 7. It
then specifies that “the Party convicted shall _nevertheless_
be liable and subject to Indictment, Trial, Judgment and
Punishment, according to Law.” _Ibid_ . (emphasis added).
——————

3 JUSTICE BARRETT disagrees, arguing that in a bribery prosecution, for
instance, excluding “any mention” of the official act associated with the
bribe “would hamstring the prosecution.” _Post_, at 6 (opinion concurring
in part); cf. _post_, at 25–27 (opinion of SOTOMAYOR, J.). But of course the
prosecutor may point to the public record to show the fact that the President performed the official act. And the prosecutor may admit evidence
of what the President allegedly demanded, received, accepted, or agreed
to receive or accept in return for being influenced in the performance of
the act. See 18 U. S. C. §201(b)(2). What the prosecutor may not do,
however, is admit testimony or private records of the President or his
advisers probing the official act itself. Allowing that sort of evidence
would invite the jury to inspect the President’s motivations for his official
actions and to second-guess their propriety. As we have explained, such
inspection would be “highly intrusive” and would “ ‘seriously cripple’ ” the
President’s exercise of his official duties. _Fitzgerald_, 457 U. S., at 745,
756 (quoting _Spalding_ v. _Vilas_, 161 U. S. 483, 498 (1896)); see _supra,_ at
18. And such second-guessing would “threaten the independence or effectiveness of the Executive.” _Trump_ v. _Vance_, 591 U. S. 786, 805 (2020).


---

Cite as: 603 U. S. ____ (2024) 33


Opinion of the Court


The Clause both limits the consequences of an impeachment judgment and clarifies that notwithstanding such
judgment, subsequent prosecution may proceed. By its own
terms, the Clause does not address whether and on what
conduct a President may be prosecuted if he was never impeached and convicted.

Historical evidence likewise lends little support to
Trump’s position. For example, Justice Story reasoned that
without the Clause’s clarification that “Indictment, Trial,
Judgment and Punishment” may nevertheless follow Senate conviction, “it might be matter of extreme doubt,
whether . . . a second trial for the same offence could be had,
either after an acquittal, or a conviction in the court of impeachments.” 2 J. Story, Commentaries on the Constitution of the United States §780, p. 251 (1833). James Wilson,
who served on the Committee that drafted the Clause and
later as a Justice of this Court, similarly concluded that acquittal of impeachment charges posed no bar to subsequent
prosecution. See 2 Documentary History of the Ratification
of the Constitution 492 (M. Jensen ed. 1979). And contrary
to Trump’s contention, Alexander Hamilton did not disagree. The Federalist Papers on which Trump relies, see
Brief for Petitioner 17–18, concerned the checks available
against a _sitting_ President. Hamilton noted that unlike
“the King of Great-Britain,” the President “would be liable
to be impeached” and “removed from office,” and “would afterwards be liable to prosecution and punishment.” The
Federalist No. 69, at 463; see also _id_ ., No. 77, at 520 (explaining that the President is “at all times liable to impeachment, trial, dismission from office . . . and to the forfeiture of life and estate by subsequent prosecution”).
Hamilton did not endorse or even consider whether the Impeachment Judgment Clause immunizes a _former_ President from prosecution.

The implication of Trump’s theory is that a President who
evades impeachment for one reason or another during his


---

34 TRUMP _v._ UNITED STATES


Opinion of the Court


term in office can never be held accountable for his criminal
acts in the ordinary course of law. So if a President manages to conceal certain crimes throughout his Presidency,
or if Congress is unable to muster the political will to impeach the President for his crimes, then they must forever
remain impervious to prosecution.

Impeachment is a political process by which Congress can
remove a President who has committed “Treason, Bribery,
or other high Crimes and Misdemeanors.” Art. II, §4.
Transforming that political process into a necessary step in
the enforcement of criminal law finds little support in the
text of the Constitution or the structure of our Government.

B
The Government for its part takes a similarly broad view,
contending that the President enjoys no immunity from
criminal prosecution for any action. It maintains this view
despite agreeing with much of our analysis.
For instance, the Government does not dispute that Congress may not criminalize Presidential conduct within the
President’s “conclusive and preclusive” constitutional authority. See Tr. of Oral Arg. 133 (“[C]ore powers . . . can’t
be regulated at all, like the pardon power and veto.”); see
also _id._, at 84–85. And it too accords protection to Presidential conduct if subjecting that conduct to generally applicable laws would “raise serious constitutional questions regarding the President’s authority” or cause a “possible
conflict with the President’s constitutional prerogatives.”
Application of 28 U. S. C. §458 to Presidential Appointments of Federal Judges, 19 Op. OLC 350, 351–352 (1995);
see Brief for United States 26–29; Tr. of Oral Arg. 78. Indeed, the Executive Branch has long held that view. The
Office of Legal Counsel has recognized, for instance, that a
federal statute generally prohibiting appointments to “‘any
office or duty in any court’” of persons within certain degrees of consanguinity to the judges of such courts would, if


---

Cite as: 603 U. S. ____ (2024) 35


Opinion of the Court


applied to the President, infringe his power to appoint federal judges, thereby raising a serious constitutional question. 19 Op. OLC, at 350 (quoting 28 U. S. C. §458); see _id._,
at 350–352. So it viewed such a statute as not applying to
the President. Likewise, it has narrowly construed a criminal prohibition on grassroots lobbying to avoid the constitutional issues that would otherwise arise, reasoning that
the statute should not “be construed to prohibit the President or executive branch agencies from engaging in a general open dialogue with the public on the Administration’s
programs and policies.” Constraints Imposed by 18 U. S. C.
§1913 on Lobbying Efforts, 13 Op. OLC 300, 304 (1989); see
_id_ ., at 304–306.

The Government thus broadly agrees that the President’s
official acts are entitled to some degree of constitutional
protection. And with respect to the allegations in the indictment before us, the Government agrees that at least
some of the alleged conduct involves official acts. See Tr. of
Oral Arg. 125; cf. _id._, at 128.

Yet the Government contends that the President should
not be considered immune from prosecution for those official acts. See Brief for United States 9. On the Government’s view, as-applied challenges in the course of the trial
suffice to protect Article II interests, and review of a district
court’s decisions on such challenges should be deferred until after trial. See Tr. of Oral Arg. 69, 79–80, 154–158. If
the President is instead immune from prosecution, a district court’s denial of immunity would be appealable before
trial. See _Mitchell_, 472 U. S., at 524–530 (explaining that
questions of immunity are reviewable before trial because
the essence of immunity is the entitlement not to be subject
to suit).

The Government asserts that the “[r]obust safeguards”
available in typical criminal proceedings alleviate the need
for pretrial review. Brief for United States 20 (boldface and


---

36 TRUMP _v._ UNITED STATES


Opinion of the Court


emphasis omitted). First, it points to the Justice Department’s “longstanding commitment to the impartial enforcement of the law,” _id._, at 21, as well as the criminal justice
system’s further protections: grand juries, a defendant’s
procedural rights during trial, and the requirement that the
Government prove its case beyond a reasonable doubt, _id._,
at 22. Next, it contends that “existing principles of statutory construction and as-applied constitutional challenges”
adequately address the separation of powers concerns involved in applying generally applicable criminal laws to a
President. _Id._, at 29. Finally, the Government cites certain
defenses that would be available to the President in a particular prosecution, such as the public-authority defense or
the advice of the Attorney General. _Id._, at 29–30; see _Nar-_
_done_ v. _United States_, 302 U. S. 379, 384 (1937); Tr. of Oral
Arg. 107–108.

These safeguards, though important, do not alleviate the
need for pretrial review. They fail to address the fact that
under our system of separated powers, criminal prohibitions cannot apply to certain Presidential conduct to begin
with. As we have explained, when the President acts pursuant to his exclusive constitutional powers, Congress cannot—as a structural matter—regulate such actions, and
courts cannot review them. See Part II–A, _supra_ . And he
is at least presumptively immune from prosecution for his
other official actions. See Part II–B, _supra_ .

Questions about whether the President may be held liable for particular actions, consistent with the separation of
powers, must be addressed at the outset of a proceeding.
Even if the President were ultimately not found liable for
certain official actions, the possibility of an extended proceeding alone may render him “unduly cautious in the discharge of his official duties.” _Fitzgerald_, 457 U. S., at 752,
n. 32. Vulnerability “‘to the burden of a trial and to the
inevitable danger of its outcome, would dampen the ardor
of all but the most resolute.’” _Id._, at 752–753, n. 32 (quoting


---

Cite as: 603 U. S. ____ (2024) 37


Opinion of the Court


_Gregoire_ v. _Biddle_, 177 F. 2d 579, 581 (CA2 1949) (Hand,
L., C. J.)). The Constitution does not tolerate such impediments to “the effective functioning of government.” _Fitzger-_
_ald_, 457 U. S., at 751.

As for the Government’s assurances that prosecutors and
grand juries will not permit political or baseless prosecutions from advancing in the first place, those assurances are
available to every criminal defendant and fail to account for
the President’s “unique position in the constitutional
scheme.” _Id._, at 749. We do not ordinarily decline to decide
significant constitutional questions based on the Government’s promises of good faith. See _United States_ v. _Stevens_,
559 U. S. 460, 480 (2010) (“We would not uphold an unconstitutional statute merely because the Government promised to use it responsibly.”). Nor do we do so today.

C
As for the dissents, they strike a tone of chilling doom
that is wholly disproportionate to what the Court actually
does today—conclude that immunity extends to official discussions between the President and his Attorney General,
and then remand to the lower courts to determine “in the
first instance” whether and to what extent Trump’s remaining alleged conduct is entitled to immunity. _Supra_, at 24,
28, 30.
The principal dissent’s starting premise—that unlike
Speech and Debate Clause immunity, no constitutional text
supports Presidential immunity, see _post_, at 4–6 (opinion of
SOTOMAYOR, J.)—is one that the Court rejected decades ago
as “unpersuasive.” _Fitzgerald_, 457 U. S., at 750, n. 31; see
also _Nixon_, 418 U. S., at 705–706, n. 16 (rejecting unanimously a similar argument in the analogous executive privilege context). “[A] specific textual basis has not been considered a prerequisite to the recognition of immunity.”
_Fitzgerald_, 457 U. S., at 750, n. 31. Nor is that premise correct. True, there is no “Presidential immunity clause” in


---

38 TRUMP _v._ UNITED STATES


Opinion of the Court


the Constitution. But there is no “‘separation of powers
clause’” either. _Seila Law_, 591 U. S., at 227. Yet that doctrine is undoubtedly carved into the Constitution’s text by
its three articles separating powers and vesting the Executive power solely in the President. See _ibid._ And the
Court’s prior decisions, such as _Nixon_ and _Fitzgerald_, have
long recognized that doctrine as mandating certain Presidential privileges and immunities, even though the Constitution contains no explicit “provision for immunity.” _Post_,
at 4; see Part II–B–1, _supra_ . Neither the dissents nor the
Government disavow any of those prior decisions. See Tr.
of Oral Arg. 76–77.

The principal dissent then cites the Impeachment Judgment Clause, arguing that it “clearly contemplates that a
former President may be subject to criminal prosecution.”
_Post_, at 6. But that Clause does not indicate whether a former President may, consistent with the separation of powers, be prosecuted for his _official_ conduct in particular. See
_supra_, at 32–33. And the assortment of historical sources
the principal dissent cites are unhelpful for the same reason. See _post_, at 6–8. As the Court has previously noted,
relevant historical evidence on the question of Presidential
immunity is of a “fragmentary character.” _Fitzgerald_, 457
U. S., at 752, n. 31; see also _Clinton_, 520 U. S., at 696–697;
cf. _Youngstown_, 343 U. S., at 634 (Jackson, J., concurring)
(noting “the poverty of really useful and unambiguous authority applicable to concrete problems of executive
power”). “[T]he most compelling arguments,” therefore,
“arise from the Constitution’s separation of powers and the
Judiciary’s historic understanding of that doctrine.” _Fitz-_
_gerald_, 457 U. S., at 752, n. 31 _._

The Court’s prior admonition is evident in the principal
dissent’s citations. Some of its cherry-picked sources do not
even discuss the President in particular. See, _e.g._, _post_, at
7–8 (citing 2 Debates on the Constitution 177 (J. Elliot ed.
1836); 2 J. Story, Commentaries on the Constitution of the


---

Cite as: 603 U. S. ____ (2024) 39


Opinion of the Court


United States §780, pp. 250–251 (1833)). And none of them
indicate whether he may be prosecuted for his official conduct. See, _e.g._, _post_, at 6, 7, n. 2 (citing The Federalist No.
69; 4 Debates on the Constitution, at 109). The principal
dissent’s most compelling piece of evidence consists of excerpted statements of Charles Pinckney from an 1800 Senate debate. See _post_, at 7. But those statements reflect only
the now-discredited argument that any immunity not expressly mentioned in the Constitution must not exist. See
3 Records of the Federal Convention of 1787, pp. 384–385
(M. Farrand ed. 1911). And Pinckney is not exactly a reliable authority on the separation of powers: He went on to
state on the same day that “it was wrong to give the nomination of Judges to the President”—an opinion expressly rejected by the Framers. _Id._, at 385. Given the Framers’ desire for an energetic and vigorous President, the principal
dissent’s view that the Constitution they designed allows
all his actions to be subject to prosecution—even the exercise of powers it grants exclusively to him—defies credulity.

Unable to muster any meaningful textual or historical
support, the principal dissent suggests that there is an “established understanding” that “former Presidents are answerable to the criminal law for their official acts.” _Post_, at
9. Conspicuously absent is mention of the fact that since
the founding, no President has ever faced criminal
charges—let alone for his conduct in office. And accordingly
no court has ever been faced with the question of a President’s immunity from prosecution. All that our Nation’s
practice establishes on the subject is silence.

Coming up short on reasoning, the dissents repeatedly
level variations of the accusation that the Court has rendered the President “above the law.” See, _e.g._, _post_, at 1, 3,
11, 12, 21, 30 (opinion of SOTOMAYOR, J.); _post_, at 9, 10, 11,
12, 13, 19 (opinion of JACKSON, J.). As before, that “rhetorically chilling” contention is “wholly unjustified.” _Fitzger-_


---

40 TRUMP _v._ UNITED STATES


Opinion of the Court


_ald_, 457 U. S., at 758, n. 41. Like everyone else, the President is subject to prosecution in his unofficial capacity. But
unlike anyone else, the President is a branch of government, and the Constitution vests in him sweeping powers
and duties. Accounting for that reality—and ensuring that
the President may exercise those powers forcefully, as the
Framers anticipated he would—does not place him above
the law; it preserves the basic structure of the Constitution
from which that law derives.

The dissents’ positions in the end boil down to ignoring
the Constitution’s separation of powers and the Court’s
precedent and instead fear mongering on the basis of extreme hypotheticals about a future where the President
“feels empowered to violate federal criminal law.” _Post_, at
18 (opinion of SOTOMAYOR, J.); see _post_, at 26, 29–30; _post_,
at 8–9, 10, 12, 16, 20–21 (opinion of JACKSON, J.). The dissents overlook the more likely prospect of an Executive
Branch that cannibalizes itself, with each successive President free to prosecute his predecessors, yet unable to boldly
and fearlessly carry out his duties for fear that he may be
next. For instance, Section 371—which has been charged
in this case—is a broadly worded criminal statute that can
cover “‘any conspiracy for the purpose of impairing, obstructing or defeating the lawful function of any department of Government.’” _United States_ v. _Johnson_, 383 U. S.
169, 172 (1966) (quoting _Haas_ v. _Henkel_, 216 U. S. 462, 479
(1910)). Virtually every President is criticized for insufficiently enforcing some aspect of federal law (such as drug,
gun, immigration, or environmental laws). An enterprising
prosecutor in a new administration may assert that a previous President violated that broad statute. Without immunity, such types of prosecutions of ex-Presidents could
quickly become routine. The enfeebling of the Presidency
and our Government that would result from such a cycle of
factional strife is exactly what the Framers intended to


---

Cite as: 603 U. S. ____ (2024) 41


Opinion of the Court


avoid. Ignoring those risks, the dissents are instead content to leave the preservation of our system of separated
powers up to the good faith of prosecutors.

Finally, the principal dissent finds it “troubling” that the
Court does not “designate any course of conduct alleged in
the indictment as private.” _Post_, at 27. Despite the unprecedented nature of this case, the significant constitutional
questions that it raises, its expedited treatment in the lower
courts and in this Court, the lack of factual analysis in the
lower courts, and the lack of briefing on how to categorize
the conduct alleged, the principal dissent would go ahead
and declare all of it unofficial. The other dissent, meanwhile, analyzes the case under comprehensive models and
paradigms of its own concoction and accuses the Court of
providing “no meaningful guidance about how to apply [the]
new paradigm or how to categorize a President’s conduct.”
_Post_, at 13 (opinion of JACKSON, J.). It would have us exhaustively define every application of Presidential immunity. See _post_, at 13–14. Our dissenting colleagues exude an
impressive infallibility. While their confidence may be inspiring, the Court adheres to time-tested practices instead—deciding what is required to dispose of this case and
remanding after “revers[ing] on a threshold question,” _Zi-_
_votofsky_, 566 U. S., at 201, to obtain “guidance from the litigants [and] the court below,” _Vidal_ v. _Elster_, 602 U. S. 286,
328 (2024) (SOTOMAYOR, J., concurring in judgment).

V
This case poses a question of lasting significance: When
may a former President be prosecuted for official acts taken
during his Presidency? Our Nation has never before needed
an answer. But in addressing that question today, unlike
the political branches and the public at large, we cannot afford to fixate exclusively, or even primarily, on present exigencies. In a case like this one, focusing on “transient results” may have profound consequences for the separation


---

42 TRUMP _v._ UNITED STATES


Opinion of the Court


of powers and for the future of our Republic. _Youngstown_,
343 U. S., at 634 (Jackson, J., concurring). Our perspective
must be more farsighted, for “[t]he peculiar circumstances
of the moment may render a measure more or less wise, but
cannot render it more or less constitutional.” Chief Justice
John Marshall, A Friend of the Constitution No. V, Alexandria Gazette, July 5, 1819, in John Marshall’s Defense of
_McCulloch v. Maryland_ 190–191 (G. Gunther ed. 1969).

Our first President had such a perspective. In his Farewell Address, George Washington reminded the Nation
that “a Government of as much vigour as is consistent with
the perfect security of Liberty is indispensable.” 35 Writings of George Washington 226 (J. Fitzpatrick ed. 1940). A
government “too feeble to withstand the enterprises of faction,” he warned, could lead to the “frightful despotism” of
“alternate domination of one faction over another, sharpened by the spirit of revenge.” _Id._, at 226–227. And the
way to avoid that cycle, he explained, was to ensure that
government powers remained “properly distributed and adjusted.” _Id._, at 226.

It is these enduring principles that guide our decision in
this case. The President enjoys no immunity for his unofficial acts, and not everything the President does is official.
The President is not above the law. But Congress may not
criminalize the President’s conduct in carrying out the responsibilities of the Executive Branch under the Constitution. And the system of separated powers designed by the
Framers has always demanded an energetic, independent
Executive. The President therefore may not be prosecuted
for exercising his core constitutional powers, and he is entitled, at a minimum, to a presumptive immunity from prosecution for all his official acts. That immunity applies
equally to all occupants of the Oval Office, regardless of politics, policy, or party.

The judgment of the Court of Appeals for the D. C. Circuit
is vacated, and the case is remanded for further proceedings


---

Cite as: 603 U. S. ____ (2024) 43


Opinion of the Court


consistent with this opinion.

_It is so ordered._


---

Cite as: 603 U. S. ____ (2024) 1


THOMAS, J., concurring

# **SUPREME COURT OF THE UNITED STATES**

_________________


No. 23–939

_________________

DONALD J. TRUMP, PETITIONER _v._
UNITED STATES


ON WRIT OF CERTIORARI TO THE UNITED STATES COURT OF
APPEALS FOR THE DISTRICT OF COLUMBIA CIRCUIT


[July 1, 2024]


JUSTICE THOMAS, concurring.

Few things would threaten our constitutional order more
than criminally prosecuting a former President for his official acts. Fortunately, the Constitution does not permit us
to chart such a dangerous course. As the Court forcefully
explains, the Framers “deemed an energetic executive essential to . . . the security of liberty,” and our “system of separated powers” accordingly insulates the President from
prosecution for his official acts. _Ante_, at 10, 42 (internal
quotation marks omitted). To conclude otherwise would
hamstring the vigorous Executive that our Constitution envisions. “While the separation of powers may prevent us
from righting every wrong, it does so in order to ensure that
we do not lose liberty.” _Morrison_ v. _Olson_, 487 U. S. 654,
710–711 (1988) (Scalia, J., dissenting).

I write separately to highlight another way in which this
prosecution may violate our constitutional structure. In
this case, the Attorney General purported to appoint a private citizen as Special Counsel to prosecute a former President on behalf of the United States. But, I am not sure that
any office for the Special Counsel has been “established by
Law,” as the Constitution requires. Art. II, §2, cl. 2. By requiring that Congress create federal offices “by Law,” the
Constitution imposes an important check against the President—he cannot create offices at his pleasure. If there is


---

2 TRUMP _v._ UNITED STATES


THOMAS, J., concurring


no law establishing the office that the Special Counsel occupies, then he cannot proceed with this prosecution. A private citizen cannot criminally prosecute anyone, let alone a
former President.

No former President has faced criminal prosecution for
his acts while in office in the more than 200 years since the
founding of our country. And, that is so despite numerous
past Presidents taking actions that many would argue constitute crimes. If this unprecedented prosecution is to proceed, it must be conducted by someone duly authorized to
do so by the American people. The lower courts should thus
answer these essential questions concerning the Special
Counsel’s appointment before proceeding.

I
The Constitution sets forth how an office may be created
and how it may be filled. The Appointments Clause provides:

“[The President] shall nominate, and by and with the
Advice and Consent of the Senate, shall appoint Ambassadors, other public Ministers and Consuls, Judges
of the supreme Court, and all other Officers of the
United States, whose Appointments are not herein otherwise provided for, and which shall be established by
Law: but the Congress may by Law vest the Appointment of such inferior Officers, as they think proper, in
the President alone, in the Courts of Law, or in the
Heads of Department.” Art. II, §2, cl. 2.

The constitutional process for filling an office is plain
from this text. The default manner for appointing “Officers
of the United States” is nomination by the President and
confirmation by the Senate. _Ibid_ . “But the Clause provides
a limited exception for the appointment of inferior officers:
Congress may ‘by Law’ authorize” one of three specified ac


---

Cite as: 603 U. S. ____ (2024) 3


THOMAS, J., concurring


tors “to appoint inferior officers without the advice and consent of the Senate.” _NLRB_ v. _SW General, Inc._, 580 U. S.
288, 312 (2017) (THOMAS, J., concurring). As relevant here,
a “Hea[d] of Department”—such as the Attorney General—
is one such actor that Congress may authorize “by Law” to
appoint inferior officers without senatorial confirmation.
Art. II, §2, cl. 2.

Before the President or a Department Head can appoint
any officer, however, the Constitution requires that the underlying office be “established by Law.” [1] The Constitution
itself creates some offices, most obviously that of the President and Vice President. See §1. Although the Constitution
contemplates that there will be “other Officers of the United
States, whose Appointments are not herein otherwise provided for,” it clearly requires that those offices “shall be established by Law.” §2, cl. 2. And, “established by law” refers to an office that Congress creates “by statute.” _Lucia_
v. _SEC_, 585 U. S. 237, 254 (2018) (THOMAS, J., concurring);
see also _United States_ v. _Maurice_, 26 F. Cas. 1211, 1213
(No. 15,747) (CC Va. 1823) (Marshall, C. J.).

The limitation on the President’s power to create offices
grew out of the Founders’ experience with the English monarchy. The King could wield significant power by both creating and filling offices as he saw fit. He was “emphatically
and truly styled the fountain of honor. He not only appoint[ed] to all offices, but [could] create offices.” The Federalist No. 69, p. 421 (C. Rossiter ed. 1961); see also 1 W.
Blackstone, Commentaries on the Laws of England 271 (T.
——————

1 Although a Government official may also be a “nonofficer employe[e],”
I set aside that category because it is difficult to see how an official exercising the Department of Justice’s duties to enforce the criminal law by
leading a prosecution could be anything but an officer. _Lucia_ v. _SEC_,
585 U. S. 237, 253, n. 1 (2018) (THOMAS, J., concurring); see _SW General_,
580 U. S., at 314 (opinion of THOMAS, J.). If the Special Counsel were a
nonofficer employee, the constitutional problems with this prosecution
would only be more serious. For now, I assume without deciding that the
Special Counsel is an officer.


---

4 TRUMP _v._ UNITED STATES


THOMAS, J., concurring


Cooley ed. 1871) (“[A]s the king may create new titles, so
may he create new offices”). That ability to create offices
raised many “concerns about the King’s ability to amass too
much power”; the King could both create a multitude of offices and then fill them with his supporters. J. Mascott,
Who Are “Officers of the United States”? 70 Stan. L. Rev.
443, 492 (2018) (Mascott); see also G. Wood, The Creation
of the American Republic 1776–1787, p. 143 (1969) (describing “the power of appointment to offices” as “the most insidious and powerful weapon of eighteenth-century despotism”); T. Paine, Common Sense (1776), reprinted in The
Great Works of Thomas Paine 11 (1877) (explaining that
“the crown . . . derives its whole consequence merely from
being the giver of places and pensions”). In fact, one of the
grievances raised by the American colonists in declaring
their independence was that the King “ha[d] erected a multitude of New Offices, and sent hither swarms of Officers to
harass our people and eat out their substance.” Declaration
of Independence ¶12. The Founders thus drafted the Constitution with “evidently a great inferiority in the power of
the President, in this particular, to that of the British king.”
The Federalist No. 69, at 421.

The Founders broke from the monarchial model by giving
the President the power to _fill_ offices (with the Senate’s approval), but not the power to _create_ offices. They did so by
“imposing the constitutional requirement that new officer
positions be ‘established by Law’ rather than through a
King-like custom of the head magistrate unilaterally creating new offices.” Mascott 492–493 (footnote omitted); see
also 1 Annals of Cong. 581–582 (1789) (“The powers relative
to offices are partly Legislative and partly Executive. The
Legislature creates the office, defines the powers, limits its
duration, and annexes a compensation”); see also _ibid_ . (describing the power to “designat[e] the man to fill the office”
as “of an Executive nature”). The Constitution thus “giv[es]


---

Cite as: 603 U. S. ____ (2024) 5


THOMAS, J., concurring


Congress broad authority to establish and organize the Executive Branch.” _Seila Law LLC_ v. _Consumer Financial_
_Protection Bureau_, 591 U. S. 197, 266 (2020) (KAGAN, J.,
concurring in judgment in part and dissenting in part). By
keeping the ability to create offices out of the President’s
hands, the Founders ensured that no President could unilaterally create an army of officer positions to then fill with
his supporters. Instead, our Constitution leaves it in the
hands of the people’s elected representatives to determine
whether new executive offices should exist.

Longstanding practice from the founding to today comports with this original understanding that Congress must
create offices by law. The First Congress, for instance, routinely and explicitly created offices by statute. See, _e_ . _g_ .,
§35, 1 Stat. 92–93 (creating the offices of Attorney General
and U. S. Attorney for each district); see also §§1–2, _id_ ., at
50 (creating offices of Secretary of War and his Chief Clerk);
ch. 12, §1, _id_ ., at 65 (creating offices within the Department
of Treasury for Secretary of the Treasury, a Comptroller,
Auditor, Treasurer, Register, and Assistant to the Secretary). Still today, Congress creates the offices that the Executive Branch may fill. For example, Congress has created
several offices within the Department of Justice, including
the offices of the Attorney General, Deputy Attorney General, Associate Attorney General, Solicitor General, and Assistant Attorneys General. See 28 U. S. C. §§503–506. For
some agencies, Congress has also granted the agency head
the power to “appoint such officers and employees . . . as are
necessary to execute the functions vested in him.” 7
U. S. C. §610(a) (Department of Agriculture); see also, _e_ . _g_ .,
20 U. S. C. §3461 (Department of Education); 42 U. S. C.
§913 (Department of Health and Human Services).

In the past, Congress has at times expressly created offices similar to the position now occupied by the Special
Counsel. Congress created an office for a “special counsel”


---

6 TRUMP _v._ UNITED STATES


THOMAS, J., concurring


to investigate the Teapot Dome Scandal and pursue prosecutions. See ch. 16, 43 Stat. 6. And, a statute provided for
“the appointment of an independent counsel” that we addressed in _Morrison_ v. _Olson_ . See 28 U. S. C. §592. That
statute lapsed, and Congress has not since reauthorized the
appointment of an independent counsel. See §599. [2 ]

We cannot ignore the importance that the Constitution
places on _who_ creates a federal office. To guard against tyranny, the Founders required that a federal office be “established by Law.” As James Madison cautioned, “[i]f there is
any point in which the separation of the Legislative and Executive powers ought to be maintained with greater caution, it is that which relates to officers and offices.” 1 Annals of Cong. 581. If Congress has not reached a consensus
that a particular office should exist, the Executive lacks the
power to create and fill an office of his own accord.

II
It is difficult to see how the Special Counsel has an office
“established by Law,” as required by the Constitution.
When the Attorney General appointed the Special Counsel,
he did not identify any statute that clearly creates such an
office. See Dept. of Justice Order No. 5559–2022 (Nov. 18,
2022). Nor did he rely on a statute granting him the authority to appoint officers as he deems fit, as the heads of
some other agencies have. [3] See _supra_, at 5. Instead, the
Attorney General relied upon several statutes of a general
nature. See Order No. 5559–2022 (citing 28 U. S. C. §§509,
510, 515, 533).


——————

2 To be sure, a few Presidents have appointed “special prosecutors”
without pointing to any express statutory authorization. See generally
T. Eastland, Ethics, Politics and the Independent Counsel 8–9 (1989) (describing past uses of special prosecutors). But, this Court had no occasion to review the constitutionality of those prosecutors’ authority.

3 In fact, Congress gave the Attorney General the power to appoint “additional officers . . . as he deems necessary”—but, only for the Bureau of
Prisons. 18 U. S. C. §4041.


---

Cite as: 603 U. S. ____ (2024) 7


THOMAS, J., concurring


None of the statutes cited by the Attorney General appears to create an office for the Special Counsel, and especially not with the clarity typical of past statutes used for
that purpose. See, _e_ . _g_ ., 43 Stat. 6 (“[T]he President is further authorized and directed to appoint . . . special counsel
who shall have charge and control of the prosecution of such
litigation”). Sections 509 and 510 are generic provisions
concerning the functions of the Attorney General and his
ability to delegate authority to “any other officer, employee,
or agency.” Section 515 contemplates an “attorney specially
appointed by the Attorney General _under law_,” thereby suggesting that such an attorney’s office must have already
been created by some other law. (Emphasis added.) As for
§533, it provides that “[t]he Attorney General may appoint
_officials_ . . . to detect and prosecute crimes against the
United States.” (Emphasis added.) It is unclear whether
an “official” is equivalent to an “officer” as used by the Constitution. See _Lucia_, 585 U. S., at 254–255 (opinion of
THOMAS, J.) (considering the meaning of “officer”). Regardless, this provision would be a curious place for Congress to
hide the creation of an office for a Special Counsel. It is
placed in a chapter concerning the Federal Bureau of Investigation (§§531–540d), not the separate chapters concerning U. S. Attorneys (§§541–550) or the now-lapsed Independent Counsel (§§591–599). [4 ]

To be sure, the Court gave passing reference to the cited
statutes as supporting the appointment of the Special Prosecutor in _United States_ v. _Nixon_, 418 U. S. 683, 694 (1974),
but it provided no analysis of those provisions’ text. Perhaps there is an answer for why these statutes create an
office for the Special Counsel. But, before this consequen

——————

4 Regulations remain on the books that contemplate an “outside” Special Counsel, 28 CFR §600.1 (2023), but I doubt a regulation can create a
federal office without underlying statutory authority to do so.


---

8 TRUMP _v._ UNITED STATES


THOMAS, J., concurring


tial prosecution proceeds, we should at least provide a fulsome explanation of why that is so.

Even if the Special Counsel has a valid office, questions
remain as to whether the Attorney General filled that office
in compliance with the Appointments Clause. For example,
it must be determined whether the Special Counsel is a
principal or inferior officer. If the former, his appointment
is invalid because the Special Counsel was not nominated
by the President and confirmed by the Senate, as principal
officers must be. Art. II, §2, cl. 2. Even if he is an inferior
officer, the Attorney General could appoint him without
Presidential nomination and senatorial confirmation only if
“Congress . . . by law vest[ed] the Appointment” in the Attorney General as a “Hea[d] of Department.” _Ibid_ . So, the
Special Counsel’s appointment is invalid unless a statute
created the Special Counsel’s office _and_ gave the Attorney
General the power to fill it “by Law.”

Whether the Special Counsel’s office was “established by
Law” is not a trifling technicality. If Congress has not
reached a consensus that a particular office should exist,
the Executive lacks the power to unilaterally create and
then fill that office. Given that the Special Counsel purports to wield the Executive Branch’s power to prosecute,
the consequences are weighty. Our Constitution’s separation of powers, including its separation of the powers to create and fill offices, is “the absolutely central guarantee of a
just Government” and the liberty that it secures for us all.
_Morrison_, 487 U. S., at 697 (Scalia, J., dissenting). There is
no prosecution that can justify imperiling it.

              -               -               In this case, there has been much discussion about ensuring that a President “is not above the law.” But, as the
Court explains, the President’s immunity from prosecution
for his official acts _is_ the law. The Constitution provides for


---

Cite as: 603 U. S. ____ (2024) 9


THOMAS, J., concurring


“an energetic executive,” because such an Executive is “essential to . . . the security of liberty.” _Ante_, at 10 (internal
quotation marks omitted). Respecting the protections that
the Constitution provides for the Office of the Presidency
secures liberty. In that same vein, the Constitution also
secures liberty by separating the powers to create and fill
offices. And, there are serious questions whether the Attorney General has violated that structure by creating an office of the Special Counsel that has not been established by
law. Those questions must be answered before this prosecution can proceed. We must respect the Constitution’s separation of powers in all its forms, else we risk rendering its
protection of liberty a parchment guarantee.


---

Cite as: 603 U. S. ____ (2024) 1


BARRETT, J., concurring in part

# **SUPREME COURT OF THE UNITED STATES**

_________________


No. 23–939

_________________

DONALD J. TRUMP, PETITIONER _v._
UNITED STATES


ON WRIT OF CERTIORARI TO THE UNITED STATES COURT OF
APPEALS FOR THE DISTRICT OF COLUMBIA CIRCUIT


[July 1, 2024]


JUSTICE BARRETT, concurring in part.

For reasons I explain below, I do not join Part III–C of the
Court’s opinion. The remainder of the opinion is consistent
with my view that the Constitution prohibits Congress from
criminalizing a President’s exercise of core Article II powers
and closely related conduct. That said, I would have framed
the underlying legal issues differently. The Court describes
the President’s constitutional protection from certain prosecutions as an “immunity.” As I see it, that term is shorthand for two propositions: The President can challenge the
constitutionality of a criminal statute as applied to official
acts alleged in the indictment, and he can obtain interlocutory review of the trial court’s ruling.

There appears to be substantial agreement on the first
point. Like the Court, the dissenting Justices and the Special Counsel all accept that some prosecutions of a President’s official conduct may be unconstitutional. See _post_, at
16 (opinion of SOTOMAYOR, J.); Brief for United States 24–
30. As for interlocutory review, our precedent recognizes
that resolving certain legal issues before trial is necessary
to safeguard important constitutional interests—here, Executive Branch independence on matters that Article II assigns to the President’s discretion.

Properly conceived, the President’s constitutional protection from prosecution is narrow. The Court leaves open the


---

2 TRUMP _v._ UNITED STATES


BARRETT, J., concurring in part


possibility that the Constitution forbids prosecuting the
President for _any_ official conduct, instructing the lower
courts to address that question in the first instance. See
_ante_, at 14. I would have answered it now. Though I agree
that a President cannot be held criminally liable for conduct
within his “conclusive and preclusive” authority and closely
related acts, _ante_, at 8–9, the Constitution does not vest
every exercise of executive power in the President’s sole discretion, _Youngstown Sheet & Tube Co._ v. _Sawyer_, 343 U. S.
579, 637 (1952) (Jackson, J., concurring). [1] Congress has
concurrent authority over many Government functions,
and it may sometimes use that authority to regulate the
President’s official conduct, including by criminal statute.
Article II poses no barrier to prosecution in such cases.

I would thus assess the validity of criminal charges predicated on most official acts— _i.e._, those falling outside of the
President’s core executive power—in two steps. The first
question is whether the relevant criminal statute reaches
the President’s official conduct. Not every broadly worded
statute does. For example, §956 covers conspiracy to murder in a foreign country and does not expressly exclude the
President’s decision to, say, order a hostage rescue mission
abroad. 18 U. S. C. §956(a). The underlying murder statute, however, covers only “unlawful” killings. §1111. The
Office of Legal Counsel has interpreted that phrase to reflect a public-authority exception for official acts involving
the military and law enforcement. Memorandum from D.
Barron, Acting Assistant Atty. Gen., to E. Holder, Atty.
——————

1 Consistent with our separation of powers precedent, I agree with the
Court that the supervision and removal of appointed, high ranking Justice Department officials falls within the President’s core executive
power. See _Seila Law LLC_ v. _Consumer Financial Protection Bureau_,
591 U. S. 197, 213–215 (2020); _ante_, at 19–21. I do not understand the
Court to hold that all exercises of the Take Care power fall within the
core executive power. Cf. _post_, at 24 (SOTOMAYOR, J., dissenting). I agree
with the dissent that the Constitution does not justify such an expansive
view. _Ibid._


---

Cite as: 603 U. S. ____ (2024) 3


BARRETT, J., concurring in part


Gen., Re: Applicability of Federal Criminal Laws and the
Constitution to Contemplated Lethal Operations Against
Shaykh Anwar al-Aulaqi 12–19 (July 16, 2010); see also
Brief for United States 29–30; _post_, at 16, and n. 3
(SOTOMAYOR, J., dissenting). I express no view about the
merits of that interpretation, but it shows that the threshold question of statutory interpretation is a nontrivial step.

If the statute covers the alleged official conduct, the prosecution may proceed only if applying it in the circumstances
poses no “‘dange[r] of intrusion on the authority and functions of the Executive Branch.’” _Ante_, at 14 (quoting _Nixon_
v. _Fitzgerald_, 457 U. S. 731, 754 (1982)). On remand, the
lower courts will have to apply that standard to various allegations involving the President’s official conduct. [2] Some
of those allegations raise unsettled questions about the
scope of Article II power, see _ante_, at 21–28, but others do
not. For example, the indictment alleges that the President
“asked the Arizona House Speaker to call the legislature
into session to hold a hearing” about election fraud claims.
App. 193. The President has no authority over state legislatures or their leadership, so it is hard to see how prose

——————

2 This analysis is unnecessary for allegations involving the President’s
private conduct because the Constitution offers no protection from prosecution of acts taken in a private capacity. _Ante_, at 15. Sorting private
from official conduct sometimes will be difficult—but not always. Take
the President’s alleged attempt to organize alternative slates of electors.
See, _e_ . _g_ ., App. 208. In my view, that conduct is private and therefore not
entitled to protection. See _post_, at 27–28 (SOTOMAYOR, J., dissenting).
The Constitution vests power to appoint Presidential electors in the
States. Art. II, §1, cl. 2; see also _Chiafalo_ v. _Washington_, 591 U. S. 578,
588–589 (2020). And while Congress has a limited role in that process,
see Art. II, §1, cls. 3–4, the President has none. In short, a President has
no legal authority—and thus no official capacity—to influence how the
States appoint their electors. I see no plausible argument for barring
prosecution of that alleged conduct.


---

4 TRUMP _v._ UNITED STATES


BARRETT, J., concurring in part


cuting him for crimes committed when dealing with the Arizona House Speaker would unconstitutionally intrude on
executive power.

This two-step analysis—considering first whether the
statute applies and then whether its application to the particular facts is constitutional—is similar to the approach
that the Special Counsel presses in this Court. Brief for
United States 24–30. It is also our usual approach to considering the validity of statutes in situations raising a constitutional question. See, _e_ . _g_ ., _Seila Law LLC_ v. _Consumer_
_Financial Protection Bureau_, 591 U. S. 197, 213, 229
(2020). [3] An important difference in this context is that the
President is entitled to an interlocutory appeal of the trial
court’s ruling. See _ante_, at 36. A criminal defendant in federal court normally must wait until after trial to seek review of the trial court’s refusal to dismiss charges. See
_United States_ v. _MacDonald_, 435 U. S. 850, 853–854 (1978);
see also 18 U. S. C. §3731. But where trial itself threatens
certain constitutional interests, we have treated the trial
court’s resolution of the issue as a “final decision” for purposes of appellate jurisdiction. _MacDonald_, 435 U. S., at
854–856; see 28 U. S. C. §1291; see also §1257.

——————

3 The Court has sometimes applied an avoidance canon when interpreting a statute that would interfere with the President’s prerogatives.
See, _e.g._, _Franklin_ v. _Massachusetts_, 505 U. S. 788, 800–801 (1992); _Pub-_
_lic Citizen_ v. _Dept. of Justice_, 491 U. S. 440, 465–467 (1989); see also _Sale_
v. _Haitian Centers Council, Inc._, 509 U. S. 155, 188 (1993). The Office of
Legal Counsel has advocated for a clear-statement rule if applying a statute would “raise serious constitutional questions relating to the President’s constitutional authority.” See Application of 28 U. S. C. §458 to
Presidential Appointments of Federal Judges, 19 Op. OLC 350, 350–357
(1995). In my view, neither canon applies in this circumstance. Courts
should instead determine the statute’s ordinary meaning and, if it covers
the alleged official acts, assess whether prosecution would intrude on the
President’s constitutional authority. See _Public Citizen_, 491 U. S., at
481–482 (Kennedy, J., concurring in judgment) (declining to apply the
avoidance canon and concluding that the Federal Advisory Committee
Act is unconstitutional as applied).


---

Cite as: 603 U. S. ____ (2024) 5


BARRETT, J., concurring in part


The present circumstances fall squarely within our precedent authorizing interlocutory review. When a President
moves to dismiss an indictment on Article II grounds, he
“makes no challenge whatsoever to the merits of the charge
against him.” _Abney_ v. _United States_, 431 U. S. 651, 659
(1977) (allowing interlocutory appeal of rejection of double
jeopardy defense). He instead contests whether the Constitution allows Congress to criminalize the alleged conduct, a
question that is “collateral to, and separable from” his guilt
or innocence. _Ibid_ . Moreover, the President’s Executive
Branch authority “would be significantly undermined if appellate review” of the constitutional challenge “were postponed until after conviction and sentence.” _Id_ ., at 660; see
also _Helstoski_ v. _Meanor_, 442 U. S. 500, 507 (1979) (allowing interlocutory appeal of refusal to dismiss an indictment
on Speech or Debate Clause grounds). The prospect of a
trial court erroneously allowing the prosecution to proceed
poses a unique danger to the “independence of the Executive Branch.” _Trump_ v. _Vance_, 591 U. S. 786, 800 (2020).
As the Court explains, the possibility that the President
will be made to defend his official conduct before a jury after
he leaves office could distort his decisions while in office.
_Ante_, at 13–14, 36. These Article II concerns do not insulate
the President from prosecution. But they do justify interlocutory review of the trial court’s final decision on the President’s as-applied constitutional challenge. See _Helstoski_,
442 U. S., at 507–508; _Abney_, 431 U. S., at 659–661; see also
Reply Brief for United States in No. 23–624, p. 5 (agreeing
that the President “has a right to an interlocutory appeal
from the district court’s rejection of his immunity defense”).

I understand most of the Court’s opinion to be consistent
with these views. I do not join Part III–C, however, which
holds that the Constitution limits the introduction of protected conduct as _evidence_ in a criminal prosecution of a
President, beyond the limits afforded by executive privilege.
See _ante_, at 30–32. I disagree with that holding; on this


---

6 TRUMP _v._ UNITED STATES


BARRETT, J., concurring in part


score, I agree with the dissent. See _post_, at 25–27
(SOTOMAYOR, J., dissenting). The Constitution does not require blinding juries to the circumstances surrounding conduct for which Presidents _can_ be held liable. Consider a
bribery prosecution—a charge not at issue here but one that
provides a useful example. The federal bribery statute forbids any public official to seek or accept a thing of value “for
or because of any official act.” 18 U. S. C. §201(c). The Constitution, of course, does not authorize a President to seek
or accept bribes, so the Government may prosecute him if
he does so. See Art. II, §4 (listing “Bribery” as an impeachable offense); see also Memorandum from L. Silberman,
Deputy Atty. Gen., to R. Burress, Office of the President,
Re: Conflict of Interest Problems Arising Out of the President’s Nomination of Nelson A. Rockefeller To Be Vice President Under the Twenty-Fifth Amendment to the Constitution 5 (Aug. 28, 1974) (suggesting that the federal bribery
statute applies to the President). Yet excluding from trial
any mention of the official act connected to the bribe would
hamstring the prosecution. To make sense of charges alleging a _quid pro quo_, the jury must be allowed to hear about
both the _quid_ and the _quo_, even if the _quo_, standing alone,
could not be a basis for the President’s criminal liability.

I appreciate the Court’s concern that allowing into evidence official acts for which the President cannot be held
criminally liable may prejudice the jury. _Ante_, at 31. But
the rules of evidence are equipped to handle that concern
on a case-by-case basis. Most importantly, a trial court can
exclude evidence of the President’s protected conduct “if its
probative value is substantially outweighed by a danger of
. . . unfair prejudice” or “confusing the issues.” Fed. Rule
Evid. 403; see also Rule 105 (requiring the court to “restrict
the evidence to its proper scope and instruct the jury accordingly”). The balance is more likely to favor admitting
evidence of an official act in a bribery prosecution, for instance, than one in which the protected conduct has little


---

Cite as: 603 U. S. ____ (2024) 7


BARRETT, J., concurring in part


connection to the charged offense. And if the evidence
comes in, the trial court can instruct the jury to consider it
only for lawful purposes. See _Richardson_ v. _Marsh_, 481
U. S. 200, 206–207 (1987). I see no need to depart from that
familiar and time-tested procedure here.


              -               -               The Constitution does not insulate Presidents from criminal liability for official acts. But _any_ statute regulating the
exercise of executive power is subject to a constitutional
challenge. See, _e_ . _g_ ., _Collins_ v. _Yellen_, 594 U. S. 220, 235–
236 (2021); _Zivotofsky_ v. _Clinton_, 566 U. S. 189, 192–194
(2012); _Free Enterprise Fund_ v. _Public Company Accounting_
_Oversight Bd._, 561 U. S. 477, 487–488 (2010). A criminal
statute is no exception. Thus, a President facing prosecution may challenge the constitutionality of a criminal statute as applied to official acts alleged in the indictment. If
that challenge fails, however, he must stand trial.


---

Cite as: 603 U. S. ____ (2024) 1


SOTOMAYOR, J., dissenting

# **SUPREME COURT OF THE UNITED STATES**

_________________


No. 23–939

_________________

DONALD J. TRUMP, PETITIONER _v._
UNITED STATES


ON WRIT OF CERTIORARI TO THE UNITED STATES COURT OF
APPEALS FOR THE DISTRICT OF COLUMBIA CIRCUIT


[July 1, 2024]


JUSTICE SOTOMAYOR, with whom JUSTICE KAGAN and
JUSTICE JACKSON join, dissenting.

Today’s decision to grant former Presidents criminal immunity reshapes the institution of the Presidency. It makes
a mockery of the principle, foundational to our Constitution
and system of Government, that no man is above the law.
Relying on little more than its own misguided wisdom about
the need for “bold and unhesitating action” by the President, _ante,_ at 3, 13, the Court gives former President Trump
all the immunity he asked for and more. Because our Constitution does not shield a former President from answering
for criminal and treasonous acts, I dissent.

I
The indictment paints a stark portrait of a President desperate to stay in power.
In the weeks leading up to January 6, 2021, thenPresident Trump allegedly “spread lies that there had been
outcome-determinative fraud in the election and that he
had actually won,” App. 181, Indictment ¶2, despite being
“notified repeatedly” by his closest advisers “that his claims
were untrue,” _id_ ., at 188, ¶11.
When dozens of courts swiftly rejected these claims,
Trump allegedly “pushed officials in certain states to ignore
the popular vote; disenfranchise millions of voters; dismiss


---

2 TRUMP _v._ UNITED STATES


SOTOMAYOR, J., dissenting


legitimate electors; and ultimately, cause the ascertainment of and voting by illegitimate electors” in his favor. _Id_ .,
at 185–186, ¶10(a). It is alleged that he went so far as to
threaten one state election official with criminal prosecution if the official did not “‘find’ 11,780 votes” Trump needed
to change the election result in that state. _Id_ ., at 202,
¶31(f ). When state officials repeatedly declined to act outside their legal authority and alter their state election processes, Trump and his co-conspirators purportedly developed a plan to disrupt and displace the legitimate election
certification process by organizing fraudulent slates of electors. See _id_ ., at 208–209, ¶¶53–54.

As the date of the certification proceeding neared, Trump
allegedly also sought to “use the power and authority of the
Justice Department” to bolster his knowingly false claims
of election fraud by initiating “sham election crime investigations” and sending official letters “falsely claim[ing] that
the Justice Department had identified significant concerns
that may have impacted the election outcome” while
“falsely present[ing] the fraudulent electors as a valid alternative to the legitimate electors.” _Id_ ., at 186–187, ¶10(c).
When the Department refused to do as he asked, Trump
turned to the Vice President. Initially, he sought to persuade the Vice President “to use his ceremonial role at the
January 6 certification proceeding to fraudulently alter the
election results.” _Id_ ., at 187, ¶10(d). When persuasion
failed, he purportedly “attempted to use a crowd of supporters that he had gathered in Washington, D. C., to pressure
the Vice President to fraudulently alter the election results.” _Id_ ., at 221, ¶86.

Speaking to that crowd on January 6, Trump “falsely
claimed that, based on fraud, the Vice President could alter
the outcome of the election results.” _Id_ ., at 229, ¶104(a).
When this crowd then “violently attacked the Capitol and
halted the proceeding,” _id_ ., at 188, ¶10(e), Trump allegedly


---

Cite as: 603 U. S. ____ (2024) 3


SOTOMAYOR, J., dissenting


delayed in taking any step to rein in the chaos he had unleashed. Instead, in a last desperate ploy to hold onto
power, he allegedly “attempted to exploit the violence and
chaos at the Capitol” by pressuring lawmakers to delay the
certification of the election and ultimately declare him the
winner. _Id_ ., at 233, ¶119. That is the backdrop against
which this case comes to the Court.

II
The Court now confronts a question it has never had to
answer in the Nation’s history: Whether a former President
enjoys immunity from federal criminal prosecution. The
majority thinks he should, and so it invents an atextual,
ahistorical, and unjustifiable immunity that puts the President above the law.
The majority makes three moves that, in effect, completely insulate Presidents from criminal liability. First,
the majority creates absolute immunity for the President’s
exercise of “core constitutional powers.” _Ante,_ at 6. This
holding is unnecessary on the facts of the indictment, and
the majority’s attempt to apply it to the facts expands the
concept of core powers beyond any recognizable bounds. In
any event, it is quickly eclipsed by the second move, which
is to create expansive immunity for all “official act[s].”
_Ante,_ at 14. Whether described as presumptive or absolute,
under the majority’s rule, a President’s use of any official
power for any purpose, even the most corrupt, is immune
from prosecution. That is just as bad as it sounds, and it is
baseless. Finally, the majority declares that evidence concerning acts for which the President is immune can play no
role in any criminal prosecution against him. See _ante,_ at
30–32. That holding, which will prevent the Government
from using a President’s official acts to prove knowledge or
intent in prosecuting private offenses, is nonsensical.
Argument by argument, the majority invents immunity


---

4 TRUMP _v._ UNITED STATES


SOTOMAYOR, J., dissenting


through brute force. Under scrutiny, its arguments crumble. To start, the majority’s broad “official acts” immunity
is inconsistent with text, history, and established understandings of the President’s role. See Part III, _infra_ . Moreover, it is deeply wrong, even on its own functionalist terms.
See Part IV, _infra_ . Next, the majority’s “core” immunity is
both unnecessary and misguided. See Part V, _infra_ . Furthermore, the majority’s illogical evidentiary holding is unprecedented. See Part VI, _infra_ . Finally, this majority’s
project will have disastrous consequences for the Presidency and for our democracy. See Part VII, _infra_ .

III
The main takeaway of today’s decision is that all of a
President’s official acts, defined without regard to motive or
intent, are entitled to immunity that is “at least . . . _pre-_
_sumptive_,” and quite possibly “absolute.” _Ante,_ at 14.
Whenever the President wields the enormous power of his
office, the majority says, the criminal law (at least presumptively) cannot touch him. This official-acts immunity
has “no firm grounding in constitutional text, history, or
precedent.” _Dobbs_ v. _Jackson Women’s Health Organiza-_
_tion_, 597 U. S. 215, 280 (2022). Indeed, those “standard
grounds for constitutional decisionmaking,” _id_ ., at 279, all
point in the opposite direction. No matter how you look at
it, the majority’s official-acts immunity is utterly indefensible.

A
The majority calls for a “careful assessment of the scope
of Presidential power under the Constitution.” _Ante,_ at 5.
For the majority, that “careful assessment” does not involve
the Constitution’s text. I would start there.
The Constitution’s text contains no provision for immunity from criminal prosecution for former Presidents. Of
course, “the silence of the Constitution on this score is not


---

Cite as: 603 U. S. ____ (2024) 5


SOTOMAYOR, J., dissenting


dispositive.” _United States_ v. _Nixon_, 418 U. S. 683, 706,
n. 16 (1974). Insofar as the majority rails against the notion that a “‘specific textual basis’” is required, _ante,_ at 37
(quoting _Nixon_ v. _Fitzgerald_, 457 U. S. 731, 750, n. 31
(1982)), it is attacking an argument that has not been made
here. The omission in the text of the Constitution is worth
noting, however, for at least three reasons.

First, the Framers clearly knew how to provide for immunity from prosecution. They did provide a narrow immunity for legislators in the Speech or Debate Clause. See
Art. I, §6, cl. 1 (“Senators and Representatives . . . shall in
all Cases, except Treason, Felony and Breach of the Peace,
be privileged from Arrest during their Attendance at the
Session of their respective Houses, and in going to and returning from the same; and for any Speech or Debate in either House, they shall not be questioned in any other
Place”). They did not extend the same or similar immunity
to Presidents.

Second, “some state constitutions at the time of the Framing specifically provided ‘express criminal immunities’ to
sitting governors.” Brief for Scholars of Constitutional Law
as _Amici Curiae_ 4 (quoting S. Prakash, Prosecuting and
Punishing Our Presidents, 100 Tex. L. Rev. 55, 69 (2021)).
The Framers chose not to include similar language in the
Constitution to immunize the President. If the Framers
“had wanted to create some constitutional privilege to
shield the President . . . from criminal indictment,” they
could have done so. Memorandum from R. Rotunda to K.
Starr re: Indictability of the President 18 (May 13, 1998).
They did not.

Third, insofar as the Constitution does speak to this question, it actually contemplates some form of criminal liability
for former Presidents. The majority correctly rejects
Trump’s argument that a former President cannot be prosecuted unless he has been impeached by the House and convicted by the Senate for the same conduct. See _ante,_ at 32–


---

6 TRUMP _v._ UNITED STATES


SOTOMAYOR, J., dissenting


34; Part IV–C, _infra_ . The majority ignores, however, that
the Impeachment Judgment Clause cuts against its own position. That Clause presumes the availability of criminal
process as a backstop by establishing that an official impeached and convicted by the Senate “shall _nevertheless_ be
liable and subject to Indictment, Trial, Judgment and Punishment, according to Law.” Art. I, §3, cl. 7 (emphasis
added). That Clause clearly contemplates that a former
President may be subject to criminal prosecution for the
same conduct that resulted (or could have resulted) in an
impeachment judgment—including conduct such as “Bribery,” Art. II, §4, which implicates official acts almost by definition. [1 ]

B
Aware of its lack of textual support, the majority points
out that this Court has “recognized Presidential immunities
and privileges ‘rooted in the constitutional tradition of the
separation of powers and supported by our history.’” _Ante_,
at 10 (quoting _Fitzgerald_, 457 U. S., at 749). That is true,
as far as it goes. Nothing in our history, however, supports
the majority’s entirely novel immunity from criminal prosecution for official acts.
The historical evidence that exists on Presidential immunity from criminal prosecution cuts decisively against it.
For instance, Alexander Hamilton wrote that former Presidents would be “liable to prosecution and punishment in the
ordinary course of law.” The Federalist No. 69, p. 452 (J.
Harv. Lib. ed. 2009). For Hamilton, that was an important
distinction between “the king of Great Britain,” who was
“sacred and inviolable,” and the “President of the United
States,” who “would be amenable to personal punishment


——————

1 Article II, §4, provides: “The President, Vice President and all Civil
Officers of the United States, shall be removed from Office on Impeachment for and Conviction of, Treason, Bribery, or other high Crimes and
Misdemeanors.”


---

Cite as: 603 U. S. ____ (2024) 7


SOTOMAYOR, J., dissenting


and disgrace.” _Id_ ., at 458. In contrast to the king, the President should be subject to “personal responsibility” for his
actions, “stand[ing] upon no better ground than a governor
of New York, and upon worse ground than the governors of
Maryland and Delaware,” whose State Constitutions gave
them some immunity. _Id_ ., at 452.

At the Constitutional Convention, James Madison, who
was aware that some state constitutions provided governors immunity, proposed that the Convention “conside[r]
what privileges ought to be allowed to the Executive.” 2
Records of the Federal Convention of 1787, p. 503 (M. Farrand ed. 1911). There is no record of any such discussion.
_Ibid._ Delegate Charles Pinckney later explained that “[t]he
Convention which formed the Constitution well knew” that
“no subject had been more abused than privilege,” and so it
“determined to . . . limi[t] privilege to what was necessary,
and no more.” 3 _id._, at 385. “No privilege . . . was intended
for [the] Executive.” _Ibid._ [2 ]

Other commentators around the time of the Founding observed that federal officials had no immunity from prosecution, drawing no exception for the President. James Wilson
recognized that federal officers who use their official powers
to commit crimes “may be tried by their country; and if their
criminality is established, the law will punish. A grand jury
may present, a petty jury may convict, and the judges will
pronounce the punishment.” 2 Debates on the Constitution
177 (J. Elliot ed. 1836). A few decades later, Justice Story
evinced the same understanding. He explained that, when


——————

2 To note, as the majority does, see _ante_, at 39, that this Court has recognized civil immunities arguably inconsistent with this view is not to
say that Pinckney was wrong about what the Framers had “intended.”
Indeed, Pinckney’s contemporaries shared the same view during the ratification debates. See, _e.g._, 4 Debates on the Constitution 109 (J. Elliot
ed. 1836) (J. Iredell) (“If the President does a single act by which the
people are prejudiced, he is punishable himself. . . . If he commits any
crime, he is punishable by the laws of his country”).


---

8 TRUMP _v._ UNITED STATES


SOTOMAYOR, J., dissenting


a federal official commits a crime in office, “it is indispensable, that provision should be made, that the common tribunals of justice should be at liberty to entertain jurisdiction
of the offence, for the purpose of inflicting, the common punishment applicable to unofficial offenders.” 2 Commentaries on the Constitution of the United States §780,
pp. 250–251 (1833). Without a criminal trial, he explained,
“the grossest official offenders might escape without any
substantial punishment, even for crimes, which would subject their fellow citizens to capital punishment.” _Id_ ., at 251.

This historical evidence reinforces that, from the very beginning, the presumption in this Nation has always been
that no man is free to flout the criminal law. The majority
fails to recognize or grapple with the lack of historical evidence for its new immunity. With nothing on its side of the
ledger, the most the majority can do is claim that the historical evidence is a wash. See _ante,_ at 38–39. It claims
that the Court previously has described the “relevant historical evidence on the question of Presidential immunity”
as “‘fragmentary’” and not worthy of consideration. _Ante,_
at 38 (quoting _Fitzgerald_, 457 U. S., at 752, n. 31). Yet the
Court has described only the evidence regarding “the President’s immunity _from damages liability_ ” as “fragmentary.”
_Fitzgerald_, 457 U. S., at 751–752, n. 31 (emphasis added).
Moreover, far from dismissing that evidence as irrelevant,
the _Fitzgerald_ Court was careful to note that “[t]he best historical evidence clearly support[ed]” the immunity from
damages liability that it recognized, and it relied in part on
that historical evidence to overcome the lack of any textual
basis for its immunity. _Id_ ., at 152, n. 31. The majority ignores this reliance. It seems history matters to this Court
only when it is convenient. See, _e_ . _g_ ., _New York State Rifle_
_& Pistol Assn., Inc._ v. _Bruen_, 597 U. S. 1 (2022); _Dobbs_, 597
U. S. 215.


---

Cite as: 603 U. S. ____ (2024) 9


SOTOMAYOR, J., dissenting


C
Our country’s history also points to an established understanding, shared by both Presidents and the Justice Department, that former Presidents are answerable to the
criminal law for their official acts. Cf. _Chiafalo_ v. _Washing-_
_ton_, 591 U. S. 578, 592–593 (2020) (“‘Long settled and established practice’ may have ‘great weight in a proper interpretation of constitutional provisions’” (quoting _The_
_Pocket Veto Case_, 279 U. S. 655, 689 (1929))). Consider Watergate, for example. After the Watergate tapes revealed
President Nixon’s misuse of official power to obstruct the
Federal Bureau of Investigation’s investigation of the Watergate burglary, President Ford pardoned Nixon. Both
Ford’s pardon and Nixon’s acceptance of the pardon necessarily “rested on the understanding that the former President faced potential criminal liability.” Brief for United
States 15; see also Public Papers of the Presidents, Gerald
R. Ford, Vol. 1, Sept. 8, 1974, p. 103 (1975) (granting former
President Nixon a “full, free, and absolute pardon . . . for all
offenses against the United States which he . . . has committed or may have committed or taken part in during” his
Presidency); R. Nixon, Statement by Former President
Richard Nixon to P. Buchen, Counsel to President Ford,
p. 1 (Sept. 8, 1974) (accepting “full and absolute pardon for
any charges which might be brought against me for actions
taken during the time I was President of the United
States”).

Subsequent special counsel and independent counsel investigations have also operated on the assumption that the
Government can criminally prosecute former Presidents for
their official acts, where they violate the criminal law. See,
_e_ . _g_ ., 1 L. Walsh, Final Report of the Independent Counsel
for Iran/Contra Matters: Investigations and Prosecutions
445 (1993) (“[B]ecause a President, and certainly a past
President, is subject to prosecution . . . the conduct of Pres


---

10 TRUMP _v._ UNITED STATES


SOTOMAYOR, J., dissenting


ident Reagan in the Iran/contra matter was reviewed by Independent Counsel against the applicable statutes. It was
concluded that [his] conduct fell well short of criminality
which could be successfully prosecuted”).

Indeed, Trump’s own lawyers during his second impeachment trial assured Senators that declining to impeach
Trump for his conduct related to January 6 would not leave
him “in any way above the law.” 2 Proceedings of the U. S.
Senate in the Impeachment Trial of Donald John Trump, S.
Doc. 117–2, p. 144 (2021). They insisted that a former President “is like any other citizen and can be tried in a court of
law.” _Ibid._ ; see also 1 _id_ ., S. Doc. 117–3, at 339 (Trump’s
impeachment counsel stating that “no former officeholder
is immune” from the judicial process “for investigation,
prosecution, and punishment”); _id_ ., at 322–323 (Trump’s
impeachment counsel stating: “If my colleagues on this side
of the Chamber actually think that President Trump committed a criminal offense . . . [a]fter he is out of office, you
go and arrest him”). Now that Trump is facing criminal
charges for those acts, though, the tune has changed. Being
treated “like any other citizen” no longer seems so appealing.

In sum, the majority today endorses an expansive vision
of Presidential immunity that was never recognized by the
Founders, any sitting President, the Executive Branch, or
even President Trump’s lawyers, until now. Settled understandings of the Constitution are of little use to the majority
in this case, and so it ignores them.

IV
A
Setting aside this evidence, the majority announces that
former Presidents are “absolute[ly],” or “at least . . . presumptive[ly],” immune from criminal prosecution for all of
their official acts. _Ante,_ at 14 (emphasis omitted). The majority purports to keep us in suspense as to whether this


---

Cite as: 603 U. S. ____ (2024) 11


SOTOMAYOR, J., dissenting


immunity is absolute or presumptive, but it quickly gives
up the game. It explains that, “[a]t a minimum, the President must . . . be immune from prosecution for an official
act unless the Government can show that applying a criminal prohibition to that act would pose _no ‘dangers of intru-_
_sion_ on the authority and functions of the Executive
Branch.’” _Ibid._ (emphasis added). No dangers, none at all.
It is hard to imagine a criminal prosecution for a President’s
official acts that would pose no dangers of intrusion on Presidential authority in the majority’s eyes. Nor should that
be the standard. Surely some intrusions on the Executive
may be “justified by an overriding need to promote objectives within the constitutional authority of Congress.”
_Nixon_ v. _Administrator of General Services_, 433 U. S. 425,
443 (1977). Other intrusions may be justified by the “primary constitutional duty of the Judicial Branch to do justice
in criminal prosecutions.” _United States_ v. _Nixon_, 418 U. S.
683, 707 (1974). According to the majority, however, any
incursion on Executive power is too much. When presumptive immunity is this conclusive, the majority’s indecision
as to “whether [official-acts] immunity must be absolute” or
whether, instead, “presumptive immunity is sufficient,”
_ante,_ at 6, hardly matters.

Maybe some future opinion of this Court will decide that
presumptive immunity is “sufficient,” _ibid._, and replace the
majority’s ironclad presumption with one that makes the
difference between presumptive and absolute immunity
meaningful. Today’s Court, however, has replaced a presumption of equality before the law with a presumption
that the President is above the law for all of his official acts.

Quick on the heels of announcing this astonishingly
broad official-acts immunity, the majority assures us that a
former President can still be prosecuted for “unofficial acts.”
_Ante,_ at 15. Of course he can. No one has questioned the
ability to prosecute a former President for unofficial (other


---

12 TRUMP _v._ UNITED STATES


SOTOMAYOR, J., dissenting


wise known as private) acts. Even Trump did not claim immunity for such acts and, as the majority acknowledges,
such an immunity would be impossible to square with _Clin-_
_ton_ v. _Jones_, 520 U. S. 681 (1997). See _ante_, at 15. This
unremarkable proposition is no real limit on today’s decision. It does not hide the majority’s embrace of the most
far-reaching view of Presidential immunity on offer.

In fact, the majority’s dividing line between “official” and
“unofficial” conduct narrows the conduct considered “unofficial” almost to a nullity. It says that whenever the President acts in a way that is “‘not manifestly or palpably beyond [his] authority,’” he is taking official action. _Ante,_ at
17 (quoting _Blassingame_ v. _Trump_, 87 F. 4th 1, 13 (CADC
2023)). It then goes a step further: “In dividing official from
unofficial conduct, courts may not inquire into the President’s motives.” _Ante,_ at 18. It is one thing to say that motive is irrelevant to questions regarding the scope of civil
liability, but it is quite another to make it irrelevant to
questions regarding criminal liability. Under that rule, any
use of official power for any purpose, even the most corrupt
purpose indicated by objective evidence of the most corrupt
motives and intent, remains official and immune. Under
the majority’s test, if it can be called a test, the category of
Presidential action that can be deemed “unofficial” is destined to be vanishingly small.

Ultimately, the majority pays lip service to the idea that
“[t]he President, charged with enforcing federal criminal
laws, is not above them,” _ante,_ at 13–14, but it then proceeds to place former Presidents beyond the reach of the
federal criminal laws for any abuse of official power.

B
So how does the majority get to its rule? With text, history, and established understanding all weighing against it,
the majority claims just one arrow in its quiver: the balancing test in _Nixon_ v. _Fitzgerald_, 457 U. S. 731 (1983). Yet


---

Cite as: 603 U. S. ____ (2024) 13


SOTOMAYOR, J., dissenting


even that test cuts against it. The majority concludes that
official-acts immunity “is required to safeguard the independence and effective functioning of the Executive
Branch,” _ante,_ at 14, by rejecting that Branch’s own protestations that such immunity is not at all required and would
in fact be harmful, see Brief for United States 18–24, 29–
30. In doing so, it decontextualizes _Fitzgerald_ ’s language,
ignores important qualifications, and reaches a result that
the _Fitzgerald_ Court never would have countenanced.

In _Fitzgerald_, plaintiff A. Ernest Fitzgerald sued thenformer President Nixon for money damages. He claimed
that, while in office, Nixon had been involved in unlawfully
firing him from his government job. See 457 U. S., at 733–
741. The question for the Court was whether a former President had immunity from such a civil suit. The Court explained that it was “settled law that the separation-ofpowers doctrine does not bar every exercise of jurisdiction
over the President of the United States.” _Id_ ., at 753–754.
To determine whether a particular type of suit against a
President (or former President) could be heard, a court
“must balance the constitutional weight of the interest to be
served against the dangers of intrusion on the authority
and functions of the Executive Branch.” _Id_ ., at 754. The
Court explained that, “[w]hen judicial action is needed to
serve broad public interests—as when the Court acts, not
in derogation of the separation of powers, but to maintain
their proper balance, or to vindicate the public interest in
an ongoing criminal prosecution—the exercise of jurisdiction has been held warranted.” _Ibid._ (citations omitted).

On the facts before it, the Court concluded that a “merely
private suit for damages based on a President’s official acts”
did not serve those interests. _Ibid._ The Court reasoned
that the “visibility of [the President’s] office and the effect
of his actions on countless people” made him an easy target
for civil suits that “frequently could distract [him] from his


---

14 TRUMP _v._ UNITED STATES


SOTOMAYOR, J., dissenting


public duties.” _Id_ ., at 753. The public interest in such private civil suits, the Court concluded, was comparatively
weak. See _id_ ., at 754, n. 37 (“[T]here is a lesser public interest in actions for civil damages than, for example, in
criminal prosecutions”). Therefore, the Court held that a
former President was immune from such suits. _Ibid._

In the context of a federal criminal prosecution of a former President, however, the danger to the functioning of
the Executive Branch is much reduced. Further, as every
member of the _Fitzgerald_ Court acknowledged, see Part IV–
B–2, _infra_, the public interest in a criminal prosecution is
far weightier. Applying the _Fitzgerald_ balancing here
should yield the opposite result. Instead, the majority
elides any difference between civil and criminal immunity,
granting Trump the same immunity from criminal prosecution that Nixon enjoyed from an unlawful termination suit.
That is plainly wrong.

1
The majority relies almost entirely on its view of the danger of intrusion on the Executive Branch, to the exclusion
of the other side of the balancing test. Its analysis rests on
a questionable conception of the President as incapable of
navigating the difficult decisions his job requires while
staying within the bounds of the law. It also ignores the
fact that he receives robust legal advice on the lawfulness
of his actions.
The majority says that the danger “of intrusion on the
authority and functions of the Executive Branch” posed by
criminally prosecuting a former President for official conduct “is akin to, indeed greater than, what led us to recognize absolute Presidential immunity from civil damages liability—that the President would be chilled from taking the
‘bold and unhesitating action’ required of an independent
Executive.” _Ante,_ at 13 (quoting _Fitzgerald_, 457 U. S., at
745). It is of course important that the President be able to


---

Cite as: 603 U. S. ____ (2024) 15


SOTOMAYOR, J., dissenting


“‘“deal fearlessly and impartially with” the duties of his office.’” _Ante,_ at 10 (quoting _Fitzgerald_, 457 U. S., at 752). If
every action the President takes exposes him personally to
vexatious private litigation, the possibility of hamstringing
Presidential decisionmaking is very real. Yet there are
many facets of criminal liability, which the majority discounts, that make it less likely to chill Presidential action
than the threat of civil litigation.

First, in terms of probability, the threat of criminal liability is much smaller. In _Fitzgerald_, the threat of vexatious civil litigation loomed large. The Court observed that,
given the “visibility of his office and the effect of his actions
on countless people, the President would be an easily identifiable target for suits for civil damages.” _Id_ ., at 753. Although “‘the effect of [the President’s] actions on countless
people’ could result in untold numbers of private plaintiffs
suing for damages based on any number of Presidential
acts” in the civil context, the risk in the criminal context is
“only that a former President may face one federal prosecution, in one jurisdiction, for each criminal offense allegedly
committed while in office.” 2023 WL 8359833, *9 (DC, Dec.
1, 2023) (quoting _Fitzgerald_, 457 U. S., at 753). The majority’s bare assertion that the burden of exposure to federal
criminal prosecution is more limiting to a President than
the burden of exposure to civil suits does not make it true,
and it is not persuasive.

Second, federal criminal prosecutions require “robust
procedural safeguards” not found in civil suits. 2023 WL
8359833, *10. The criminal justice system has layers of protections that “filter out insubstantial legal claims,” whereas
civil litigation lacks “analogous checks.” _Cheney_ v. _United_
_States Dist. Court for_ _D. C._, 542 U. S. 367, 386 (2004). To
start, Justice Department policy requires scrupulous and
impartial prosecution, founded on both the facts and the
law. See generally Dept. of Justice, Justice Manual §9–
27.000 (Principles of Federal Prosecution) (June 2023). The


---

16 TRUMP _v._ UNITED STATES


SOTOMAYOR, J., dissenting


grand jury provides an additional check on felony prosecutions, acting as a “buffer or referee between the Government and the people,” to ensure that the charges are wellfounded. _United States_ v. _Williams_, 504 U. S. 36, 47 (1992);
see also _Harlow_ v. _Fitzgerald_, 457 U. S. 800, 826, n. 6 (1982)
(Burger, C. J., dissenting) (“[A] criminal prosecution cannot
be commenced absent careful consideration by a grand jury
at the request of a prosecutor; the same check is not present
with respect to the commencement of civil suits in which
advocates are subject to no realistic accountability”).

If the prosecution makes it past the grand jury, then the
former President still has all the protections our system
provides to criminal defendants. If the former President
has an argument that a particular statute is unconstitutional as applied to him, then he can move to dismiss the
charges on that ground. Indeed, a former President is likely
to have legal arguments that would be unavailable to the
average criminal defendant. For example, he may be able
to rely on a public-authority exception from particular criminal laws, [3] or an advice-of-the-Attorney-General defense,
see Tr. of Oral Arg. 107–108. [4 ]


——————

3 See _Nardone_ v. _United States_, 302 U. S. 379, 384 (1937) (explaining
that public officers may be “impliedly excluded from [statutory] language
embracing all persons” if reading the statute to include such officers
“would work obvious absurdity as, for example, the application of a speed
law to a policeman pursuing a criminal or the driver of a fire engine responding to an alarm”); see also Memorandum from D. Barron, Acting
Assistant Atty. Gen., Office of Legal Counsel, to E. Holder, Atty. Gen.,
Re: Applicability of Federal Criminal Laws and the Constitution to Contemplated Lethal Operations Against Shaykh Anwar al-Aulaqi 12 (July
16, 2010) (interpreting criminal statute prohibiting unlawful killings “to
incorporate the public authority justification, which can render lethal action carried out by a government official lawful in some circumstances”).

4 Trump did not raise those defenses in this case, and the immunity
that the majority has created likely will obviate the need to raise them
in future cases. Yet those defenses would have protected former Presidents from unwarranted criminal prosecutions much more precisely
than the blanket immunity the majority creates today.


---

Cite as: 603 U. S. ____ (2024) 17


SOTOMAYOR, J., dissenting


If the case nonetheless makes it to trial, the Government
will bear the burden of proving every element of the alleged
crime beyond a reasonable doubt to a unanimous jury of the
former President’s fellow citizens. See _United States_ v.
_Gaudin_, 515 U. S. 506, 510 (1995). If the Government manages to overcome even that significant hurdle, then the former President can appeal his conviction, and the appellate
review of his claims will be “‘particularly meticulous.’”
_Trump_ v. _Vance_, 591 U. S. 786, 809 (2020) (quoting _Nixon_,
418 U. S., at 702). He can ultimately seek this Court’s review, and if past practice (including in this case) is any indication, he will receive it.

In light of these considerable protections, the majority’s
fear that “‘bare allegations of malice,’” _ante,_ at 18 (alteration omitted), would expose former Presidents to trial and
conviction is unfounded. Bare allegations of malice would
not make it out of the starting gate. Although a private civil
action may be brought based on little more than “‘intense
feelings,’” _ante,_ at 11 (quoting _Fitzgerald_, 457 U. S., at 752),
a federal criminal prosecution is made of firmer stuff. Certainly there has been, on occasion, great feelings of animosity between incoming and outgoing Presidents over the
course of our country’s history. Yet it took allegations as
grave as those at the center of this case to have the first
federal criminal prosecution of a former President. That
restraint is telling.

Third, because of longstanding interpretations by the Executive Branch, every sitting President has so far believed
himself under the threat of criminal liability after his term
in office and nevertheless boldly fulfilled the duties of his
office. The majority insists that the threat of criminal sanctions is “more likely to distort Presidential decisionmaking
than the potential payment of civil damages.” _Ante,_ at 13.
If that is right, then that distortion has been shaping Presidential decisionmaking since the earliest days of the Republic. Although it makes sense to avoid “diversion of the


---

18 TRUMP _v._ UNITED STATES


SOTOMAYOR, J., dissenting


President’s attention during the decisionmaking process”
with “needless worry,” _Clinton_, 520 U. S., at 694, n. 19, one
wonders why requiring some small amount of his attention
(or his legal advisers’ attention) to go towards complying
with federal criminal law is such a great burden. If the
President follows the law that he must “take Care” to execute, Art. II, §3, he has not been rendered “‘unduly cautious,’” _ante,_ at 10 (quoting _Fitzgerald_, 457 U. S., at 752,
n. 32). Some amount of caution is necessary, after all. It is
a far greater danger if the President feels empowered to violate federal criminal law, buoyed by the knowledge of future immunity. I am deeply troubled by the idea, inherent
in the majority’s opinion, that our Nation loses something
valuable when the President is forced to operate within the
confines of federal criminal law.

So what exactly is the majority worried about deterring
when it expresses great concern for the “deterrent” effect
that “the threat of trial, judgment, and imprisonment”
would pose? _Ante,_ at 13. It cannot possibly be the deterrence of acts that are truly criminal. Nor does it make sense
for the majority to wring its hands over the possibility that
Presidents might stop and think carefully before taking action that borders on criminal. Instead, the majority’s main
concern could be that Presidents will be deterred from taking necessary and lawful action by the fear that their successors might pin them with a baseless criminal prosecution—a prosecution that would almost certainly be doomed
to fail, if it even made it out of the starting gate. See _ante,_
at 40. The Court should not have so little faith in this Nation’s Presidents. As this Court has said before in the context of criminal proceedings, “‘[t]he chance that now and
then there may be found some timid soul who will take
counsel of his fears and give way to their repressive power
is too remote and shadowy to shape the course of justice.’”
_Nixon_, 418 U. S., at 712, n. 20 (quoting _Clark_ v. _United_
_States_, 289 U. S. 1, 16 (1933)). The concern that countless


---

Cite as: 603 U. S. ____ (2024) 19


SOTOMAYOR, J., dissenting


(and baseless) civil suits would hamper the Executive may
have been justified in _Fitzgerald_, but a well-founded federal
criminal prosecution poses no comparable danger to the
functioning of the Executive Branch.

2
At the same time, the public interest in a federal criminal
prosecution of a former President is vastly greater than the
public interest in a private individual’s civil suit. All nine
Justices in _Fitzgerald_ explicitly recognized that distinction.
The five-Justice majority noted that there was a greater
public interest “in criminal prosecutions” than in “actions
for civil damages.” 457 U. S., at 754, n. 37. Chief Justice
Burger’s concurrence accordingly emphasized that the majority’s immunity was “limited to civil damages claims,” rather than “ _criminal_ prosecution.” _Id_ ., at 759–760. The four
dissenting Justices agreed that a “contention that the President is immune from criminal prosecution in the courts,” if
ever made, would not “be credible.” _Id_ ., at 780 (White, J.,
dissenting). At the very least, the _Fitzgerald_ Court did not
expect that its balancing test would lead to the same outcome in the criminal context.
The public’s interest in prosecution is transparent: a federal prosecutor herself acts on behalf of the United States.
Even the majority acknowledges that the “[f]ederal criminal laws seek to redress ‘a wrong to the public’ as a whole,
not just ‘a wrong to the individual,’” _ante,_ at 13 (quoting
_Huntington_ v. _Attrill_, 146 U. S. 657, 668 (1892)), such that
there is “a compelling ‘public interest in fair and effective
law enforcement,’” _ante,_ at 13 (quoting _Vance_, 591 U. S., at
808). Indeed, “our historic commitment to the rule of law”
is “nowhere more profoundly manifest than in our view that
. . . ‘guilt shall not escape or innocence suffer.’” _Nixon_, 418
U. S., at 708–709 (quoting _Berger_ v. _United States_, 295 U. S.
78, 88 (1935)).
The public interest in criminal prosecution is particularly


---

20 TRUMP _v._ UNITED STATES


SOTOMAYOR, J., dissenting


strong with regard to officials who are granted some degree
of civil immunity because of their duties. It is in those cases
where the public can see that officials exercising power under public trust remain on equal footing with their fellow
citizens under the criminal law. See, _e_ . _g_ ., _O’Shea_ v. _Little-_
_ton_, 414 U. S. 488, 503 (1974) (“[W]e have never held that
the performance of the duties of judicial, legislative, or executive officers, requires or contemplates the immunization
of otherwise criminal deprivations of constitutional
rights”); _Dennis_ v. _Sparks_, 449 U. S. 24, 31 (1980) (“[J]udicial immunity was not designed to insulate the judiciary
from all aspects of public accountability. Judges are immune from §1983 damages actions, but they are subject to
criminal prosecutions as are other citizens”); _Imbler_ v.
_Pachtman_, 424 U. S. 409, 428–429 (1976) (“We emphasize
that the [civil] immunity of prosecutors . . . does not leave
the public powerless to deter misconduct or to punish that
which occurs. This Court has never suggested that the policy considerations which compel civil immunity for certain
governmental officials also place them beyond the reach of
the criminal law. Even judges, cloaked with absolute civil
immunity for centuries, could be punished criminally”).

The public interest in the federal criminal prosecution of
a former President alleged to have used the powers of his
office to commit crimes may be greater still. “[T]he President . . . represent[s] all the voters in the Nation,” and his
powers are given by the people under our Constitution. _An-_
_derson_ v. _Celebrezze_, 460 U. S. 780, 795 (1983). When Presidents use the powers of their office for personal gain or as
part of a criminal scheme, every person in the country has
an interest in that criminal prosecution. The majority overlooks that paramount interest entirely.

Finally, the question of federal criminal immunity for a
former President “involves a countervailing Article II consideration absent in _Fitzgerald_ ”: recognizing such an im


---

Cite as: 603 U. S. ____ (2024) 21


SOTOMAYOR, J., dissenting


munity “would frustrate the Executive Branch’s enforcement of the criminal law.” Brief for United States 19. The
President is, of course, entrusted with “‘supervisory and
policy responsibilities of utmost discretion and sensitivity.’”
_Ante_ at 10 (quoting _Fitzgerald_, 457 U. S., at 750). One of
the most important is “enforcement of federal law,” as “it is
the President who is charged constitutionally to ‘take Care
that the Laws be faithfully executed.’” _Id._, at 750 (quoting
Art. II, §3). The majority seems to think that allowing former Presidents to escape accountability for breaking the
law while disabling the current Executive from prosecuting
such violations somehow respects the independence of the
Executive. It does not. Rather, it diminishes that independence, exalting occupants of the office over the office itself. There is a twisted irony in saying, as the majority
does, that the person charged with “tak[ing] Care that the
Laws be faithfully executed” can break them with impunity.

In the case before us, the public interest and countervailing Article II interest are particularly stark. The public interest in this criminal prosecution implicates both “[t]he
Executive Branch’s interest in upholding Presidential elections and vesting power in a new President under the Constitution” as well as “the voters’ interest in democratically
selecting their President.” 91 F. 4th 1173, 1195 (CADC
2024) ( _per curiam_ ). It also, of course, implicates Congress’s
own interest in regulating conduct through the criminal
law. Cf. _Fitzgerald_, 457 U. S., at 749, n. 27 (noting that the
case did not involve “affirmative action by Congress”). Yet
the majority believes that a President’s anxiety over prosecution overrides the public’s interest in accountability and
negates the interests of the other branches in carrying out
their constitutionally assigned functions. It is, in fact, the
majority’s position that “boil[s] down to ignoring the Constitution’s separation of powers.” _Ante,_ at 40.


---

22 TRUMP _v._ UNITED STATES


SOTOMAYOR, J., dissenting


C
Finally, in an attempt to put some distance between its
official-acts immunity and Trump’s requested immunity,
the majority insists that “Trump asserts a far broader immunity than the limited one [the majority has] recognized.”
_Ante_, at 32. If anything, the opposite is true. The only part
of Trump’s immunity argument that the majority rejects is
the idea that “the Impeachment Judgment Clause requires
that impeachment and Senate conviction precede a President’s criminal prosecution.” _Ibid._ That argument is obviously wrong. See _ante_, at 32–34. Rejecting it, however,
does not make the majority’s immunity narrower than
Trump’s. Inherent in Trump’s Impeachment Judgment
Clause argument is the idea that a former President who
was impeached in the House and convicted in the Senate
for crimes involving his official acts could then be prosecuted in court for those acts. See Brief for Petitioner 22
(“The Founders thus adopted a carefully balanced approach
that permits the criminal prosecution of a former President
for his official acts, but only if that President is first impeached by the House and convicted by the Senate”). By
extinguishing that path to overcoming immunity, however
nonsensical it might be, the majority arrives at an officialacts immunity even more expansive than the one Trump
argued for. On the majority’s view (but not Trump’s), a former President whose abuse of power was so egregious and
so offensive even to members of his own party that he was
impeached in the House and convicted in the Senate still
would be entitled to “at least presumptive” criminal immunity for those acts.

V
Separate from its official-acts immunity, the majority recognizes absolute immunity for “conduct within [the President’s] exclusive sphere of constitutional authority.” _Ante,_
at 9. Feel free to skip over those pages of the majority’s


---

Cite as: 603 U. S. ____ (2024) 23


SOTOMAYOR, J., dissenting


opinion. With broad official-acts immunity covering the
field, this ostensibly narrower immunity serves little purpose. In any event, this case simply does not turn on conduct within the President’s “exclusive sphere of constitutional authority,” and the majority’s attempt to apply a core
immunity of its own making expands the concept of “core
constitutional powers,” _ante,_ at 6, beyond any recognizable
bounds.

The idea of a narrow core immunity might have some intuitive appeal, in a case that actually presented the issue.
If the President’s power is “conclusive and preclusive” on a
given subject, then Congress should not be able to “ac[t]
upon the subject.” _Youngstown Sheet & Tube Co._ v. _Sawyer_,
343 U. S. 579, 638 (1952) (Jackson, J., concurring). In his
_Youngstown_ concurrence, Justice Robert Jackson posited
that the President’s “power of removal in executive agencies” seemed to fall within this narrow category. _Ibid_ ., n. 4.
Other decisions of this Court indicate that the pardon
power also falls in this category, see _United States_ v. _Klein_,
13 Wall. 128, 147 (1872) (“To the executive alone is intrusted the power of pardon; and it is granted without
limit”), as does the power to recognize foreign countries, see
_Zivotofsky_ v. _Kerry_, 576 U. S. 1, 32 (2015) (holding that the
President has “exclusive power . . . to control recognition determinations”).

In this case, however, the question whether a former
President enjoys a narrow immunity for the “exercise of his
core constitutional powers,” _ante,_ at 6, has never been at
issue, and for good reason: Trump was not criminally indicted for taking actions that the Constitution places in the
unassailable core of Executive power. He was not charged,
for example, with illegally wielding the Presidency’s pardon
power or veto power or appointment power or even removal
power. Instead, Trump was charged with a conspiracy to
commit fraud to subvert the Presidential election. It is true
that the detailed indictment in this case alleges that Trump


---

24 TRUMP _v._ UNITED STATES


SOTOMAYOR, J., dissenting


threatened to remove an Acting Attorney General who
would not carry out his scheme. See, _e_ . _g_ ., App. 216–217,
Indictment ¶¶74, 77. Yet it is equally clear that the Government does not seek to “impose criminal liability on the

[P]resident for exercising or talking about exercising the
appointment and removal power.” Tr. of Oral Arg. 127. If
that were the majority’s concern, it could simply have said
that the Government cannot charge a President’s threatened use of the removal power as an overt act in the conspiracy. It says much more.

The core immunity that the majority creates will insulate
a considerably larger sphere of conduct than the narrow
core of “conclusive and preclusive” powers that the Court
previously has recognized. The first indication comes when
the majority includes the President’s broad duty to “‘take
Care that the Laws be faithfully executed’” among the core
functions for which a former President supposedly enjoys
absolute immunity. _Ante,_ at 20 (quoting Art. II, §3). That
expansive view of core power will effectively insulate all
sorts of noncore conduct from criminal prosecution. Were
there any question, consider how the majority applies its
newly minted core immunity to the allegations in this case.
It concludes that “Trump is . . . absolutely immune from
prosecution for” any “conduct involving his discussions with
Justice Department officials.” _Ante,_ at 21. That conception
of core immunity expands the “conclusive and preclusive”
category beyond recognition, foreclosing the possibility of
prosecution for broad swaths of conduct. Under that view
of core powers, even fabricating evidence and insisting the
Department use it in a criminal case could be covered. The
majority’s conception of “core” immunity sweeps far more
broadly than its logic, borrowed from _Youngstown_, should
allow.

The majority tries to assuage any concerns about its
made-up core immunity by suggesting that the Government


---

Cite as: 603 U. S. ____ (2024) 25


SOTOMAYOR, J., dissenting


agrees with it. See _ante,_ at 34. That suggestion will surprise the Government. To say, as the Government did, that
a “small core of exclusive official acts” such as “the pardon
power, the power to recognize foreign nations, the power to
veto legislation, [and] the power to make appointments”
cannot be regulated by Congress, see Tr. of Oral Arg. 85–
87, does not suggest that the Government agrees with immunizing any and all conduct conceivably related to the majority’s broad array of supposedly “core” powers. The Government in fact advised this Court to “leav[e] potentially
more difficult questions” about the scope of any immunity
“that might arise on different facts for decision if they are
ever presented.” Brief for United States 45. That would
have made sense. The indictment here does not pose any
threat of impermissibly criminalizing acts within the President’s “conclusive and preclusive” authority. Perhaps for
this reason, even Trump discouraged consideration of “a
narrower scope of immunity,” claiming that such an immunity “would be nearly impossible to fashion, and would
certainly involve impractical line-drawing problems in
every application.” Brief for Petitioner 43–44.

When forced to wade into thorny separation-of-powers
disputes, this Court’s usual practice is to “confine the opinion only to the very questions necessary to decision of the
case.” _Dames & Moore_ v. _Regan_, 453 U. S. 654, 661 (1981).
There is plenty of peril and little value in crafting a core
immunity doctrine that Trump did not seek and that rightly
has no application to this case.

VI
Not content simply to invent an expansive criminal immunity for former Presidents, the majority goes a dramatic
and unprecedented step further. It says that acts for which
the President is immune must be redacted from the narrative of even wholly private crimes committed while in office.
They must play no role in proceedings regarding private


---

26 TRUMP _v._ UNITED STATES


SOTOMAYOR, J., dissenting


criminal acts. See _ante,_ at 30–32.

Even though the majority’s immunity analysis purports
to leave unofficial acts open to prosecution, its draconian
approach to official-acts evidence deprives these prosecutions of any teeth. If the former President cannot be held
criminally liable for his official acts, those acts should still
be admissible to prove knowledge or intent in criminal prosecutions of unofficial acts. For instance, the majority struggles with classifying whether a President’s speech is in his
capacity as President (official act) or as a candidate (unofficial act). Imagine a President states in an official speech
that he intends to stop a political rival from passing legislation that he opposes, no matter what it takes to do so (official act). He then hires a private hitman to murder that
political rival (unofficial act). Under the majority’s rule, the
murder indictment could include no allegation of the President’s public admission of premeditated intent to support
the _mens rea_ of murder. That is a strange result, to say the
least. [5 ]

The majority’s extraordinary rule has no basis in law.
Consider the First Amendment context. Although the First
Amendment prohibits criminalizing most speech, it “does
not prohibit the evidentiary use of speech,” including its use
“to prove motive or intent.” _Wisconsin_ v. _Mitchell_, 508 U. S.
476, 489 (1993). Evidentiary rulings and limiting instructions can ensure that evidence concerning official acts is
“considered only for the proper purpose for which it was admitted.” _Huddleston_ v. _United States_, 485 U. S. 681, 691–
692 (1988). The majority has no coherent explanation as to


——————

5 The majority suggests, in a footnote, that a “prosecutor may point to
the public record to show the fact that the President performed the official act,” so long as the prosecutor does not “invite the jury to inspect”
the act in any way. _Ante,_ at 32, n. 3. Whatever that suggestion is supposed to accomplish, it does not salvage the majority’s nonsensical evidentiary rule.


---

Cite as: 603 U. S. ____ (2024) 27


SOTOMAYOR, J., dissenting


why these protections that are sufficient in every other context would be insufficient here. It simply asserts that it
would be “untenable” and would deprive immunity of its
“‘intended effect.’” _Ante,_ at 31 (quoting _Fitzgerald_, 457
U. S., at 756). The majority hazards an explanation that
the use of official-acts evidence will “raise a unique risk that
the jurors’ deliberations will be prejudiced by their views of
the President’s policies and performance while in office.”
_Ante,_ at 31. That “unique risk,” however, is not a product
of introducing official-acts evidence. It is simply the risk
involved in any suit against a former President, including
the private-acts prosecutions the majority says it would allow.

VII
Today’s decision to grant former Presidents immunity for
their official acts is deeply wrong. As troubling as this criminal immunity doctrine is in theory, the majority’s application of the doctrine to the indictment in this case is perhaps
even more troubling. In the hands of the majority, this new
official-acts immunity operates as a one-way ratchet.
First, the majority declares all of the conduct involving
the Justice Department and the Vice President to be official
conduct, see _ante,_ at 19–24, yet it refuses to designate any
course of conduct alleged in the indictment as private, despite concessions from Trump’s counsel. [6] Trump’s counsel
conceded, for example, that the allegation that Trump


——————

6 The majority protests that it is “adher[ing] to time-tested practices”
by “deciding what is required to dispose of this case and remanding” to
lower courts to sort out the details. _Ante,_ at 41. Yet it implicitly acknowledges that it reaches far beyond what any lower court considered or any
party briefed by designating certain conduct official in the first instance.
See _ibid._ (noting “the lack of factual analysis in the lower courts, and the
lack of briefing on how to categorize the conduct alleged”). In reaching
out to shield some conduct as official while refusing to recognize any conduct as unofficial, the majority engages in judicial activism, not judicial
restraint.


---

28 TRUMP _v._ UNITED STATES


SOTOMAYOR, J., dissenting


“turned to a private attorney who was willing to spread
knowingly false claims of election fraud to spearhead his
challenges to the election results” “sounds private.” Tr. of
Oral Arg. 29. He likewise conceded that the allegation that
Trump “conspired with another private attorney who
caused the filing in court of a verification signed by [Trump]
that contained false allegations to support a challenge”
“sounds private.” _Ibid._ ; see also _id_ ., at 36–37 (Trump’s
counsel explaining that it is not “disputed” that such conduct is “unofficial”). Again, when asked about allegations
that “[t]hree private actors . . . helped implement a plan to
submit fraudulent slates of presidential electors to obstruct
the certification proceeding, and [Trump] and a co-conspirator attorney directed that effort,” Trump’s counsel conceded
the alleged conduct was “private.” _Id._, at 29–30. Only the
majority thinks that organizing fraudulent slates of electors might qualify as an official act of the President, see
_ante,_ at 24–28, or at least an act so “interrelated” with other
allegedly official acts that it might warrant protection, _ante,_
at 28. If the majority’s sweeping conception of “official acts”
has any real limits, the majority is unwilling to reveal them
in today’s decision.

Second, the majority designates certain conduct immune
while refusing to recognize anything as prosecutable. It
shields large swaths of conduct involving the Justice Department with immunity, see _ante,_ at 19–21; see also Part
V, _supra_, but it does not give an inch in the other direction.
The majority admits that the Vice President’s responsibility
“‘presiding over the Senate’” is “‘not an “executive branch”
function,’” and it further admits that the President “plays
no direct constitutional or statutory role” in the counting of
electoral votes. _Ante,_ at 23–24. Yet the majority refuses to
conclude that Trump lacks immunity for his alleged attempts to “enlist the Vice President to use his ceremonial
role at the January 6 certification proceeding to fraudulently alter the election results.” App. 187, Indictment


---

Cite as: 603 U. S. ____ (2024) 29


SOTOMAYOR, J., dissenting


¶10(d). Instead, it worries that a prosecution for this conduct might make it harder for the President to use the Vice
President “to advance [his] agenda in Congress.” _Ante,_ at
24. Such a prosecution, according to the majority, “may
well hinder the President’s ability to perform his constitutional functions.” _Ibid._ Whether a prosecution for this conduct warrants immunity should have been an easy question, but the majority turns it into a debatable one.
Remarkably, the majority goes further and declines to deny
immunity even for the allegations that Trump organized
fraudulent elector slates, pressured States to subvert the
legitimate election results, and exploited violence at the
Capitol to influence the certification proceedings. It is not
conceivable that a prosecution for these alleged efforts to
overturn a Presidential election, whether labeled official or
unofficial under the majority’s test, would pose any “‘dangers of intrusion on the authority and functions of the Executive Branch,’” _ante,_ at 14, and the majority could have
said as much. Instead, it perseverates on a threshold question that should be immaterial.

Looking beyond the fate of this particular prosecution,
the long-term consequences of today’s decision are stark.
The Court effectively creates a law-free zone around the
President, upsetting the status quo that has existed since
the Founding. This new official-acts immunity now “lies
about like a loaded weapon” for any President that wishes
to place his own interests, his own political survival, or his
own financial gain, above the interests of the Nation. _Kore-_
_matsu_ v. _United States_, 323 U. S. 214, 246 (1944) (Jackson,
J., dissenting). The President of the United States is the
most powerful person in the country, and possibly the
world. When he uses his official powers in any way, under
the majority’s reasoning, he now will be insulated from
criminal prosecution. Orders the Navy’s Seal Team 6 to assassinate a political rival? Immune. Organizes a military


---

30 TRUMP _v._ UNITED STATES


SOTOMAYOR, J., dissenting


coup to hold onto power? Immune. Takes a bribe in exchange for a pardon? Immune. Immune, immune, immune.

Let the President violate the law, let him exploit the trappings of his office for personal gain, let him use his official
power for evil ends. Because if he knew that he may one
day face liability for breaking the law, he might not be as
bold and fearless as we would like him to be. That is the
majority’s message today.

Even if these nightmare scenarios never play out, and I
pray they never do, the damage has been done. The relationship between the President and the people he serves
has shifted irrevocably. In every use of official power, the
President is now a king above the law.

              -               -               The majority’s single-minded fixation on the President’s
need for boldness and dispatch ignores the countervailing
need for accountability and restraint. The Framers were
not so single-minded. In the Federalist Papers, after “endeavor[ing] to show” that the Executive designed by the
Constitution “combines . . . all the requisites to energy,” Alexander Hamilton asked a separate, equally important
question: “Does it also combine the requisites to safety, in a
republican sense, a due dependence on the people, a due responsibility?” The Federalist No. 77, p. 507 (J. Harvard Library ed. 2009). The answer then was yes, based in part
upon the President’s vulnerability to “prosecution in the
common course of law.” _Ibid._ The answer after today is no.
Never in the history of our Republic has a President had
reason to believe that he would be immune from criminal
prosecution if he used the trappings of his office to violate
the criminal law. Moving forward, however, all former
Presidents will be cloaked in such immunity. If the occupant of that office misuses official power for personal gain,
the criminal law that the rest of us must abide will not provide a backstop.
With fear for our democracy, I dissent.


---

Cite as: 603 U. S. ____ (2024) 1


JACKSON, J., dissenting

# **SUPREME COURT OF THE UNITED STATES**

_________________


No. 23–939

_________________

DONALD J. TRUMP, PETITIONER _v._
UNITED STATES


ON WRIT OF CERTIORARI TO THE UNITED STATES COURT OF
APPEALS FOR THE DISTRICT OF COLUMBIA CIRCUIT


[July 1, 2024]


JUSTICE JACKSON, dissenting.

JUSTICE SOTOMAYOR has thoroughly addressed the
Court’s flawed reasoning and conclusion as a matter of history, tradition, law, and logic. I agree with every word of
her powerful dissent. I write separately to explain, as succinctly as I can, the theoretical nuts and bolts of what, exactly, the majority has done today to alter the paradigm of
accountability for Presidents of the United States. I also
address what that paradigm shift means for our Nation
moving forward.

I
To fully appreciate the profound change the majority has
wrought, one must first acknowledge what it means to have
immunity from criminal prosecution. Put simply, immunity is “exemption” from the duties and liabilities imposed by
law. Black’s Law Dictionary 898 (11th ed. 2019); see _Hop-_
_kins_ v. _Clemson_, 221 U. S. 636, 643 (1911) (explaining that
immunity is “exemption from legal process”). In its purest
form, the concept of immunity boils down to a maxim—
“‘[t]he King can do no wrong’”—a notion that was firmly
“rejected at the birth of [our] Republic.” _Clinton_ v. _Jones_,
520 U. S. 681, 697, n. 24 (1997) (quoting 1 W. Blackstone,
Commentaries *246 (Blackstone)); see _United States_ v.
_Burr_, 25 F. Cas. 30, 34 (No. 14,692d) (CC Va. 1807). To say


---

2 TRUMP _v._ UNITED STATES


JACKSON, J., dissenting


that someone is immune from criminal prosecution is to say
that, like a King, he “is not under the coercive power of the
law,” which “will not suppose him capable of committing a
folly, much less a crime.” 4 Blackstone *33. Thus, being
immune is not like having a defense _under_ the law. Rather,
it means that the law does not apply to the immunized person in the first place. Conferring immunity therefore “create[s] a privileged class free from liability for wrongs inflicted or injuries threatened.” _Hopkins_, 221 U. S., at 643.

It is indisputable that immunity from liability for wrongdoing is the exception rather than the rule in the American
criminal justice system. That is entirely unsurprising, for
the very idea of immunity stands in tension with foundational principles of our system of Government. It is a core
tenet of our democracy that the People are the sovereign,
and the Rule of Law is our first and final security. “[F]rom
their own experience and their deep reading in history, the
Founders knew that Law alone saves a society from being
rent by internecine strife or ruled by mere brute power however disguised.” _United States_ v. _Mine Workers_, 330 U. S.
258, 308 (1947) (Frankfurter, J., concurring in judgment).

A corollary to that principle sets the terms for this case:
“No man in this country is so high that he is above the law.
No officer of the law may set that law at defiance with impunity. All the officers of the government, from the highest
to the lowest, are creatures of the law, and are bound to
obey it.” _United States_ v. _Lee_, 106 U. S. 196, 220 (1882). We
have long lived with the collective understanding that
“[d]ecency, security and liberty alike demand that government officials shall be subjected to the same rules of conduct that are commands to the citizen,” for “[i]n a government of laws, existence of the government will be imperilled
if it fails to observe the law scrupulously.” _Olmstead_ v.
_United States_, 277 U. S. 438, 485 (1928) (Brandeis, J., dissenting).


---

Cite as: 603 U. S. ____ (2024) 3


JACKSON, J., dissenting


II

A
These foundational presuppositions are reflected in a procedural paradigm of rules and accountability that operates
in the realm of criminal law—what I would call an individual accountability model.

The basic contours of that model are familiar, because
they manifest in every criminal case. Criminal law starts
with an act of the legislature, which holds the power “to define a crime, and ordain its punishment.” _United States_ v.
_Wiltberger_, 5 Wheat. 76, 95 (1820); accord, _Ohio_ v. _Johnson_,
467 U. S. 493, 499 (1984). Criminal statutes are laws of
general applicability that express “the assent of the people’s
representatives” that certain conduct is off limits in our society. _Wooden_ v. _United States_, 595 U. S. 360, 391 (2022)
(GORSUCH, J., concurring in judgment).

When the Federal Government believes that someone has
run afoul of a criminal statute and decides to exercise its
prosecutorial discretion to pursue punishment for that violation, it persuades a grand jury that there is probable
cause to indict. U. S. Const., Amdt. 5. Then, the Government marshals evidence to prove beyond a reasonable
doubt that the defendant engaged in the prohibited conduct
and possessed the requisite state of mind. See _United_
_States_ v. _Bailey_, 444 U. S. 394, 402 (1980) (observing that,
to hold a person criminally liable, “the concurrence of . . .
‘an evil-meaning mind [and] an evil-doing hand’” must be
proved (quoting _Morissette_ v. _United States_, 342 U. S. 246,
251 (1952))).

For his part, the defendant “stands accused but is presumed innocent until conviction upon trial or guilty plea.”
_Betterman_ v. _Montana_, 578 U. S. 437, 441 (2016). Notably,
criminal defendants have various constitutionally protected rights during the criminal-liability process, including the rights to a speedy and public trial, the right to have
a jury decide guilt or innocence, the right to the assistance


---

4 TRUMP _v._ UNITED STATES


JACKSON, J., dissenting


of counsel, and the right to confront the witnesses against
him. Amdt. 6. The defendant also has at his disposal many
means to defend himself against the criminal charge. He
can, of course, seek to hold the Government to its burden of
proof at trial. And even before trial, in a motion to dismiss
the indictment, he might make any number of legal arguments; he can assert, for example, that the Government’s
charging document does not give adequate notice of the
charge against him or that the law he has been accused of
violating is unconstitutionally vague. See _Hamling_ v.
_United States_, 418 U. S. 87, 117 (1974); _United States_ v. _Da-_
_vis_, 588 U. S. 445, 451 (2019). He might further claim that
the law is unconstitutional as applied to his particular conduct. See _United States_ v. _O’Brien_, 391 U. S. 367, 376
(1968). And he might maintain that his conduct, even if
proved, does not violate the law at issue. See, _e_ . _g_ ., _Fischer_
v. _United States_, 603 U. S. ___, ___ (2024) (slip op., at 2).

The defendant may also raise, and attempt to prove, affirmative defenses that “excuse conduct that would otherwise be punishable.” _Dixon_ v. _United States_, 548 U. S. 1, 6
(2006). Generally speaking, affirmative defenses are determinations (often adopted by legislation) that certain conduct otherwise punishable by law is justified. This might
be the case, for example, when the Legislature determines
that, under specified circumstances, the societal harm particular conduct causes “is outweighed by the need to avoid
an even greater harm.” 1 P. Robinson, Criminal Law Defenses §24(a) (1984) (Robinson).

Importantly, a defense is _not_ an immunity, even though
a defense can likewise result in a person charged with a
crime avoiding liability for his criminal conduct. Consistent
with our foundational norms, the individual accountability
model adheres to the presumption that the law applies to
all and that everyone must follow it; yet, the model makes
allowances for recognized defenses. One such defense is the


---

Cite as: 603 U. S. ____ (2024) 5


JACKSON, J., dissenting


special privilege that Government officials sometimes invoke when carrying out their official duties. [1 ]

All of this is to say that our Government has long functioned under an accountability paradigm in which no one is
above the law; an accused person is innocent until proven
guilty; and criminal defendants may raise defenses, both legal and factual, tailored to their particular circumstances,
whether they be Government officials or ordinary citizens.
For over two centuries, our Nation has survived with these
principles intact.

B
With that understanding of how our system of accountability for criminal acts ordinarily functions, it becomes
much easier to see that the majority’s ruling in this case
breaks new and dangerous ground. Departing from the traditional model of individual accountability, the majority
has concocted something entirely different: a Presidential
accountability model that creates immunity—an exemption
from criminal law—applicable only to the most powerful official in our Government.

1
So, how does this new Presidential accountability model
work? An initial problem is the lack of clarity regarding
what this new model entails. The majority announces only
its most basic contours. See _ante,_ at 6 (asserting that “the


——————

1 See R. Perkins & R. Boyce, Criminal Law 1093 (3d ed. 1982) (“Deeds
which otherwise would be criminal, such as taking or destroying property, taking hold of a person by force and against his will, placing him in
confinement, or even taking his life, are not crimes if done with proper
public authority”); see also 2 Robinson §141(a) (describing the public-authority defense, under which a defendant may escape liability if he “has
been specifically authorized to engage in the conduct constituting the offense in order to protect or further a public interest”); Brief for United
States 29–30, n. 11; _ante,_ at 16, n. 3 (SOTOMAYOR, J., dissenting) (citing
_Nardone_ v. _United States_, 302 U. S. 379, 384 (1937)).


---

6 TRUMP _v._ UNITED STATES


JACKSON, J., dissenting


nature of Presidential power requires that a former President have some immunity from criminal prosecution for official acts during his tenure in office”). Instead of no immunity (the individual accountability model) or an
unqualified grant of absolute immunity for “ _all_ official
acts,” Brief for Petitioner 44 (emphasis added), the majority
purports to adopt something of a hybrid. [2] It holds that a
former President may or may not be immune from criminal
prosecution for conduct undertaken while in office, to be determined on a case-by-case basis. According to the majority, whether a former President is immune depends on how
his criminal conduct is classified, as among three possible
categories.

First, with respect to any criminal conduct relating to a
President’s “core constitutional powers”—those subjects
“within his ‘conclusive and preclusive’ constitutional authority”—the President is entitled to absolute immunity
from criminal prosecution. See _ante_, at 6, 8. Second, expanding outward from this “core,” regarding all other “acts
within the outer perimeter of [the President’s] official responsibility,” the President is entitled to “at least a _pre-_
_sumptive_ immunity from criminal prosecution.” _Ante_, at 14.

——————

2 Its feigned judicial humility notwithstanding, see _ante,_ at 41, the majority’s holding goes further— _much_ further—than necessary to resolve
this case. Petitioner’s argument in both the lower courts and this one
was that a former President is categorically immune from federal criminal prosecution for “all” acts within the outer perimeter of his official
duties. See Opening Brief for Defendant-Appellant in No. 23–3228
(CADC, Dec. 23, 2023), p. 23; 91 F. 4th 1173, 1188–1189, 1195, 1208
(CADC 2024) ( _per curiam_ ); Brief for Petitioner 41–47 (arguing for absolute immunity for “all actions within the ‘outer perimeter’ ” of a President’s responsibilities, and imploring the Court not to adopt a “ ‘functionbased’ approach”). Thus, it would have been enough for the Court simply
to reject petitioner’s categorical claim and leave it at that. But the majority _sua sponte_ rephrased the question presented, and it now takes full
advantage of this opportunity to devise from whole cloth an entirely new
legal framework for judicial evaluation of potential criminal immunity
for former Presidents.


---

Cite as: 603 U. S. ____ (2024) 7


JACKSON, J., dissenting


Third, if the criminal conduct at issue comprises “unofficial
acts, there is no immunity.” _Ante_, at 15. [3 ]

Applying the majority’s new Presidential accountability
model thus seems to involve bearing down on the indictment’s allegations and making a series of determinations
about the nature of the conduct at issue. From the structure of the paradigm, it appears that the first decision point
is whether the alleged criminal conduct involves one of the
President’s “core” powers. If so (and apparently regardless
of the degree to which the conduct implicates that core
power), the President is absolutely immune from criminal
liability for engaging in that criminal conduct. If not, then
one must proceed to consider whether the conduct qualifies
as an “official” act or “unofficial” act of that President. If
the crime is an official act, the President is presumptively
immune from criminal prosecution and punishment. But
even then, immunity still hinges on whether there is any
legal or factual basis for concluding that the presumption of
immunity has been rebutted. Alternatively, if the charged
conduct is an unofficial act (a determination that, inci

——————

3 It is important to note that the majority reframes the immunity question presented here as a separation of powers concern that is compelled
by Article II—as if what is being asked is whether Congress can criminalize executive prerogatives. See, _e.g._, _ante_, at 6–7; see also _ante,_ at 1–
2 (BARRETT, J., concurring in part). But that is not anywhere close to
what is happening in this case. No one maintains that Congress has
passed a law that specifically criminalizes the President’s use of any
power that the Constitution vests exclusively in the Executive, much less
that the Judiciary is being conscripted to adjudicate the propriety of such
a statute. To the contrary, the indictment here invokes criminal statutes
of general applicability that everyone is supposed to follow, both on and
off the job. So, the real question is: Can the President, too, be held accountable for committing crimes while he is undertaking his official duties? The nature of his authority under Article II (whether conclusive
and preclusive, or shared with Congress, or otherwise) is entirely beside
the point.


---

8 TRUMP _v._ UNITED STATES


JACKSON, J., dissenting


dentally, courts must make without considering the President’s motivations, _ante,_ at 18), the President is not immune. [4 ]

2
The majority’s multilayered, multifaceted threshold
parsing of the character of a President’s criminal conduct
differs from the individual accountability model in several
crucial respects. For one thing, it makes it next to impossible to know _ex ante_ when and under what circumstances a
President will be subject to accountability for his criminal
acts. For every allegation, courts must run this gauntlet
first—no matter how well documented or heinous the criminal act might be.
Thus, even a hypothetical President who admits to having ordered the assassinations of his political rivals or critics, see, _e.g.,_ Tr. of Oral Arg. 9, or one who indisputably instigates an unsuccessful coup, _id_ ., at 41–43, has a fair shot
at getting immunity under the majority’s new Presidential
accountability model. That is because whether a President’s conduct will subject him to criminal liability turns on
the court’s evaluation of a variety of factors related to the
character of that particular act—specifically, those characteristics that imbue an act with the status of “official” or
“unofficial” conduct (minus motive). In the end, then, under
the majority’s new paradigm, whether the President will be
exempt from legal liability for murder, assault, theft, fraud,


——————

4 JUSTICE BARRETT’s version of the Presidential accountability paradigm works slightly differently; she would have us ask, first, “whether
the relevant criminal statute reaches the President’s official conduct.”
_Ante,_ at 2. But, again, what is at issue here are statutes of general applicability—they only “reach” the President’s conduct to the extent that
he chooses to engage in the prohibited behavior. See n. 3, _supra_ . JUSTICE
BARRETT’s framing, thus, sidesteps the fact that, when immunity is being
considered, what is actually at issue is whether the President is exempt
from punishment if he opts to exercise his official duties using means
that violate criminal law.


---

Cite as: 603 U. S. ____ (2024) 9


JACKSON, J., dissenting


or any other reprehensible and outlawed criminal act will
turn on whether he committed that act in his official capacity, such that the answer to the immunity question will always and inevitably be: It depends.

Under the individual accountability paradigm, the accountability analysis is markedly less convoluted, and leads
to a more certain outcome. None of the same complications
or consequences arise, because, as I have explained, there
are no exemptions from the criminal law for any person, but
every defendant can assert whatever legal arguments and
defenses might be applicable under governing law. Since
no one is above the law, everyone can focus on what the law
demands and permits, and on what the defendant did or did
not do; no one has to worry about characterizing any criminal conduct as official or unofficial in order to assess the
applicability of an immunity at the outset.

The majority’s new Presidential accountability model is
also distinct insofar as it accepts as a basic starting premise
that generally applicable criminal laws do _not_ apply to everyone in our society. In the majority’s view, while all other
citizens of the United States must do their jobs and live
their lives within the confines of criminal prohibitions, the
President cannot be made to do so; he must sometimes be
exempt from the law’s dictates depending on the character
of his conduct. Indeed, the majority holds that the President, unlike anyone else in our country, is comparatively
free to engage in criminal acts in furtherance of his official
duties.

That point bears emphasizing. Immunity can issue for
Presidents under the majority’s model even for unquestionably and intentionally egregious criminal behavior. Regardless of the nature or the impact of the President’s criminal conduct, so long as he is committing crimes “pursuant
to the powers invested exclusively in him by the Constitution,” _ante,_ at 7, or as needed “to carry out his constitutional
duties without undue caution,” _ante,_ at 14, he is likely to be


---

10 TRUMP _v._ UNITED STATES


JACKSON, J., dissenting


deemed immune from prosecution. [5 ]

Ultimately, the majority’s model simply sets the criminal
law to one side when it comes to crimes allegedly committed
by the President. Before accountability can be sought or
rendered, the Judiciary serves as a newfound special gatekeeper, charged not merely with interpreting the law but
with policing whether it applies to the President _at all_ .
Also, under the new Presidential accountability model, the
starting presumption is that the criminal law does _not_ apply to Presidents, no matter how obviously illegal, harmful,
or unacceptable a President’s official behavior might be.
Regardless of all that, courts must now ensure that a former President is _not_ held accountable for any criminal conduct he engages in while he is on duty, unless his conduct
consists primarily (and perhaps solely) of unofficial acts.

3
The structure and function of the two accountability paradigms are not the only differences—the models also assign
different roles to participants in the criminal justice system, and they ultimately generate different relationships
between the Presidency and the Rule of Law.

Under the individual accountability model, duty-bound
prosecutorial officers initially exercise their discretion to
decide whether to seek punishment for alleged violations of

——————

5 To fully appreciate the oddity of making the criminal immunity determination turn on the character of the President’s responsibilities, consider what the majority says is one of the President’s “conclusive and
preclusive” prerogatives: “ ‘[t]he President’s power to remove . . . those
who wield executive power on his behalf.’ ” _Ante,_ at 8 (quoting _Seila Law_
_LLC_ v. _Consumer Financial Protection_ _Bureau_, 591 U. S. 197, 204
(2020)). While the President may have the authority to decide to remove
the Attorney General, for example, the question here is whether the
President has the option to remove the Attorney General by, say, poisoning him to death. Put another way, the issue here is not whether the
President has exclusive removal power, but whether a generally applicable criminal law prohibiting murder can restrict _how_ the President exercises that authority.


---

Cite as: 603 U. S. ____ (2024) 11


JACKSON, J., dissenting


criminal law (a determination that is made based on numerous factors). And even if prosecutors decide to bring a
charge, a jury of the criminal defendant’s peers ultimately
determines whether that defendant (including a former
President) will actually be held to account for having engaged in unlawful conduct, after the court has resolved any
legal challenges and has instructed the jury as to the requirements of the law.

By contrast, under the majority’s new Presidential accountability paradigm, what a prosecutor or jury does may
not even matter, since the courts take center stage once
charges are brought against a former President, marshaling their resources to conduct a complex and amorphous
threshold immunity evaluation. Whether a former President will be entirely exempted from the dictates of the law
(such that the roles of other participants in the criminal justice process become irrelevant) requires a judicial assessment, in the first instance, of his criminal conduct and the
circumstances under which he acted.

Finally, and most importantly, recall that under the individual accountability model, an indicted former President
can raise an affirmative defense just like any other criminal
defendant. This means that the President remains answerable to the law, insofar as he must show that he was justified in committing a criminal act while in office under the
given circumstances. In other words, while the President
might indeed be privileged to commit a crime in the course
of his official duties, any such privilege exists only when the
People (acting either through their elected representatives
or as members of a jury) determine that the former President’s conduct was in fact justified, notwithstanding the
general criminal prohibition.

Under the majority’s immunity regime, by contrast, the
President can commit crimes in the course of his job even
under circumstances _in which no one thinks he has any ex-_


---

12 TRUMP _v._ UNITED STATES


JACKSON, J., dissenting


_cuse_ ; the law simply does not apply to him. Unlike a defendant who invokes an affirmative defense and relies on a
legal determination that there was a good reason for his
otherwise unlawful conduct, a former President invoking
immunity relies on the premise that he can do whatever he
wants, however he wants, so long as he uses his “‘official
power’” in doing so. _Ante,_ at 19. In the former paradigm,
the President remains subject to law; in the latter, he is
above it.

III
JUSTICE SOTOMAYOR has already warned of the dire consequences that are likely to follow from the majority’s decision in this case. _Ante,_ at 29–30 (dissenting opinion). I have
thus far endeavored merely to explain what today’s ruling
amounts to on a theoretical level: the Court’s abandonment
of the individual accountability model as applied to Presidents, and its introduction of a new Presidential accountability model that authorizes the Judiciary to exempt Presidents from punishment under law, depending on the official
or unofficial character of the criminal conduct at issue.
Here, I will highlight just two observations about the results that follow from this paradigm shift. First, by changing the accountability paradigm in this fashion, the Court
has unilaterally altered the balance of power between the
three coordinate branches of our Government as it relates
to the Rule of Law, aggrandizing power in the Judiciary and
the Executive, to the detriment of Congress. Second, the
majority’s new Presidential accountability model undermines the constraints of the law as a deterrent for future
Presidents who might otherwise abuse their power, to the
detriment of us all.

A
Consider the structural implications of today’s decision
from the standpoint of the separation of powers. Until now,


---

Cite as: 603 U. S. ____ (2024) 13


JACKSON, J., dissenting


Congress’s laws, passed by the representatives of the People, bound the People and their elected officials just the
same. Law, we have explained, “is the only supreme power
in our system of government, and every man who by accepting office participates in its functions is only the more
strongly bound to submit to that supremacy, and to observe
the limitations which it imposes upon the exercise of the
authority which it gives.” _Lee_, 106 U. S., at 220. With its
adoption of a paradigm that sometimes exempts the President from the dictates of the law (when the Court says so),
this Court has effectively snatched from the Legislature the
authority to bind the President (or not) to Congress’s mandates, and it has also thereby substantially augmented the
power of both the Office of the Presidency and itself.

As to the former, it should go without saying that the Office of the Presidency, the apex of the Executive Branch, is
made significantly more powerful when the constraints of
the criminal law are lifted with respect to the exercise of a
President’s official duties. After today’s ruling, the President must still “take Care that the Laws be faithfully executed,” Art. II, §3; yet, when acting in his official capacity,
he has no obligation to follow those same laws himself.

But whatever additional power the majority’s new Presidential accountability model gives to the Presidency, it
gives doubly to the Court itself, for the majority provides no
meaningful guidance about how to apply this new paradigm
or how to categorize a President’s conduct. For instance, its
opinion lists some examples of the “core” constitutional
powers with respect to which the President is now entitled
to absolute immunity—a list that apparently includes the
removal power, the power to recognize foreign nations, and
the pardon power. _Ante,_ at 6–9. However, the majority
does not—and likely cannot—supply any useful or administrable definition of the scope of that “core.” For what it’s
worth, the Constitution’s text is no help either; Article II


---

14 TRUMP _v._ UNITED STATES


JACKSON, J., dissenting


does not contain a Core Powers Clause. [6] So the actual
metes and bounds of the “core” Presidential powers are really anyone’s guess.

Nor does the majority explain how to consistently distinguish between official and unofficial acts. Quite the opposite, in fact. While acknowledging that this is a critical line
that courts must draw in order for its new accountability
model to work properly, the majority simultaneously cautions that making this distinction “can be difficult”—likely
a gross understatement given the recognized “breadth of
the President’s ‘discretionary responsibilities’ under the
Constitution and laws of the United States.” _Ante,_ at 17.
The majority likewise provides no guidance as to when,
how, or why the President’s “presumptive” immunity for
noncore official acts might be rebutted, saying only that applying the criminal law to a President’s acts must pose “no
‘dangers of intrusion on the authority and functions of the
Executive Branch.’” _Ante,_ at 14 (quoting _Nixon_ v. _Fitzger-_
_ald_, 457 U. S. 731, 754 (1982)).

At most, to distinguish official from unofficial conduct,
the majority advises asking whether the former President’s
conduct was “‘manifestly or palpably beyond [his] authority.’” _Ante,_ at 17 (quoting _Blassingame_ v. _Trump_, 87 F. 4th
1, 13 (CADC 2023)). But that test can be illusory, as is evidenced by the facts alleged in this very case. With respect
to the indictment’s allegations concerning petitioner’s attempt to assemble false slates of electors in conjunction


——————

6 Some of the powers the majority designates as “core” powers are, at
best, implied from indefinite constitutional language. See, _e_ . _g_ ., _Seila_
_Law_, 591 U. S., at 268–269 (KAGAN, J., concurring in judgment with respect to severability and dissenting in part) (“Nowhere does the text say
anything about the President’s power to remove subordinate officials at
will”); _Zivotofsky_ v. _Kerry_, 576 U. S. 1, 11 (2015) (“[T]he Constitution does
not use the term ‘recognition,’ either in Article II or elsewhere”); _id_ ., at
63 (ROBERTS, C. J., dissenting) (calling the “asserted textual bases” for
an exclusive Presidential recognition power “tenuous”).


---

Cite as: 603 U. S. ____ (2024) 15


JACKSON, J., dissenting


with the events of January 6, 2021, for example, the majority admits that the “alleged conduct cannot be neatly categorized,” and that “[t]he analysis therefore . . . may prove to
be challenging.” _Ante,_ at 28–29. With that, at least, I could
not agree more.

This much is clear: Before today, none of these kinds of
inquiries was necessary for criminal liability to be fairly assessed with respect to persons accused of having engaged in
criminal conduct. And, frankly, none is needed now—except as relates to the President under the new paradigm the
majority has crafted.

Perhaps even more troubling, while Congress (the branch
of our Government most accountable to the People) is the
entity our Constitution tasks with deciding, as a general
matter, what conduct is on or off limits, the Court has now
arrogated that power unto itself when that question pertains to the President. In essence, the Court has now imposed its own preclearance requirement on the application
of Congress’s laws to a former President alleged to have
committed crimes while in office. Who will be responsible
for drawing the crucial “‘line between [the President’s] personal and official affairs’”? _Ante,_ at 29. To ask the question
is to know the answer. A majority of this Court, applying
an indeterminate test, will pick and choose which laws apply to which Presidents, by labeling his various allegedly
criminal acts as “core,” “official,” or “manifestly or palpably”
beyond the President’s authority.

Ironically, then, while purportedly seeking to transcend
politics, see _ante,_ at 41–42, the Court today displaces the
independent judgments of the political branches about the
circumstances under which the criminal law should apply.
Effectively, the Court elbows out of the way both Congress
and prosecutorial authorities within the Executive Branch,
making itself the indispensable player in all future attempts to hold former Presidents accountable to generally
applicable criminal laws. “The Framers, however, did not


---

16 TRUMP _v._ UNITED STATES


JACKSON, J., dissenting


make the judiciary the overseer of our government.”
_Youngstown Sheet & Tube Co._ v. _Sawyer_, 343 U. S. 579, 594
(1952) (Frankfurter, J., concurring). To be sure, this Court
may sometimes “have to intervene in determining where
authority lies as between the democratic forces in our
scheme of government.” _Id_ ., at 597. But it has long been
understood that “we should be wary and humble” when doing so. _Ibid_ .

The majority displays no such caution or humility now.
Instead, the Court today transfers from the political
branches to itself the power to decide when the President
can be held accountable. What is left in its wake is a greatly
weakened Congress, which must stand idly by as the President disregards its criminal prohibitions and uses the powers of his office to push the envelope, while choosing to follow (or not) existing laws, as he sees fit. We also now have
a greatly empowered Court, which can opt to allow Congress’s policy judgments criminalizing conduct to stand (or
not) with respect to a former President, as a matter of its
own prerogative.

B
If the structural consequences of today’s paradigm shift
mark a step in the wrong direction, then the practical consequences are a five-alarm fire that threatens to consume
democratic self-governance and the normal operations of
our Government. The majority shoos away this possibility.
_Ante,_ at 37 (accusing the dissents of “strik[ing] a tone of
chilling doom that is wholly disproportionate to what the
Court actually does today”). But JUSTICE SOTOMAYOR
makes this point plain, see _ante,_ at 29–30, and I will not
belabor it.

Here, I will merely observe that, from a theoretical perspective, philosophers have long considered deterrence to
be a key justification for adopting and maintaining systems


---

Cite as: 603 U. S. ____ (2024) 17


JACKSON, J., dissenting


that ensure accountability for criminal conduct. [7] For that
same reason, some commentators also maintain that decreasing the certainty of accountability for wrongful acts at
least arguably reduces incentives to follow the law. [8 ]

Under the individual accountability model, because everyone is subject to the law, the potential of criminal liability
operates as a constraint on the actions and decisions of everyone, including the President. After today, that reality is
no more. Consequently, our Nation has lost a substantial
check on Presidents who would use their official powers to
commit crimes with impunity while in office.

So, one might ask, what remains of accountability for
Presidents under law? With today’s paradigm shift, the
majority leaves in place only the chance that this Court
might someday determine that the criminal conduct in
question was an “unofficial” act, or that the Government
will somehow rebut the presumption of immunity that applies to a President’s official acts, such that criminal consequences might attach. But with the parameters of official
and unofficial conduct unknown, I think it highly unlikely
that a sitting President would feel constrained by these remote possibilities.


——————

7 See, _e_ . _g_ ., Plato, Laws 274 (B. Jowett transl. 2000) (“Not that he is
punished because he did wrong, for that which is done can never be undone, but in order that in future times, he, and those who see him corrected, may utterly hate injustice, or at any rate abate much of their evildoing”); see also J. Bentham, The Rationale of Punishment 20 (1830)
(“General prevention ought to be the chief end of punishment, as it is its
real justification”); A. von Hirsch, Doing Justice: The Choice of Punishments 44 (1976) (“The threat and imposition of punishment is called for
in order to secure compliance—not full compliance, but more compliance
than there might be were there no legal penalties at all”).

8 See, _e_ . _g_ ., M. Ryan, Taking Another Look at Second-Look Sentencing,
81 Brooklyn L. Rev. 149, 156, and n. 37 (2015) (“[U]ndermining the . . .
certainty of punishment . . . could undermine the deterrence value of
punishment”).


---

18 TRUMP _v._ UNITED STATES


JACKSON, J., dissenting


All of this leads me to ponder why, exactly, has the majority concluded that an indeterminate “core”-versus-“official”-versus-“unofficial” line-drawing exercise is the better
way to address potential criminal acts of a President?
Could it be that the majority believes the obviously grave
dangers of shifting from the individual accountability
model to the Presidential accountability model might nevertheless be offset by the great benefits of doing so? Cf. J.
Bentham, A Fragment on Government and an Introduction
to the Principles of Morals and Legislation 3 (W. Harrison
ed. 1948) (arguing that acts can be justified by the maxim
that “it is the greatest happiness of the greatest number
that is the measure of right and wrong” (emphasis deleted)).

Some of the majority’s analysis suggests as much. As far
as I can tell, the majority is mostly concerned that, without
immunity, Presidents might “be chilled from taking the
‘bold and unhesitating action’ required of an independent
Executive.” _Ante,_ at 13. The Court’s opinion candidly laments that application of the law to Presidents might not
be evenhanded, and that, as a result, Presidents might be
less “‘vigorous’ and ‘energetic’” as executive officers. _Ante,_
at 10; accord, _ante,_ at 39. But that concern ignores (or rejects) the foundational principles upon which the traditional individual accountability paradigm is based. Worse
still, promoting more vigor from Presidents in exercising
their official duties—and, presumably, less deliberation—
invites breathtaking risks in terms of harm to the American
people that, in my view, far outweigh the benefits.

This is not to say that the majority is wrong when it perceives that it can be cumbersome for a President to have to
follow the law while carrying out his duty to enforce it. It
is certainly true that “[a] scheme of government like ours
no doubt at times feels the lack of power to act with complete, all-embracing, swiftly moving authority.” _Youngs-_
_town_, 343 U. S., at 613 (Frankfurter, J., concurring). But


---

Cite as: 603 U. S. ____ (2024) 19


JACKSON, J., dissenting


any American who has studied history knows that “our government was _designed_ to have such restrictions.” _Ibid._ (emphasis added). Our Constitution’s “separation of powers
was adopted by the Convention of 1787, not to promote efficiency but to preclude the exercise of arbitrary power. The
purpose was, not to avoid friction, but . . . to save the people
from autocracy.” _Myers_ v. _United States_, 272 U. S. 52, 293
(1926) (Brandeis, J., dissenting).

Having now cast the shadow of doubt over when—if
ever—a former President will be subject to criminal liability
for any criminal conduct he engages in while on duty, the
majority incentivizes all future Presidents to cross the line
of criminality while in office, knowing that unless they act
“manifestly or palpably beyond [their] authority,” _ante,_ at
17, they will be presumed above prosecution and punishment alike.

But the majority also tells us not to worry, because “[l]ike
everyone else, the President is subject to prosecution in his
_unofficial_ capacity.” _Ante,_ at 40 (emphasis added). This attempted reassurance is cold comfort, even setting aside the
fact that the Court has neglected to lay out a standard that
reliably distinguishes between a President’s official and unofficial conduct. Why? Because there is _still_ manifest inequity: Presidents alone are now free to commit crimes when
they are on the job, while all other Americans must follow
the law in all aspects of their lives, whether personal or professional. The official-versus-unofficial act distinction also
seems both arbitrary and irrational, for it suggests that the
unofficial criminal acts of a President are the only ones worthy of prosecution. Quite to the contrary, it is when the
President commits crimes using his unparalleled official
powers that the risks of abuse and autocracy will be most
dire. So, the fact that, “unlike anyone else, the President
is” vested with “sweeping powers and duties,” _ibid._, actually
underscores, rather than undermines, the grim stakes of
setting the criminal law to the side when the President


---

20 TRUMP _v._ UNITED STATES


JACKSON, J., dissenting


flexes those very powers.

The vision John Adams enshrined in the Massachusetts
Declaration of Rights—“‘a government of laws and not of
men’”—speaks directly to this concept. _Mine Workers_, 330
U. S., at 307 (Frankfurter, J., concurring in judgment). Adams characterized that document as an homage to the Rule
of Law; it reflected both a flat “rejection in positive terms of
rule by fiat” and a solemn promise that “[e]very act of government may be challenged by an appeal to law.” _Id_ ., at
308. Thanks to the majority, that vision and promise are
likely to be fleeting in the future. From this day forward,
Presidents of tomorrow will be free to exercise the Commander-in-Chief powers, the foreign-affairs powers, and all
the vast law enforcement powers enshrined in Article II
however they please—including in ways that Congress has
deemed criminal and that have potentially grave consequences for the rights and liberties of Americans.

IV
To the extent that the majority’s new accountability paradigm allows Presidents to evade punishment for their
criminal acts while in office, the seeds of absolute power for
Presidents have been planted. And, without a doubt, absolute power corrupts absolutely. “If one man can be allowed
to determine for himself what is law, every man can. That
means first chaos, then tyranny.” _Id_ ., at 312. Likewise, “[i]f
the Government becomes a lawbreaker, it breeds contempt
for law; it invites every man to become a law unto himself;
it invites anarchy.” _Olmstead_, 277 U. S., at 485 (Brandeis,
J., dissenting). I worry that, after today’s ruling, our Nation
will reap what this Court has sown.
Stated simply: The Court has now declared for the first
time in history that the most powerful official in the United
States can (under circumstances yet to be fully determined)
become a law unto himself. As we enter this uncharted territory, the People, in their wisdom, will need to remain ever


---

Cite as: 603 U. S. ____ (2024) 21


JACKSON, J., dissenting


attentive, consistently fulfilling their established role in our
constitutional democracy, and thus collectively serving as
the ultimate safeguard against any chaos spawned by this
Court’s decision. For, like our democracy, our Constitution
is “the creature of their will, and lives only by their will.”
_Cohens_ v. _Virginia_, 6 Wheat. 264, 389 (1821).

For my part, I simply cannot abide the majority’s senseless discarding of a model of accountability for criminal acts
that treats every citizen of this country as being equally
subject to the law—as the Rule of Law requires. That core
principle has long prevented our Nation from devolving into
despotism. Yet the Court now opts to let down the guardrails of the law for one extremely powerful category of citizen: any future President who has the will to flout Congress’s established boundaries.

In short, America has traditionally relied on the law to
keep its Presidents in line. Starting today, however, Americans must rely on the courts to determine when (if at all)
the criminal laws that their representatives have enacted
to promote individual and collective security will operate as
speedbumps to Presidential action or reaction. Once selfregulating, the Rule of Law now becomes the rule of judges,
with courts pronouncing which crimes committed by a President have to be let go and which can be redressed as impermissible. So, ultimately, this Court itself will decide
whether the law will be any barrier to whatever course of
criminality emanates from the Oval Office in the future.
The potential for great harm to American institutions and
Americans themselves is obvious.

              -               -               The majority of my colleagues seems to have put their
trust in our Court’s ability to prevent Presidents from becoming Kings through case-by-case application of the indeterminate standards of their new Presidential accountability paradigm. I fear that they are wrong. But, for all our


---

22 TRUMP _v._ UNITED STATES


JACKSON, J., dissenting


sakes, I hope that they are right.

In the meantime, because the risks (and power) the Court
has now assumed are intolerable, unwarranted, and plainly
antithetical to bedrock constitutional norms, I dissent.

---
*Conversion confidence: 100% (119 pages)*